@@ -1,6 +1,6 @@
 /*************************************************************************************
   Copyright (C) 2004 by Jeroen Wijnhout (Jeroen.Wijnhout@kdemail.net)
-                2012-2019 by Michel Ludwig (michel.ludwig@kdemail.net)
+                2012-2024 by Michel Ludwig (michel.ludwig@kdemail.net)
  *************************************************************************************/
 
 /***************************************************************************
@@ -24,9 +24,9 @@
 #include <KJob>
 #include <KLocalizedString>
 #include <KPluginFactory>
-#include <KPluginLoader>
 #include <KProcess>
 
+#include <QPluginLoader>
 #include <QTemporaryDir>
 
 #include "documentinfo.h"
@@ -80,7 +80,7 @@ void ConfigTest::addDependency(ConfigTest *test)
 
 bool ConfigTest::allDependenciesSucceeded() const
 {
-    Q_FOREACH(ConfigTest *test, m_dependencyTestList) {
+    for(ConfigTest *test : m_dependencyTestList) {
         if(test->status() != Success) {
             return false;
         }
@@ -138,13 +138,13 @@ void Tester::runTests()
 #endif
     KIO::CopyJob *copyJob = KIO::copyAs(QUrl::fromLocalFile(testDirectory), QUrl::fromLocalFile(destinationDirectory), KIO::HideProgressInfo | KIO::Overwrite);
     connect(copyJob, SIGNAL(result(KJob*)), this, SLOT(handleFileCopyResult(KJob*)));
-    emit(percentageDone(0));
+    Q_EMIT(percentageDone(0));
 }
 
 void Tester::handleFileCopyResult(KJob* job)
 {
     if(job->error()) {
-        emit(finished(false));
+        Q_EMIT(finished(false));
     }
     else {
         startNextTest();
@@ -200,8 +200,8 @@ void Tester::startNextTest()
         m_currentTest->call();
     }
     else {
-        emit(percentageDone(100));
-        emit(finished(true));
+        Q_EMIT(percentageDone(100));
+        Q_EMIT(finished(true));
     }
 }
 
@@ -212,7 +212,7 @@ void Tester::handleTestComplete(ConfigTest *test)
         addResult(test->testGroup(), test);
     }
     ++m_testsDone;
-    emit(percentageDone((m_testsDone / (float) m_testList.size()) * 100.0));
+    Q_EMIT(percentageDone((m_testsDone / (float) m_testList.size()) * 100.0));
     startNextTest();
 }
 
@@ -248,7 +248,7 @@ void TestToolInKileTest::call()
                             "Kile is not configured correctly. Go to Settings->Configure Kile->Tools "
                             "and either fix the problem or change to the default settings."
                            );
-        emit(testComplete(this));
+        Q_EMIT(testComplete(this));
         return;
     }
     // We don't want the tool to spawn subtools (especially, for LaTeX-style tools).
@@ -267,7 +267,7 @@ void TestToolInKileTest::reportSuccess()
 
     m_status = Success;
     m_resultText = i18n("Passed");
-    emit(testComplete(this));
+    Q_EMIT(testComplete(this));
 }
 
 void TestToolInKileTest::reportFailure()
@@ -277,7 +277,7 @@ void TestToolInKileTest::reportFailure()
 
     m_status = Failure;
     m_resultText = i18n("Failed");
-    emit(testComplete(this));
+    Q_EMIT(testComplete(this));
 }
 
 
@@ -305,15 +305,15 @@ OkularVersionTest::~OkularVersionTest()
 
 void OkularVersionTest::call()
 {
-    KPluginLoader pluginLoader(OKULAR_LIBRARY_NAME);
-    KPluginFactory *factory = pluginLoader.factory();
+    QPluginLoader pluginLoader(OKULAR_LIBRARY_NAME);
+    KPluginFactory *factory = qobject_cast<KPluginFactory *>(pluginLoader.instance());
 
     if (!factory) {
         m_status = Failure;
     }
     else {
         KParts::ReadOnlyPart *part = factory->create<KParts::ReadOnlyPart>();
-        Okular::ViewerInterface *viewerInterface = dynamic_cast<Okular::ViewerInterface*>(part);
+        Okular::ViewerInterface *viewerInterface = qobject_cast<Okular::ViewerInterface*>(part);
 
         if(!viewerInterface) {
             // OkularPart doesn't provide the ViewerInterface
@@ -327,9 +327,9 @@ void OkularVersionTest::call()
         delete part;
     }
 
-    delete factory;
+    pluginLoader.unload();
 
-    emit(testComplete(this));
+    Q_EMIT(testComplete(this));
 }
 
 
@@ -381,7 +381,7 @@ void FindProgramTest::call()
         m_status = Success;
         m_resultText = i18nc("executable => path", "Found (%1 => %2)", m_programName, execPath);
     }
-    emit(testComplete(this));
+    Q_EMIT(testComplete(this));
 }
 
 void FindProgramTest::setAdditionalFailureMessage(const QString& s)
@@ -415,22 +415,20 @@ void ProgramTest::call()
     m_testProcess->setWorkingDirectory(m_workingDir);
     QStringList argList;
     if(!m_arg0.isEmpty()) {
-        argList << m_arg0;
+        argList.push_back(m_arg0);
     }
     if(!m_arg1.isEmpty()) {
-        argList << m_arg1;
+        argList.push_back(m_arg1);
     }
     if(!m_arg2.isEmpty()) {
-        argList << m_arg2;
+        argList.push_back(m_arg2);
     }
     m_testProcess->setProgram(m_programName, argList);
     if (!KileConfig::teXPaths().isEmpty()) {
         m_testProcess->setEnv("TEXINPUTS", KileInfo::expandEnvironmentVars(KileConfig::teXPaths() + ":$TEXINPUTS"));
     }
-    connect(m_testProcess, SIGNAL(finished(int,QProcess::ExitStatus)),
-            this, SLOT(handleTestProcessFinished(int,QProcess::ExitStatus)));
-    connect(m_testProcess, SIGNAL(error(QProcess::ProcessError)),
-            this, SLOT(handleTestProcessError(QProcess::ProcessError)));
+    connect(m_testProcess, &KProcess::finished, this, &ProgramTest::handleTestProcessFinished);
+    connect(m_testProcess, &KProcess::errorOccurred, this, &ProgramTest::handleTestProcessError);
     m_testProcess->start();
 }
 
@@ -465,7 +463,7 @@ void ProgramTest::reportSuccess()
 {
     m_resultText = i18n("Passed");
     m_status = Success;
-    emit(testComplete(this));
+    Q_EMIT(testComplete(this));
 }
 
 void ProgramTest::reportFailure()
@@ -477,7 +475,7 @@ void ProgramTest::reportFailure()
         m_resultText = i18n("Failed");
     }
     m_status = Failure;
-    emit(testComplete(this));
+    Q_EMIT(testComplete(this));
 }
 
 
@@ -520,14 +518,14 @@ void LaTeXSrcSpecialsSupportTest::reportSuccess()
 {
     m_resultText = i18n("Supported, use the 'Modern' configuration for (La)TeX to auto-enable inverse and forward search capabilities.");
     m_status = Success;
-    emit(testComplete(this));
+    Q_EMIT(testComplete(this));
 }
 
 void LaTeXSrcSpecialsSupportTest::reportFailure()
 {
     m_resultText = i18n("Not supported, use the srcltx package to enable the inverse and forward search capabilities.");
     m_status = Failure;
-    emit(testComplete(this));
+    Q_EMIT(testComplete(this));
 }
 
 
@@ -547,14 +545,14 @@ void SyncTeXSupportTest::reportSuccess()
 {
     m_resultText = i18n("Supported, use the 'Modern' configuration for PDFLaTeX and XeLaTeX to auto-enable inverse and forward search capabilities.");
     m_status = Success;
-    emit(testComplete(this));
+    Q_EMIT(testComplete(this));
 }
 
 void SyncTeXSupportTest::reportFailure()
 {
     m_resultText = i18n("Not supported");
     m_status = Failure;
-    emit(testComplete(this));
+    Q_EMIT(testComplete(this));
 }
 
 void SyncTeXSupportTest::processFinishedSuccessfully()
@@ -574,22 +572,22 @@ void Tester::installConsecutivelyDependentTests(ConfigTest *t1, ConfigTest *t2,
     if(!t1) {
         return;
     }
-    m_testList << t1;
+    m_testList.push_back(t1);
     if(!t2) {
         return;
     }
     t2->addDependency(t1);
-    m_testList << t2;
+    m_testList.push_back(t2);
     if(!t3) {
         return;
     }
     t3->addDependency(t2);
-    m_testList << t3;
+    m_testList.push_back(t3);
     if(!t4) {
         return;
     }
     t4->addDependency(t3);
-    m_testList << t4;
+    m_testList.push_back(t4);
 }
 
 void Tester::setupTests()
@@ -795,7 +793,7 @@ void Tester::setupTests()
     */
     FindProgramTest *dvipngProgramTest = new FindProgramTest("DVItoPNG", "dvipng", false);
     dvipngProgramTest->setAdditionalFailureMessage(i18n("PNG previews cannot be used for mathgroups in the bottom preview pane"));
-    m_testList << dvipngProgramTest;
+    m_testList.push_back(dvipngProgramTest);
     /*
     echo "starting test: Convert"
     setTool Convert
@@ -805,7 +803,7 @@ void Tester::setupTests()
     */
     FindProgramTest *convertProgramTest = new FindProgramTest("Convert", "convert", false);
     convertProgramTest->setAdditionalFailureMessage(i18n("PNG previews cannot be used with conversions 'dvi->ps->png' and 'pdf->png' in the bottom preview pane"));
-    m_testList << convertProgramTest;
+    m_testList.push_back(convertProgramTest);
 }
 
 bool Tester::isSyncTeXSupportedForPDFLaTeX()
