@@ -73,7 +73,7 @@ ResultItem::ResultItem(QListWidget *listWidget, const QString &toolGroup, int st
                 itemcolor = "#FFA201";
             }
         }
-        rt += QString("<li><b><font color=\"%1\">%2</font></b>: &nbsp;%3</li>").arg(itemcolor).arg(tests[i]->name()).arg(tests[i]->resultText());
+        rt += QString("<li><b><font color=\"%1\">%2</font></b>: &nbsp;%3</li>").arg(itemcolor, tests[i]->name(), tests[i]->resultText());
     }
     rt += "</ul>";
 
@@ -89,7 +89,7 @@ ResultItem::ResultItem(QListWidget *listWidget, const QString &toolGroup, int st
         }
     }
 
-    setData(Qt::UserRole, rt.arg(color).arg(toolGroup).arg(statustr));
+    setData(Qt::UserRole, rt.arg(color, toolGroup, statustr));
 
     //this is for sorting only
     setText(QString::number(status) + ':' + toolGroup);
@@ -206,7 +206,6 @@ void ConfigChecker::finished(bool ok)
 
     nextButton()->setVisible(false);
     finishButton()->setVisible(true);
-    QString testResultText = "<br/>";
 
     QStringList tools = m_tester->testGroups();
     QStringList critical, failure;
@@ -228,7 +227,7 @@ void ConfigChecker::finished(bool ok)
 
     if(ok) {
         QString cap = i18n("Test Results");
-        QString overallResultText;
+        QString testResultText = "<br/>";
         if (critical.count() > 0) {
             testResultText += i18n("The following <b>critical</b> tests did not succeed:"
                                    "<br/><br/>%1<br/><br/>Kile cannot function correctly on your system. Please consult the "
@@ -279,7 +278,7 @@ void ConfigChecker::finished(bool ok)
     }
     else {
         // start by hiding all the labels
-        Q_FOREACH(QWidget *widget, m_testResultsPageWidgetItem->widget()->findChildren<QLabel*>()) {
+        for(QWidget *widget : m_testResultsPageWidgetItem->widget()->findChildren<QLabel*>()) {
             widget->setVisible(false);
         }
         // and then we show those again that we want
