@@ -4,7 +4,7 @@
    Copyright (C) 2001 Anders Lund <anders.lund@lund.tdcadsl.dk>
    Copyright (C) 2003 Jan-Marek Glogowski <glogow@stud.fbi.fh-darmstadt.de>
    Copyright (C) 2005 Holger Danielsson <holger.danielsson@versanet.de>
-   Copyright (C) 2008-2014 Michel Ludwig <michel.ludwig@kdemail.net>
+   Copyright (C) 2008-2022 Michel Ludwig <michel.ludwig@kdemail.net>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -56,13 +56,12 @@
 #include <QListWidget>
 #include <QObject>
 #include <QPushButton>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QVBoxLayout>
 
 #include <KProcess>
 #include <KAcceleratorManager>
 #include <KComboBox>
-#include <KIconLoader>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KShell>
@@ -149,7 +148,7 @@ FindFilesDialog::FindFilesDialog(QWidget *parent, KileInfo *ki, KileGrep::Mode m
                       << i18n("File");
 
     QHBoxLayout *template_layout = new QHBoxLayout();
-    template_layout->setMargin(0);
+    template_layout->setContentsMargins(0, 0, 0, 0);
     template_combo = new KComboBox(false, searchgroup);
     template_combo->addItems(templatemode_list);
     template_combo->adjustSize();
@@ -454,23 +453,22 @@ void FindFilesDialog::slotItemSelected(const QString& item)
 {
     KILE_DEBUG_MAIN << "\tgrep: start item selected";
     int pos;
-    QString filename, linenumber;
 
     QString str = item;
     if((pos = str.indexOf(':')) != -1) {
-        filename = str.left(pos);
+        QString filename = str.left(pos);
         str = str.right(str.length() - 1 - pos);
         if((pos = str.indexOf(':')) != -1) {
-            linenumber = str.left(pos);
+            QString linenumber = str.left(pos);
             QFileInfo fileInfo(filename);
             if(fileInfo.isAbsolute()) {
-                emit itemSelected(filename, linenumber.toInt());
+                Q_EMIT itemSelected(filename, linenumber.toInt());
             }
             else if(m_mode == KileGrep::Project) {
-                emit itemSelected(m_projectdir + QDir::separator() + filename, linenumber.toInt());
+                Q_EMIT itemSelected(m_projectdir + QDir::separator() + filename, linenumber.toInt());
             }
             else {
-                emit itemSelected(dir_combo->comboBox()->itemText(0) + QDir::separator() + filename, linenumber.toInt());
+                Q_EMIT itemSelected(dir_combo->comboBox()->itemText(0) + QDir::separator() + filename, linenumber.toInt());
             }
         }
     }
@@ -640,7 +638,7 @@ QString FindFilesDialog::buildFilesCommand()
         files_temp = filter_combo->currentText();
     }
 
-    QStringList tokens = files_temp.split(' ', QString::SkipEmptyParts);
+    QStringList tokens = files_temp.split(' ', Qt::SkipEmptyParts);
     QStringList::Iterator it = tokens.begin();
     if (it != tokens.end()) {
         files = " '" + (*it) + '\'';
@@ -687,7 +685,7 @@ void FindFilesDialog::slotSearch()
     }
 
     KILE_DEBUG_MAIN << "\tgrep: start new search";
-    QRegExp re(getPattern());
+    QRegularExpression re(getPattern());
     if(!re.isValid()) {
         KMessageBox::error(m_ki->mainWindow(), i18n("Invalid regular expression: %1", re.errorString()), i18n("Grep Tool Error"));
         return;
