@@ -21,7 +21,7 @@
 #include <QHBoxLayout>
 #include <QLabel>
 #include <QLayout>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QTreeWidget>
 #include <QValidator>
 #include <QVBoxLayout>
@@ -85,7 +85,7 @@ NewLatexCommand::NewLatexCommand(QWidget *parent, const QString &caption,
 
     // layout
     QVBoxLayout *vbox = new QVBoxLayout();
-    vbox->setMargin(0);
+    vbox->setContentsMargins(0, 0, 0, 0);
     page->setLayout(vbox);
 
     QLabel *label1 = new QLabel(page);
@@ -195,8 +195,6 @@ NewLatexCommand::NewLatexCommand(QWidget *parent, const QString &caption,
             // m_coParameter->addItem(QString());
             m_coParameter->setWhatsThis(i18n("Does this command need an argument?"));
         }
-
-        currentRow++;
     }
 
     // stretch last row
@@ -213,8 +211,8 @@ NewLatexCommand::NewLatexCommand(QWidget *parent, const QString &caption,
             label1->setText(i18n("Define a new LaTeX command:"));
             pattern = "\\\\?[A-Za-z]+";
         }
-        QRegExp reg(pattern);
-        m_edName->setValidator(new QRegExpValidator(reg, m_edName));
+        QRegularExpression reg(pattern);
+        m_edName->setValidator(new QRegularExpressionValidator(reg, m_edName));
         m_edName->setFocus();
     }
     else {                         // edit mode
@@ -575,9 +573,8 @@ bool LatexCommandsDialog::isUserDefined(const QString &name)
 
 bool LatexCommandsDialog::hasUserDefined(QTreeWidget *listview)
 {
-    QTreeWidgetItem *tli;
     for (int i = 0; i < listview->topLevelItemCount(); ++i) {
-        tli = listview->topLevelItem(i);
+        QTreeWidgetItem *tli = listview->topLevelItem(i);
         for (int j = 0; j < tli->childCount(); ++j) {
             if (isUserDefined(tli->child(j)->text(0))) {
                 return true;
@@ -599,7 +596,7 @@ void LatexCommandsDialog::slotEnableButtons()
     QTreeWidget *listview = (getListviewMode() == lvEnvMode) ? m_widget.environments : m_widget.commands;
     resetState = (hasUserDefined(listview));
 
-    QTreeWidgetItem *item = (QTreeWidgetItem *)listview->currentItem();
+    QTreeWidgetItem *item = listview->currentItem();
 
     if (item && item != m_lviAmsmath)
     {
@@ -631,12 +628,12 @@ void LatexCommandsDialog::slotAddClicked()
         caption  = i18n("LaTeX Commands");
     }
 
-    QTreeWidgetItem *item = (QTreeWidgetItem *)listview->currentItem();
+    QTreeWidgetItem *item = listview->currentItem();
     if (item && isParentItem(item)) {
         // get current command type
         KileDocument::CmdAttribute type = getCommandMode(item);
         if (type == KileDocument::CmdAttrNone) {
-            KILE_DEBUG_MAIN << "\tLatexCommandsDialog error: no item in slotAddClicked() (" << item->text(0) << ")" << endl;
+            KILE_DEBUG_MAIN << "\tLatexCommandsDialog error: no item in slotAddClicked() (" << item->text(0) << ")" << Qt::endl;
             return;
         }
 
@@ -649,7 +646,7 @@ void LatexCommandsDialog::slotAddClicked()
             QString name;
             KileDocument::LatexCmdAttributes attr;
             dialog->getParameter(name, attr);
-            setEntry((QTreeWidgetItem *)item, name, attr);
+            setEntry(item, name, attr);
             // open this parent item
             if (!item->isExpanded()) {
                 item->setExpanded(true);
@@ -674,7 +671,7 @@ void LatexCommandsDialog::slotDeleteClicked()
         message  = i18n("Do you want to delete this command?");
     }
 
-    QTreeWidgetItem *item = (QTreeWidgetItem *)listview->currentItem();
+    QTreeWidgetItem *item = listview->currentItem();
     if (item && !isParentItem(item)) {
         if (KMessageBox::warningContinueCancel(this, message, i18n("Delete")) == KMessageBox::Continue) {
             m_commandChanged = true;
@@ -703,14 +700,14 @@ void LatexCommandsDialog::slotEditClicked()
         caption  = i18n("LaTeX Commands");
     }
 
-    QTreeWidgetItem *item = (QTreeWidgetItem *)listview->currentItem();
+    QTreeWidgetItem *item = listview->currentItem();
     if (item && !isParentItem(item)) {
-        QTreeWidgetItem *parentitem = (QTreeWidgetItem *)item->parent();
+        QTreeWidgetItem *parentitem = item->parent();
         if (parentitem) {
             // get current command type
             KileDocument::CmdAttribute type = getCommandMode(parentitem);
             if (type == KileDocument::CmdAttrNone) {
-                KILE_DEBUG_MAIN << "\tLatexCommandsDialog error: no item in slotAddClicked() (" << item->text(0) << ")" << endl;
+                KILE_DEBUG_MAIN << "\tLatexCommandsDialog error: no item in slotAddClicked() (" << item->text(0) << ")" << Qt::endl;
                 return;
             }
 
@@ -807,7 +804,7 @@ void LatexCommandsDialog::writeConfig(QTreeWidget *listview, const QString &grou
         attr.type = getCommandMode(cur);
         if (attr.type == KileDocument::CmdAttrNone)
         {
-            KILE_DEBUG_MAIN << "\tLatexCommandsDialog error: no parent item (" << cur->text(0) << ")" << endl;
+            KILE_DEBUG_MAIN << "\tLatexCommandsDialog error: no parent item (" << cur->text(0) << ")" << Qt::endl;
             continue;
         }
 
@@ -819,7 +816,7 @@ void LatexCommandsDialog::writeConfig(QTreeWidget *listview, const QString &grou
             {
                 getEntry(curchild, attr);
                 QString value = m_commands->configString(attr, env);
-                KILE_DEBUG_MAIN << "\tLatexCommandsDialog write config: " << key << " --> " << value << endl;
+                KILE_DEBUG_MAIN << "\tLatexCommandsDialog write config: " << key << " --> " << value << Qt::endl;
                 if (!value.isEmpty()) {
                     group.writeEntry("Command" + QString::number(nrOfdefinedCommands), key);
                     group.writeEntry("Parameters" + QString::number(nrOfdefinedCommands), value);
