@@ -24,7 +24,6 @@
 
 class QDialogButtonBox;
 class QTreeWidget;
-class QStringList;
 class KDirWatch;
 
 class KileListSelector : public QDialog
@@ -51,7 +50,7 @@ protected:
 
 class ManageCompletionFilesDialog : public QDialog
 {
-    Q_OBJECT;
+    Q_OBJECT
 
 public:
     ManageCompletionFilesDialog(const QString &caption,
