@@ -30,7 +30,7 @@
 #include <KConfigGroup>
 #include <KIconDialog>
 #include <KIconLoader>
-#include <KIO/Job>
+#include <KIO/StatJob>
 #include <KJobWidgets>
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -78,7 +78,7 @@ ManageTemplatesDialog::ManageTemplatesDialog(KileTemplate::Manager *templateMana
     page->setObjectName("managetemplates_mainwidget");
     mainLayout->addWidget(page);
     QGridLayout *topLayout = new QGridLayout();
-    topLayout->setMargin(0);
+    topLayout->setContentsMargins(0, 0, 0, 0);
     page->setLayout(topLayout);
 
     topLayout->addWidget(new QLabel(i18n("Name:"), page), 0, 0);
@@ -159,7 +159,6 @@ ManageTemplatesDialog::ManageTemplatesDialog(KileTemplate::Manager *templateMana
     setModal(true);
 
     QVBoxLayout *mainLayout = new QVBoxLayout();
-    mainLayout->setMargin(0);
     setLayout(mainLayout);
 
     m_templateList = new QTreeWidget(this);
@@ -204,7 +203,6 @@ void ManageTemplatesDialog::populateTemplateListView(KileDocument::Type type)
 {
     m_templateManager->scanForTemplates();
     KileTemplate::TemplateList templateList = m_templateManager->getTemplates(type);
-    QString mode;
     QTreeWidgetItem* previousItem = Q_NULLPTR;
 
     m_templateList->clear();
@@ -212,7 +210,7 @@ void ManageTemplatesDialog::populateTemplateListView(KileDocument::Type type)
     {
         KileTemplate::Info info = *i;
         QFileInfo iconFileInfo(info.icon);
-        mode = (QFileInfo(info.path).isWritable() && (!iconFileInfo.exists() || iconFileInfo.isWritable())) ? " " : "*";
+        QString mode = (QFileInfo(info.path).isWritable() && (!iconFileInfo.exists() || iconFileInfo.isWritable())) ? " " : "*";
         if ((type == KileDocument::Undefined) || (info.type == type)) {
             previousItem = new TemplateListViewItem(m_templateList, previousItem, mode, info);
         }
@@ -260,7 +258,7 @@ void ManageTemplatesDialog::addTemplate()
         return;
     }
 
-    KIO::StatJob* statJob = KIO::stat(iconURL, KIO::StatJob::SourceSide, 0);
+    KIO::StatJob* statJob = KIO::stat(iconURL, KIO::StatJob::SourceSide, KIO::StatNoDetails);
     KJobWidgets::setWindow(statJob, this);
     statJob->exec();
     if (statJob->error()) {
@@ -268,7 +266,7 @@ void ManageTemplatesDialog::addTemplate()
         return;
     }
 
-    statJob = KIO::stat(m_sourceURL, KIO::StatJob::SourceSide, 0);
+    statJob = KIO::stat(m_sourceURL, KIO::StatJob::SourceSide, KIO::StatNoDetails);
     KJobWidgets::setWindow(statJob, this);
     statJob->exec();
     if (statJob->error()) {
@@ -288,15 +286,16 @@ void ManageTemplatesDialog::addTemplate()
         TemplateListViewItem *templateItem = dynamic_cast<TemplateListViewItem*>(item);
         Q_ASSERT(templateItem);
         KileTemplate::Info templateInfo = templateItem->getTemplateInfo();
-        if (KMessageBox::warningYesNo(this, i18n("You are about to replace the template \"%1\"; are you sure?", templateInfo.name)) == KMessageBox::No) {
+        if (KMessageBox::warningTwoActions(this, i18n("You are about to replace the template \"%1\"; are you sure?", templateInfo.name),
+                                           i18n("Replace template"),
+                                           KStandardGuiItem::ok(), KStandardGuiItem::cancel()) == KMessageBox::SecondaryAction) {
             reject();
             return;
         }
-        returnValue = m_templateManager->replace(templateInfo, m_sourceURL, templateName, iconURL);
-    }
-    else {
-        returnValue = m_templateManager->add(m_sourceURL, templateName, iconURL);
     }
+
+    returnValue = m_templateManager->add(m_sourceURL, templateName, iconURL);
+
     if (!returnValue) {
         KMessageBox::error(this, i18n("Failed to create the template."));
         reject();
@@ -317,18 +316,9 @@ bool ManageTemplatesDialog::removeTemplate()
 
     KileTemplate::Info templateInfo = templateItem->getTemplateInfo();
 
-    KIO::StatJob* statJob = KIO::stat(QUrl::fromUserInput(templateInfo.path), KIO::StatJob::DestinationSide, 0);
-    KIO::StatJob* statJob2 = KIO::stat(QUrl::fromUserInput(templateInfo.icon), KIO::StatJob::DestinationSide, 0);
-    KJobWidgets::setWindow(statJob, this);
-    KJobWidgets::setWindow(statJob2, this);
-    statJob->exec();
-    statJob2->exec();
-    if ((statJob->error() && statJob2->error()) || !QFileInfo(templateInfo.icon).exists()) {
-        KMessageBox::error(this, i18n("Sorry, but you do not have the necessary permissions to remove the selected template."));
-        return false;
-    }
-
-    if (KMessageBox::warningYesNo(this, i18n("You are about to remove the template \"%1\"; are you sure?", templateInfo.name)) == KMessageBox::No) {
+    if (KMessageBox::warningTwoActions(this, i18n("You are about to remove the template \"%1\"; are you sure?", templateInfo.name),
+                                       i18n("Replace template"),
+                                       KStandardGuiItem::remove(), KStandardGuiItem::cancel()) == KMessageBox::SecondaryAction) {
         return false;
     }
 
