@@ -49,7 +49,7 @@ MathEnvironmentDialog::MathEnvironmentDialog(QWidget *parent, KConfig *config, K
     setWindowTitle(i18n("Math Environments"));
 
     QVBoxLayout *vbox = new QVBoxLayout();
-    vbox->setMargin(0);
+    vbox->setContentsMargins(0, 0, 0, 0);
     page->setLayout(vbox);
 
     // environment groupbox
@@ -183,7 +183,7 @@ bool MathEnvironmentDialog::isParameterEnv()
 
 void MathEnvironmentDialog::slotEnvironmentChanged(int index)
 {
-    KILE_DEBUG_MAIN << "environment changed: " << m_coEnvironment->itemText(index) << endl;
+    KILE_DEBUG_MAIN << "environment changed: " << m_coEnvironment->itemText(index) << Qt::endl;
     m_envname = m_coEnvironment->itemText(index);
 
     // look for environment parameter in dictionary
@@ -317,7 +317,6 @@ void MathEnvironmentDialog::slotAccepted()
         aligngroups = true;
         numgroups = (m_tabulator != "&") ? m_spCols->value() : 1;
         if (m_edSpace->isEnabled()) {
-            QString spaces;
             grouptabulator = "  &" + m_edSpace->text() + "  ";
         }
         else {
