@@ -31,7 +31,6 @@
 #include <QStandardPaths>
 
 #include <KComboBox>
-#include <KIconLoader>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KProcess>
@@ -77,7 +76,7 @@ PostscriptDialog::PostscriptDialog(QWidget *parent,
                 QString basename = psfilename = texfilename.left(texfilename.length() - (*it).length());
                 psfilename = basename + ".ps";
                 psoutfilename = basename + "-out.ps";
-                if (!QFileInfo(psfilename).exists())
+                if (!QFileInfo::exists(psfilename))
                     psfilename.clear();
                 break;
             }
@@ -137,9 +136,12 @@ PostscriptDialog::PostscriptDialog(QWidget *parent,
     if (psselect) {
         m_PostscriptDialog.m_cbTask->addItem(i18n("psselect: Choose Parameter")); // 17  PS_PSSELECT_FREE
     }
-
-    m_PostscriptDialog.m_edInfile->setFilter("*.ps|PS Files\n*.ps.gz|Zipped PS Files");
-    m_PostscriptDialog.m_edOutfile->setFilter("*.ps|PS Files\n*.ps.gz|Zipped PS Files");
+    const QStringList postscriptMimeTypes = {
+        QStringLiteral("application/postscript"),
+        QStringLiteral("application/x-gzpostscript"),
+    };
+    m_PostscriptDialog.m_edInfile->setMimeTypeFilters(postscriptMimeTypes);
+    m_PostscriptDialog.m_edOutfile->setMimeTypeFilters(postscriptMimeTypes);
     m_PostscriptDialog.m_edOutfile->setMode(KFile::File | KFile::LocalOnly);
 
     // choose one common task
@@ -216,7 +218,7 @@ void PostscriptDialog::execute()
                     + i18n("***** output file: ") + to.fileName()+ '\n'
                     + i18n("***** viewer:      ") + ((m_PostscriptDialog.m_cbView->isChecked()) ? i18n("yes") : i18n("no")) + '\n'
                     + "*****\n";
-        emit( output(s) );
+        Q_EMIT( output(s) );
 
         // delete old KProcess
         if (m_proc)
@@ -242,8 +244,8 @@ void PostscriptDialog::execute()
 
 void PostscriptDialog::slotProcessOutput()
 {
-    emit(output(m_proc->readAllStandardOutput()));
-    emit(output(m_proc->readAllStandardError()));
+    Q_EMIT(output(m_proc->readAllStandardOutput()));
+    Q_EMIT(output(m_proc->readAllStandardError()));
 }
 
 
@@ -340,7 +342,7 @@ QString PostscriptDialog::buildTempfile()
     QString tempname = temp.fileName();
 
     QTextStream stream(&temp);
-    stream << "#! /bin/sh" << endl;
+    stream << "#! /bin/sh" << Qt::endl;
 
     // accept only ".ps" or ".ps.gz" as an input file
     QFileInfo fi(m_PostscriptDialog.m_edInfile->lineEdit()->text());
@@ -367,43 +369,43 @@ QString PostscriptDialog::buildTempfile()
 
     if (!zipped_psfile) {                                       // unzipped ps files
         if (m_PostscriptDialog.m_edOutfile->lineEdit()->text().isEmpty()) { // pstops/psselect | okular
-            stream << command << " " << inputfile << " | okular -" << endl;
+            stream << command << " " << inputfile << " | okular -" << Qt::endl;
             viewer = false;
         } else {                                                    // pstops/psselect
-            stream << command << " " << inputfile << " " << outputfile << endl;
+            stream << command << " " << inputfile << " " << outputfile << Qt::endl;
         }
     } else {                                                      // zipped ps files
         if (m_PostscriptDialog.m_edOutfile->lineEdit()->text().isEmpty()) { // pstops/psselect | okular
             stream << "gunzip -c " << inputfile
                    << " | " << command
                    << " | okular -"
-                   << endl;
+                   << Qt::endl;
             viewer = false;
         } else {
             stream << "gunzip -c " << inputfile                    // pstops/psselect
                    << " | " << command
                    << " > " << outputfile
-                   << endl;
+                   << Qt::endl;
         }
     }
 
     // check, if we should stop
     if ( equalfiles || viewer ) {
-        stream << "if [ $? != 0 ]; then" << endl;
-        stream << "   exit 1" << endl;
-        stream << "fi" << endl;
+        stream << "if [ $? != 0 ]; then" << Qt::endl;
+        stream << "   exit 1" << Qt::endl;
+        stream << "fi" << Qt::endl;
     }
 
     // replace the original file
     if ( equalfiles ) {
-        stream << "rm " << inputfile << endl;
-        stream << "mv " << outputfile << " " << inputfile << endl;
+        stream << "rm " << inputfile << Qt::endl;
+        stream << "mv " << outputfile << " " << inputfile << Qt::endl;
     }
 
     // viewer
     if ( viewer ) {                                                // viewer: okular
         stream << "okular" << " "
-               << ((equalfiles) ? inputfile : outputfile) << endl;
+               << ((equalfiles) ? inputfile : outputfile) << Qt::endl;
     }
 
     // everything is prepared to do the job
@@ -473,9 +475,11 @@ bool PostscriptDialog::checkParameter()
 
         if (infile != outfile && fo.exists()) {
             QString s = i18n("A file named \"%1\" already exists. Are you sure you want to overwrite it?", fo.fileName());
-            if (KMessageBox::questionYesNo(this,
-                                           "<center>" + s + "</center>",
-                                           "Postscript tools") == KMessageBox::No) {
+            if (KMessageBox::questionTwoActions(this,
+                                                "<center>" + s + "</center>",
+                                                "Postscript tools",
+                                                KStandardGuiItem::overwrite(), KStandardGuiItem::cancel())
+                == KMessageBox::SecondaryAction) {
                 return false;
             }
         }
@@ -486,7 +490,7 @@ bool PostscriptDialog::checkParameter()
 
 void PostscriptDialog::comboboxChanged(int index)
 {
-    KILE_DEBUG_MAIN << index << endl;
+    KILE_DEBUG_MAIN << index << Qt::endl;
     if (index == PS_COPY_SORTED || index == PS_COPY_UNSORTED) {
         m_PostscriptDialog.m_lbParameter->setEnabled(true);
         m_PostscriptDialog.m_lbParameter->setText(i18n("Copies:"));
