@@ -34,7 +34,6 @@ copyright            : Thomas Fischer <t-fisch@users.sourceforge.net>
 
 #include <KComboBox>
 #include <KConfig>
-#include <KIconLoader>
 #include <QLineEdit>
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -237,7 +236,7 @@ QWidget *QuickDocument::setupClassOptions(QTabWidget *tab)
     // button
     QWidget *frame = new QWidget(classOptions);
     QHBoxLayout *hl = new QHBoxLayout();
-    hl->setMargin(0);
+    hl->setContentsMargins(0, 0, 0, 0);
     frame->setLayout(hl);
     gl->addWidget(frame, 5, 1, 1, 3, Qt::AlignCenter);
 
@@ -291,7 +290,7 @@ QWidget *QuickDocument::setupPackages(QTabWidget *tab)
     QWidget *frame = new QWidget(packages);
     vl->addWidget(frame);
     QHBoxLayout *hl = new QHBoxLayout();
-    hl->setMargin(0);
+    hl->setContentsMargins(0, 0, 0, 0);
     frame->setLayout(hl);
     hl->addStretch();
 
@@ -332,7 +331,7 @@ QWidget *QuickDocument::setupProperties(QTabWidget *tab)
 
     QWidget *personalInfoPage = new QWidget(tab);
     QVBoxLayout *vl = new QVBoxLayout();
-    vl->setMargin(0);
+    vl->setContentsMargins(0, 0, 0, 0);
     personalInfoPage->setLayout(vl);
 
     QWidget *personalInfo = new QWidget(personalInfoPage);
@@ -938,7 +937,7 @@ void QuickDocument::fillCombobox(KileWidget::CategoryComboBox *combo, const QStr
     bool documentclasscombo = (combo == m_cbDocumentClass);
 
     QString sep = (m_currentClass == "beamer" && combo == m_cbPaperSize) ? ";" : ",";
-    QStringList list = cslist.split(sep, QString::SkipEmptyParts);
+    QStringList list = cslist.split(sep, Qt::SkipEmptyParts);
     if (!documentclasscombo) {
         list.sort();
     }
@@ -1030,142 +1029,142 @@ void QuickDocument::initPackages()
     QTreeWidgetItem *clichild;
 
     m_lvPackages->clear();
-    cli = insertTreeWidget(m_lvPackages, "amsmath", i18n("Special math environments and commands (AMS)"));
-    cli = insertTreeWidget(m_lvPackages, "amsfonts", i18n("Collection of fonts and symbols for math mode (AMS)"));
-    cli = insertTreeWidget(m_lvPackages, "amssymb", i18n("Defines symbol names for all math symbols in MSAM and MSBM (AMS)"));
-    cli = insertTreeWidget(m_lvPackages, "amsthm", i18n("Improved theorem setup (AMS)"));
-    cli = insertTreeWidget(m_lvPackages, "caption", i18n("Extends caption capabilities for figures and tables"));
+    insertTreeWidget(m_lvPackages, "amsmath", i18n("Special math environments and commands (AMS)"));
+    insertTreeWidget(m_lvPackages, "amsfonts", i18n("Collection of fonts and symbols for math mode (AMS)"));
+    insertTreeWidget(m_lvPackages, "amssymb", i18n("Defines symbol names for all math symbols in MSAM and MSBM (AMS)"));
+    insertTreeWidget(m_lvPackages, "amsthm", i18n("Improved theorem setup (AMS)"));
+    insertTreeWidget(m_lvPackages, "caption", i18n("Extends caption capabilities for figures and tables"));
 
     cli = insertTreeWidget(m_lvPackages, "hyperref", i18n("Hypertext marks in LaTeX"));
     cli->setExpanded(true);
     clichild = insertTreeWidget(cli, "dvips", i18n("Use dvips as hyperref driver"));
     clichild->setCheckState(0, Qt::Checked);
-    clichild = insertTreeWidget(cli, "pdftex", i18n("Use pdftex as hyperref driver"));
-    clichild = insertEditableTreeWidget(cli, "bookmarks", i18n("Make bookmarks"), "true", "true");
-    clichild = insertEditableTreeWidget(cli, "bookmarksnumbered", i18n("Put section numbers in bookmarks"), "false", "false");
-    clichild = insertEditableTreeWidget(cli, "bookmarksopen", i18n("Open up bookmark tree"), QString(), QString());
-    clichild = insertEditableTreeWidget(cli, "pdfauthor", i18n("Text for PDF Author field"), QString(), QString());
-    clichild = insertEditableTreeWidget(cli, "pdfcreator", i18n("Text for PDF Creator field"), i18n("LaTeX with hyperref package"), i18n("LaTeX with hyperref package"));
-    clichild = insertEditableTreeWidget(cli, "pdffitwindow", i18n("Resize document window to fit document size"), "false", "false");
-    clichild = insertEditableTreeWidget(cli, "pdfkeywords", i18n("Text for PDF Keywords field"), QString(), QString());
-    clichild = insertEditableTreeWidget(cli, "pdfproducer", i18n("Text for PDF Producer field"), QString(), QString());
-    clichild = insertEditableTreeWidget(cli, "pdfstartview", i18n("Starting view of PDF document"), "/Fit", "/Fit");
-    clichild = insertEditableTreeWidget(cli, "pdfsubject", i18n("Text for PDF Subject field"), QString(), QString());
-    clichild = insertEditableTreeWidget(cli, "pdftitle", i18n("Text for PDF Title field"), QString(), QString());
+    insertTreeWidget(cli, "pdftex", i18n("Use pdftex as hyperref driver"));
+    insertEditableTreeWidget(cli, "bookmarks", i18n("Make bookmarks"), "true", "true");
+    insertEditableTreeWidget(cli, "bookmarksnumbered", i18n("Put section numbers in bookmarks"), "false", "false");
+    insertEditableTreeWidget(cli, "bookmarksopen", i18n("Open up bookmark tree"), QString(), QString());
+    insertEditableTreeWidget(cli, "pdfauthor", i18n("Text for PDF Author field"), QString(), QString());
+    insertEditableTreeWidget(cli, "pdfcreator", i18n("Text for PDF Creator field"), i18n("LaTeX with hyperref package"), i18n("LaTeX with hyperref package"));
+    insertEditableTreeWidget(cli, "pdffitwindow", i18n("Resize document window to fit document size"), "false", "false");
+    insertEditableTreeWidget(cli, "pdfkeywords", i18n("Text for PDF Keywords field"), QString(), QString());
+    insertEditableTreeWidget(cli, "pdfproducer", i18n("Text for PDF Producer field"), QString(), QString());
+    insertEditableTreeWidget(cli, "pdfstartview", i18n("Starting view of PDF document"), "/Fit", "/Fit");
+    insertEditableTreeWidget(cli, "pdfsubject", i18n("Text for PDF Subject field"), QString(), QString());
+    insertEditableTreeWidget(cli, "pdftitle", i18n("Text for PDF Title field"), QString(), QString());
 
-    cli = insertTreeWidget(m_lvPackages, "mathpazo", i18n("Use Palatino font as roman font (both text and math mode)"));
-    cli = insertTreeWidget(m_lvPackages, "mathptmx", i18n("Use Times font as roman font (both text and math mode)"));
-    cli = insertTreeWidget(m_lvPackages, "makeidx", i18n("Enable index generation"));
-    cli = insertTreeWidget(m_lvPackages, "multicol", i18n("Enables multicolumn environments"));
-    cli = insertTreeWidget(m_lvPackages, "pst-all", i18n("Load all pstricks packages"));
-    cli = insertTreeWidget(m_lvPackages, "rotating", i18n("Rotates text"));
-    cli = insertTreeWidget(m_lvPackages, "subfigure", i18n("Enables subfigures inside figures"));
-    cli = insertTreeWidget(m_lvPackages, "upgreek", i18n("Typesetting capital Greek letters"));
-    cli = insertTreeWidget(m_lvPackages, "xcolor", i18n("Extending LaTeX's color facilities"));
+    insertTreeWidget(m_lvPackages, "mathpazo", i18n("Use Palatino font as roman font (both text and math mode)"));
+    insertTreeWidget(m_lvPackages, "mathptmx", i18n("Use Times font as roman font (both text and math mode)"));
+    insertTreeWidget(m_lvPackages, "makeidx", i18n("Enable index generation"));
+    insertTreeWidget(m_lvPackages, "multicol", i18n("Enables multicolumn environments"));
+    insertTreeWidget(m_lvPackages, "pst-all", i18n("Load all pstricks packages"));
+    insertTreeWidget(m_lvPackages, "rotating", i18n("Rotates text"));
+    insertTreeWidget(m_lvPackages, "subfigure", i18n("Enables subfigures inside figures"));
+    insertTreeWidget(m_lvPackages, "upgreek", i18n("Typesetting capital Greek letters"));
+    insertTreeWidget(m_lvPackages, "xcolor", i18n("Extending LaTeX's color facilities"));
 
     cli = insertTreeWidget(m_lvPackages, "babel", i18n("Adds language specific support"));
     cli->setExpanded(true);
     cli->setCheckState(0, Qt::Checked);
-    clichild = insertTreeWidget(cli, "acadian", "");
-    clichild = insertTreeWidget(cli, "afrikaans", "");
-    clichild = insertTreeWidget(cli, "american", "");
-    clichild = insertTreeWidget(cli, "australian", "");
-    clichild = insertTreeWidget(cli, "austrian", "");
-    clichild = insertTreeWidget(cli, "bahasa", "");
-    clichild = insertTreeWidget(cli, "basque", "");
-    clichild = insertTreeWidget(cli, "brazil", "");
-    clichild = insertTreeWidget(cli, "brazilian", "");
-    clichild = insertTreeWidget(cli, "breton", "");
-    clichild = insertTreeWidget(cli, "british", "");
-    clichild = insertTreeWidget(cli, "bulgarian", "");
-    clichild = insertTreeWidget(cli, "canadian", "");
-    clichild = insertTreeWidget(cli, "canadien", "");
-    clichild = insertTreeWidget(cli, "catalan", "");
-    clichild = insertTreeWidget(cli, "croatian", "");
-    clichild = insertTreeWidget(cli, "czech", "");
-    clichild = insertTreeWidget(cli, "danish", "");
-    clichild = insertTreeWidget(cli, "dutch", "");
-    clichild = insertTreeWidget(cli, "english", "");
-    clichild = insertTreeWidget(cli, "esperanto", "");
-    clichild = insertTreeWidget(cli, "estonian", "");
-    clichild = insertTreeWidget(cli, "finnish", "");
-    clichild = insertTreeWidget(cli, "francais", "");
-    clichild = insertTreeWidget(cli, "frenchb", "");
-    clichild = insertTreeWidget(cli, "french", "");
-    clichild = insertTreeWidget(cli, "galician", "");
-    clichild = insertTreeWidget(cli, "german", "");
-    clichild = insertTreeWidget(cli, "germanb", "");
-    clichild = insertTreeWidget(cli, "greek", "");
-    clichild = insertTreeWidget(cli, "polutonikogreek", "");
-    clichild = insertTreeWidget(cli, "hebrew", "");
-    clichild = insertTreeWidget(cli, "hungarian", "");
-    clichild = insertTreeWidget(cli, "icelandic", "");
-    clichild = insertTreeWidget(cli, "interlingua", "");
-    clichild = insertTreeWidget(cli, "irish", "");
-    clichild = insertTreeWidget(cli, "italian", "");
-    clichild = insertTreeWidget(cli, "latin", "");
-    clichild = insertTreeWidget(cli, "lowersorbian", "");
-    clichild = insertTreeWidget(cli, "magyar", "");
-    clichild = insertTreeWidget(cli, "naustrian", "");
-    clichild = insertTreeWidget(cli, "newzealand", "");
-    clichild = insertTreeWidget(cli, "ngerman", "");
-    clichild = insertTreeWidget(cli, "norsk", "");
-    clichild = insertTreeWidget(cli, "samin", "");
-    clichild = insertTreeWidget(cli, "nynorsk", "");
-    clichild = insertTreeWidget(cli, "polish", "");
-    clichild = insertTreeWidget(cli, "portuges", "");
-    clichild = insertTreeWidget(cli, "portuguese", "");
-    clichild = insertTreeWidget(cli, "romanian", "");
-    clichild = insertTreeWidget(cli, "russian", "");
-    clichild = insertTreeWidget(cli, "scottish", "");
-    clichild = insertTreeWidget(cli, "serbian", "");
-    clichild = insertTreeWidget(cli, "slovak", "");
-    clichild = insertTreeWidget(cli, "slovene", "");
-    clichild = insertTreeWidget(cli, "spanish", "");
-    clichild = insertTreeWidget(cli, "swedish", "");
-    clichild = insertTreeWidget(cli, "turkish", "");
-    clichild = insertTreeWidget(cli, "ukrainian", "");
-    clichild = insertTreeWidget(cli, "uppersorbian", "");
-    clichild = insertTreeWidget(cli, "welsh", "");
-    clichild = insertTreeWidget(cli, "UKenglish", "");
-    clichild = insertTreeWidget(cli, "USenglish", "");
+    insertTreeWidget(cli, "acadian", "");
+    insertTreeWidget(cli, "afrikaans", "");
+    insertTreeWidget(cli, "american", "");
+    insertTreeWidget(cli, "australian", "");
+    insertTreeWidget(cli, "austrian", "");
+    insertTreeWidget(cli, "bahasa", "");
+    insertTreeWidget(cli, "basque", "");
+    insertTreeWidget(cli, "brazil", "");
+    insertTreeWidget(cli, "brazilian", "");
+    insertTreeWidget(cli, "breton", "");
+    insertTreeWidget(cli, "british", "");
+    insertTreeWidget(cli, "bulgarian", "");
+    insertTreeWidget(cli, "canadian", "");
+    insertTreeWidget(cli, "canadien", "");
+    insertTreeWidget(cli, "catalan", "");
+    insertTreeWidget(cli, "croatian", "");
+    insertTreeWidget(cli, "czech", "");
+    insertTreeWidget(cli, "danish", "");
+    insertTreeWidget(cli, "dutch", "");
+    insertTreeWidget(cli, "english", "");
+    insertTreeWidget(cli, "esperanto", "");
+    insertTreeWidget(cli, "estonian", "");
+    insertTreeWidget(cli, "finnish", "");
+    insertTreeWidget(cli, "francais", "");
+    insertTreeWidget(cli, "frenchb", "");
+    insertTreeWidget(cli, "french", "");
+    insertTreeWidget(cli, "galician", "");
+    insertTreeWidget(cli, "german", "");
+    insertTreeWidget(cli, "germanb", "");
+    insertTreeWidget(cli, "greek", "");
+    insertTreeWidget(cli, "polutonikogreek", "");
+    insertTreeWidget(cli, "hebrew", "");
+    insertTreeWidget(cli, "hungarian", "");
+    insertTreeWidget(cli, "icelandic", "");
+    insertTreeWidget(cli, "interlingua", "");
+    insertTreeWidget(cli, "irish", "");
+    insertTreeWidget(cli, "italian", "");
+    insertTreeWidget(cli, "latin", "");
+    insertTreeWidget(cli, "lowersorbian", "");
+    insertTreeWidget(cli, "magyar", "");
+    insertTreeWidget(cli, "naustrian", "");
+    insertTreeWidget(cli, "newzealand", "");
+    insertTreeWidget(cli, "ngerman", "");
+    insertTreeWidget(cli, "norsk", "");
+    insertTreeWidget(cli, "samin", "");
+    insertTreeWidget(cli, "nynorsk", "");
+    insertTreeWidget(cli, "polish", "");
+    insertTreeWidget(cli, "portuges", "");
+    insertTreeWidget(cli, "portuguese", "");
+    insertTreeWidget(cli, "romanian", "");
+    insertTreeWidget(cli, "russian", "");
+    insertTreeWidget(cli, "scottish", "");
+    insertTreeWidget(cli, "serbian", "");
+    insertTreeWidget(cli, "slovak", "");
+    insertTreeWidget(cli, "slovene", "");
+    insertTreeWidget(cli, "spanish", "");
+    insertTreeWidget(cli, "swedish", "");
+    insertTreeWidget(cli, "turkish", "");
+    insertTreeWidget(cli, "ukrainian", "");
+    insertTreeWidget(cli, "uppersorbian", "");
+    insertTreeWidget(cli, "welsh", "");
+    insertTreeWidget(cli, "UKenglish", "");
+    insertTreeWidget(cli, "USenglish", "");
 
     cli = insertTreeWidget(m_lvPackages, "fontenc", i18n("Use a font encoding scheme"));
     cli->setExpanded(true);
     cli->setCheckState(0, Qt::Checked);
-    clichild = insertTreeWidget(cli, "HE8", "");
-    clichild = insertTreeWidget(cli, "IL2", "");
-    clichild = insertTreeWidget(cli, "LCH", "");
-    clichild = insertTreeWidget(cli, "LCY", "");
-    clichild = insertTreeWidget(cli, "LGR", "");
-    clichild = insertTreeWidget(cli, "LHE", "");
-    clichild = insertTreeWidget(cli, "LIT", "");
-    clichild = insertTreeWidget(cli, "LO1", "");
-    clichild = insertTreeWidget(cli, "LY1", "");
-    clichild = insertTreeWidget(cli, "MTT", "");
-    clichild = insertTreeWidget(cli, "OML", "");
-    clichild = insertTreeWidget(cli, "OMS", "");
-    clichild = insertTreeWidget(cli, "OT1", "");
-    clichild = insertTreeWidget(cli, "OT2", "");
-    clichild = insertTreeWidget(cli, "OT4", "");
-    clichild = insertTreeWidget(cli, "PD1", "");
-    clichild = insertTreeWidget(cli, "PU", "");
-    clichild = insertTreeWidget(cli, "QX", "");
-    clichild = insertTreeWidget(cli, "T1", "");
-    clichild = insertTreeWidget(cli, "T2A", "");
-    clichild = insertTreeWidget(cli, "T2B", "");
-    clichild = insertTreeWidget(cli, "T2C", "");
-    clichild = insertTreeWidget(cli, "T5", "");
-    clichild = insertTreeWidget(cli, "TS1", "");
-    clichild = insertTreeWidget(cli, "UT1", "");
-    clichild = insertTreeWidget(cli, "X2", "");
+    insertTreeWidget(cli, "HE8", "");
+    insertTreeWidget(cli, "IL2", "");
+    insertTreeWidget(cli, "LCH", "");
+    insertTreeWidget(cli, "LCY", "");
+    insertTreeWidget(cli, "LGR", "");
+    insertTreeWidget(cli, "LHE", "");
+    insertTreeWidget(cli, "LIT", "");
+    insertTreeWidget(cli, "LO1", "");
+    insertTreeWidget(cli, "LY1", "");
+    insertTreeWidget(cli, "MTT", "");
+    insertTreeWidget(cli, "OML", "");
+    insertTreeWidget(cli, "OMS", "");
+    insertTreeWidget(cli, "OT1", "");
+    insertTreeWidget(cli, "OT2", "");
+    insertTreeWidget(cli, "OT4", "");
+    insertTreeWidget(cli, "PD1", "");
+    insertTreeWidget(cli, "PU", "");
+    insertTreeWidget(cli, "QX", "");
+    insertTreeWidget(cli, "T1", "");
+    insertTreeWidget(cli, "T2A", "");
+    insertTreeWidget(cli, "T2B", "");
+    insertTreeWidget(cli, "T2C", "");
+    insertTreeWidget(cli, "T5", "");
+    insertTreeWidget(cli, "TS1", "");
+    insertTreeWidget(cli, "UT1", "");
+    insertTreeWidget(cli, "X2", "");
 
     cli = insertTreeWidget(m_lvPackages, "graphicx", i18n("Support for including graphics"));
     cli->setExpanded(true);
     cli->setCheckState(0, Qt::Checked);
-    clichild = insertTreeWidget(cli, "dvips", i18n("Specialize on graphic inclusion for dvips"));
-    clichild = insertTreeWidget(cli, "pdftex", i18n("Specialize on graphic inclusion for pdftex"));
-    clichild = insertTreeWidget(cli, "draft", i18n("Show only frames of graphics"));
+    insertTreeWidget(cli, "dvips", i18n("Specialize on graphic inclusion for dvips"));
+    insertTreeWidget(cli, "pdftex", i18n("Specialize on graphic inclusion for pdftex"));
+    insertTreeWidget(cli, "draft", i18n("Show only frames of graphics"));
 }
 
 // Try to read values from the config file:
@@ -1213,8 +1212,8 @@ bool QuickDocument::readPackagesListview()
             QList<QTreeWidgetItem*> items = m_lvPackages->findItems((*it).left(pos), Qt::MatchExactly);
             if (items.count() > 0) {
                 item = items[0];
-                QTreeWidgetItem *clichild;
                 if (reg.exactMatch(configGroup.readEntry(*it))) {
+                    QTreeWidgetItem *clichild;
                     if (reg.cap(2) == "1") {                                       // editable state
                         clichild = insertEditableTreeWidget(item, (*it).mid(pos + 1), reg.cap(5), reg.cap(4), reg.cap(3));
                     } else {
@@ -2210,22 +2209,22 @@ QuickDocumentInputDialog::QuickDocumentInputDialog(const QStringList &list, int
             mainLayout->addWidget(combobox);
             combobox->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Minimum);
             combobox->setDuplicatesEnabled(false);
-            combobox->addItems(list[i+2].split(',', QString::KeepEmptyParts));
+            combobox->addItems(list[i+2].split(',', Qt::KeepEmptyParts));
             if (i > 0 && m_description[i-1] == "label") {
-                ((QLabel *)m_objectlist[i-1])->setBuddy(combobox);
+                static_cast<QLabel*>(m_objectlist[i-1])->setBuddy(combobox);
             }
             m_objectlist.append(combobox);
         }
         else {
             m_objectlist.append(new QLineEdit(list[i+2], page));
             if (m_description[i] == "edit-r") {
-                ((QLineEdit *)m_objectlist[i])->setReadOnly(true);
+                static_cast<QLineEdit*>(m_objectlist[i])->setReadOnly(true);
             }
             else if (firstlinedit == -1) {
                 firstlinedit = i;
             }
             if (i > 0 && m_description[i-1] == "label") {
-                ((QLabel *)m_objectlist[i-1])->setBuddy(m_objectlist[i]);
+                static_cast<QLabel*>(m_objectlist[i-1])->setBuddy(m_objectlist[i]);
             }
         }
 
@@ -2257,16 +2256,16 @@ void QuickDocumentInputDialog::getResults(QStringList &list)
 {
     for (int i = 0; i < m_description.count(); ++i) {
         if (m_description[i] == "label") {
-            list[i+2] = ((QLabel *)m_objectlist[i])->text();
+            list[i+2] = static_cast<QLabel*>(m_objectlist[i])->text();
         }
         else if (m_description[i] == "checkbox") {
-            list[i+2] = (((QCheckBox *)m_objectlist[i])->isChecked()) ? "true" : "false";
+            list[i+2] = static_cast<QCheckBox*>(m_objectlist[i])->isChecked() ? "true" : "false";
         }
         else if (m_description[i] == "combobox") {
-            list[i+2] = ((KComboBox *)m_objectlist[i])->currentText();
+            list[i+2] = static_cast<KComboBox*>(m_objectlist[i])->currentText();
         }
         else  {
-            list[i+2] = ((QLineEdit *)m_objectlist[i])->text().simplified();
+            list[i+2] = static_cast<QLineEdit*>(m_objectlist[i])->text().simplified();
         }
     }
 }
@@ -2301,8 +2300,8 @@ void QuickDocumentInputDialog::slotAccepted()
 {
     if (m_check) {
         // get the label and main input string from the first label/linedit
-        QString inputlabel = ((QLabel *)m_objectlist[0])->text();
-        QString input = ((QLineEdit *)m_objectlist[1])->text().simplified();
+        QString inputlabel = static_cast<QLabel*>(m_objectlist[0])->text();
+        QString input = static_cast<QLineEdit*>(m_objectlist[1])->text().simplified();
 
         // should we check for an empty string
         if ((m_check & qd_CheckNotEmpty) && input.isEmpty()) {
