@@ -40,7 +40,6 @@
 #include <QVBoxLayout>
 
 #include <KConfigGroup>
-#include <KIconLoader>
 #include <KLocalizedString>
 #include <KMessageBox>
 
@@ -209,7 +208,7 @@ NewTabularDialog::NewTabularDialog(const QString &environment, KileDocument::Lat
     connect(m_Table, &KileDialog::TabularTable::itemSelectionChanged, this, &NewTabularDialog::slotItemSelectionChanged);
     connect(m_Table, &KileDialog::TabularTable::rowAppended, this, &NewTabularDialog::slotRowAppended);
     connect(m_Table, &KileDialog::TabularTable::colAppended, this, &NewTabularDialog::slotColAppended);
-    connect(m_cmbName, static_cast<void (QComboBox::*)(const QString&)>(&QComboBox::activated), this, &NewTabularDialog::slotEnvironmentChanged);
+    connect(m_cmbName, static_cast<void (QComboBox::*)(const QString&)>(&QComboBox::textActivated), this, &NewTabularDialog::slotEnvironmentChanged);
     connect(m_sbCols, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &NewTabularDialog::updateColsAndRows);
     connect(m_sbRows, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &NewTabularDialog::updateColsAndRows);
     connect(m_Table->horizontalHeader(), &QHeaderView::customContextMenuRequested, this, &NewTabularDialog::slotHeaderCustomContextMenuRequested);
@@ -305,7 +304,8 @@ bool NewTabularDialog::checkForColumnAlignment(int column)
 QIcon NewTabularDialog::generateColorIcon(bool background) const
 {
     QString iconName = background ? "format-fill-color" : "format-stroke-color";
-    QPixmap pixmap = KIconLoader().loadIcon(iconName, KIconLoader::Toolbar);
+    const int iconSize = style()->pixelMetric(QStyle::PM_ToolBarIconSize);
+    QPixmap pixmap = QIcon::fromTheme(iconName).pixmap(iconSize);
 
     QPainter painter(&pixmap);
     QColor color = background ? m_clCurrentBackground : m_clCurrentForeground;
@@ -449,8 +449,7 @@ void NewTabularDialog::slotAccepted()
     }
 
     /* environment */
-    QString environment = m_cmbName->currentText();
-    QString environmentFormatted = environment;
+    QString environmentFormatted = m_cmbName->currentText();
     QString tableWidth;
     if(m_cbStarred->isEnabled() && m_cbStarred->isChecked()) {
         environmentFormatted += '*';
@@ -544,11 +543,7 @@ void NewTabularDialog::slotAccepted()
     }
 
     m_td.tagBegin += QString("\\begin{%1}%2%3%4%5\n")
-                     .arg(environmentFormatted)
-                     .arg(tableWidth)
-                     .arg(tableParameter)
-                     .arg(tableAlignment)
-                     .arg(topBorderStr);
+                     .arg(environmentFormatted, tableWidth, tableParameter, tableAlignment, topBorderStr);
 
     /* required packages */
     m_requiredPackages.clear();
@@ -656,7 +651,8 @@ void NewTabularDialog::updateColsAndRows()
         }
 
         if(hasContent) {
-            if(KMessageBox::questionYesNo(m_Table, i18n("Setting the new size for the table will delete content. Are you sure to set the new size?"), i18n("Resizing table")) == KMessageBox::No) {
+            if(KMessageBox::questionTwoActions(m_Table, i18n("Setting the new size for the table will delete content. Are you sure to set the new size?"), i18n("Resizing table"),
+                                               KStandardGuiItem::ok(), KStandardGuiItem::cancel()) == KMessageBox::SecondaryAction) {
                 m_sbCols->setValue(m_Table->columnCount());
                 return;
             }
@@ -677,7 +673,8 @@ void NewTabularDialog::updateColsAndRows()
         }
 
         if(hasContent) {
-            if(KMessageBox::questionYesNo(m_Table, i18n("Setting the new size for the table will delete content. Are you sure to set the new size?"), i18n("Resizing table")) == KMessageBox::No) {
+            if(KMessageBox::questionTwoActions(m_Table, i18n("Setting the new size for the table will delete content. Are you sure to set the new size?"), i18n("Resizing table"),
+                                               KStandardGuiItem::ok(), KStandardGuiItem::cancel()) == KMessageBox::SecondaryAction) {
                 m_sbRows->setValue(m_Table->rowCount());
                 return;
             }
