@@ -256,13 +256,13 @@ SelectFrameAction::SelectFrameAction(const QString &text, QToolBar *parent)
 
     QWidget *page = new QWidget(parent);
     QVBoxLayout *layout = new QVBoxLayout();
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
     layout->setSpacing(0);
     page->setLayout(layout);
 
     QWidget *buttonBox = new QWidget(page);
     QHBoxLayout *buttonBoxLayout = new QHBoxLayout();
-    buttonBoxLayout->setMargin(0);
+    buttonBoxLayout->setContentsMargins(0, 0, 0, 0);
     buttonBox->setLayout(buttonBoxLayout);
 
     m_pbNone = new QToolButton(buttonBox);
@@ -284,7 +284,7 @@ SelectFrameAction::SelectFrameAction(const QString &text, QToolBar *parent)
 
     QWidget *frameWidget = new QWidget(page);
     QHBoxLayout *frameWidgetLayout = new QHBoxLayout();
-    frameWidgetLayout->setMargin(0);
+    frameWidgetLayout->setContentsMargins(0, 0, 0, 0);
     frameWidget->setLayout(frameWidgetLayout);
 
     m_FrameWidget = new TabularFrameWidget(frameWidget);
@@ -341,7 +341,7 @@ QIcon SelectFrameAction::generateIcon()
 
 void SelectFrameAction::slotTriggered()
 {
-    emit borderSelected(m_CurrentBorder);
+    Q_EMIT borderSelected(m_CurrentBorder);
 }
 
 void SelectFrameAction::slotNoneClicked()
@@ -371,7 +371,7 @@ void SelectFrameAction::slotDoneClicked()
         m_CurrentBorder = newBorder;
         setIcon(generateIcon());
     }
-    emit borderSelected(newBorder);
+    Q_EMIT borderSelected(newBorder);
     menu()->hide();
 }
 
