@@ -20,7 +20,6 @@
 #include <QDomDocument>
 #include <QProcessEnvironment>
 
-#include <KIconLoader>
 #include <QMenu>
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -103,21 +102,10 @@ bool UserMenuTree::isEmpty()
 void UserMenuTree::initEnvPathlist()
 {
     QString envpath;
-#if QT_VERSION >= 0x040600
     QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
     if ( env.contains("PATH") ) {
         envpath = env.value("PATH");
     }
-#else
-    // Returns the environment of the calling process as a list of key=value pairs.
-    QStringList environment = QProcess::systemEnvironment();
-    foreach ( const QString &s, environment ) {
-        if ( s.startsWith(QLatin1String("PATH=")) ) {
-            envpath = s.mid(5);
-            break;
-        }
-    }
-#endif
 
 #ifdef Q_WS_WIN
     m_envPathlist = envpath.split(';');
@@ -305,12 +293,12 @@ UserMenuItem *UserMenuTree::readXmlSubmenu(const QDomElement &element)
 {
     UserMenuItem *submenuitem = new UserMenuItem(UserMenuData::Submenu, QString()) ;
 
-    QString title;
     if ( element.hasChildNodes() ) {
         QDomElement e = element.firstChildElement();
         while ( !e.isNull()) {
             UserMenuItem *item = Q_NULLPTR;
 
+            QString title;
             QString tag = e.tagName();
             if ( tag == "title" ) {
                 title = e.text();
@@ -346,21 +334,21 @@ UserMenuItem *UserMenuTree::readXmlMenuentry(const QDomElement &element)
 
     UserMenuItem *menuentryitem = new UserMenuItem(menutype, QString()) ;
 
-    // default values
-    QString title;
-    QString plaintext;
-    QString filename;
-    QString parameter;
-    QString icon;
-    QString shortcut;
-    bool needsSelection = false;
-    bool useContextMenu = false;
-    bool replaceSelection = false;
-    bool selectInsertion = false;
-    bool insertOutput = false;
-
-    // read values
     if ( element.hasChildNodes() ) {
+        // default values
+        QString title;
+        QString plaintext;
+        QString filename;
+        QString parameter;
+        QString icon;
+        QString shortcut;
+        bool needsSelection = false;
+        bool useContextMenu = false;
+        bool replaceSelection = false;
+        bool selectInsertion = false;
+        bool insertOutput = false;
+
+        // read values
         QDomElement e = element.firstChildElement();
         while ( !e.isNull()) {
             QString tag = e.tagName();
@@ -922,7 +910,9 @@ void UserMenuTree::itemDown()
 // delete the whole menutree
 void  UserMenuTree::deleteMenuTree()
 {
-    if ( KMessageBox::questionYesNo(this, i18n("Do you really want to clear the complete menutree?") ) == KMessageBox::Yes ) {
+    if ( KMessageBox::questionTwoActions(this, i18n("Do you really want to clear the complete menutree?"),
+                                         i18n("Clear menutree"),
+                                         KStandardGuiItem::clear(), KStandardGuiItem::cancel()) == KMessageBox::PrimaryAction) {
         blockSignals(true);
         clear();
         blockSignals(false);
