@@ -1,6 +1,6 @@
 /*************************************************************************************
     Copyright (C) 2003 by Jeroen Wijnhout (Jeroen.Wijnhout@kdemail.net)
-              (C) 2006-2019 by Michel Ludwig (michel.ludwig@kdemail.net)
+              (C) 2006-2022 by Michel Ludwig (michel.ludwig@kdemail.net)
  *************************************************************************************/
 
 /***************************************************************************
@@ -95,7 +95,8 @@ enum
 class KileStructData
 {
 public:
-    explicit KileStructData(int lvl = 0, int tp = KileStruct::None, QString px = QString(), QString fldr = "root" )  : level(lvl), type(tp), pix(px), folder(fldr) {}
+    explicit KileStructData(int lvl = 0, int tp = KileStruct::None, const QString &px = QString(), const QString &fldr = QStringLiteral("root"))
+        : level(lvl), type(tp), pix(px), folder(fldr) {}
     /** At which level the element should be visible **/
     int				level;
     /** The type of element (see @ref KileStruct) **/
@@ -206,7 +207,7 @@ public:
     /**
      * Returns a file filter suitable for loading and saving files of this class' type.
      **/
-    virtual QLinkedList<Extensions::ExtensionType> getFileFilter() const;
+    virtual std::vector<Extensions::ExtensionType> getFileFilter() const;
 
     virtual bool isDocumentTypePromotionAllowed();
     void setDocumentTypePromotionAllowed(bool b);
@@ -486,7 +487,7 @@ public:
 
     virtual Type getType() override;
 
-    virtual QLinkedList<Extensions::ExtensionType> getFileFilter() const override;
+    virtual std::vector<Extensions::ExtensionType> getFileFilter() const override;
 
     void startLaTeXCompletion(KTextEditor::View *view);
 
@@ -539,7 +540,7 @@ public:
 
     virtual Type getType() override;
 
-    virtual QLinkedList<Extensions::ExtensionType> getFileFilter() const override;
+    virtual std::vector<Extensions::ExtensionType> getFileFilter() const override;
 
     virtual void installParserOutput(KileParser::ParserOutput *parserOutput) override;
 
@@ -562,7 +563,7 @@ public:
 
     virtual Type getType() override;
 
-    virtual QLinkedList<Extensions::ExtensionType> getFileFilter() const override;
+    virtual std::vector<Extensions::ExtensionType> getFileFilter() const override;
 };
 
 }
