@@ -42,7 +42,7 @@ void Manager::addAction(const QString& seq, Action *action)
     if(m_actionMap.find(seq) == m_actionMap.end()) {
         m_actionMap[seq] = action;
         m_watchedKeySequencesList.push_back(seq);
-        emit watchedKeySequencesChanged();
+        Q_EMIT watchedKeySequencesChanged();
     }
 }
 
@@ -56,7 +56,7 @@ void Manager::removeKeySequence(const QString& seq)
         delete (it.value());
         m_actionMap.erase(it);
         m_watchedKeySequencesList.removeAll(seq);
-        emit watchedKeySequencesChanged();
+        Q_EMIT watchedKeySequencesChanged();
     }
 }
 
@@ -76,7 +76,7 @@ void Manager::removeKeySequence(const QStringList& l)
         }
     }
     if(changed) {
-        emit watchedKeySequencesChanged();
+        Q_EMIT watchedKeySequencesChanged();
     }
 }
 
@@ -93,7 +93,7 @@ void Manager::addActionMap(const QMap<QString, Action*>& map)
         }
     }
     if(changed) {
-        emit watchedKeySequencesChanged();
+        Q_EMIT watchedKeySequencesChanged();
     }
 }
 
@@ -126,7 +126,7 @@ void Manager::clear()
 {
     m_watchedKeySequencesList.clear();
     m_actionMap.clear();
-    emit watchedKeySequencesChanged();
+    Q_EMIT watchedKeySequencesChanged();
 }
 
 
@@ -146,15 +146,15 @@ bool Manager::isSequenceAssigned(const QString& seq) const {
 
 QPair<int, QString> Manager::checkSequence(const QString& seq, const QString& skip)
 {
-    for(QList<QString>::iterator i = m_watchedKeySequencesList.begin(); i != m_watchedKeySequencesList.end(); ++i) {
-        if((*i) == skip) {
+    for(QList<QString>::iterator iterator = m_watchedKeySequencesList.begin(); iterator != m_watchedKeySequencesList.end(); ++iterator) {
+        if (*iterator == skip) {
             continue;
         }
-        if((*i).startsWith(seq)) {
-            return (*i == seq) ? qMakePair<int, QString>(1, seq) : qMakePair<int, QString>(2, *i);
+        if(iterator->startsWith(seq)) {
+            return (*iterator == seq) ? std::pair<int, QString>(1, seq) : std::pair<int, QString>(2, *iterator);
         }
-        if(!(*i).isEmpty() && seq.startsWith(*i)) {
-            return qMakePair<int, QString>(3, *i);
+        if(!iterator->isEmpty() && seq.startsWith(*iterator)) {
+            return std::pair<int, QString>(3, *iterator);
         }
     }
     return qMakePair<int, QString>(0, QString());
@@ -178,7 +178,7 @@ Recorder::~Recorder()
 bool Recorder::eventFilter(QObject* /* o */, QEvent *e)
 {
     if (e->type() == QEvent::KeyPress) {
-        QKeyEvent *keyEvent = (QKeyEvent*)(e);
+        QKeyEvent *keyEvent = static_cast<QKeyEvent*>(e);
         int curLine, curCol;
         KTextEditor::Cursor cursor = m_view->cursorPosition();
         curLine = cursor.line();
@@ -207,7 +207,7 @@ bool Recorder::seekForKeySequence(const QString& s)
         if(m_watchedKeySequencesList.contains(toCheck)) {
             m_view->document()->removeText(KTextEditor::Range(m_oldLine, m_oldCol - (s.length() - i - 1), m_oldLine, m_oldCol));
             m_typedSequence.clear(); // clean m_typedSequence to avoid wrong action triggering if one presses keys without printable character
-            emit detectedTypedKeySequence(toCheck);
+            Q_EMIT detectedTypedKeySequence(toCheck);
             return true;
         }
     }
