@@ -1,7 +1,7 @@
 /***************************************************************************************
     begin                : sam jui 13 09:50:06 CEST 2002
     copyright            : (C) 2003 by Jeroen Wijnhout (wijnhout@science.uva.nl)
-                               2007-2018 by Michel Ludwig (michel.ludwig@kdemail.net)
+                               2007-2019 by Michel Ludwig (michel.ludwig@kdemail.net)
                            (C) 2009 Thomas Braun (thomas.braun@virtuell-zuhause.de)
 
  ***************************************************************************************/
@@ -117,7 +117,6 @@ public Q_SLOTS:
 
     void updateModeStatus();
     void newCaption();
-// 	void citeViewBib();
 
     void rebuildBibliographyMenu();
 
@@ -131,7 +130,7 @@ public Q_SLOTS:
     /**
      * @param line : Jump to give line in current editor (can be called via DBUS interface).
      **/
-    void setLine(const QString &line) override;
+    void setLine(const QString &line, const QString &startupId = {}) override;
     void openProject(const QString& proj);
     void runTool(const QString& tool);
     void runToolWithConfig(const QString &tool, const QString &config);
@@ -169,6 +168,7 @@ private:
     KToggleAction                  *ModeAction,
                                    *WatchFileAction;
     KToggleAction                  *m_actionMessageView;
+    KToggleAction                  *m_actionShowMenuBar;
     KRecentFilesAction             *m_actRecentFiles;
     KToggleFullScreenAction        *m_pFullScreen;
 
@@ -289,6 +289,9 @@ private:
     template<class ContextType, class Func>
     QAction* createAction(KStandardAction::StandardAction actionType, const QString &name, const ContextType* context, Func function);
 
+    template<class ContextType, class Func>
+    QAction* createAction(const QString &text, const QString &actionName, const QString& iconName, const QList<QKeySequence>& shortcut, const ContextType* context, Func function);
+
     void setMasterDocumentFileName(const QString& fileName);
     void clearMasterDocument();
 
@@ -297,12 +300,12 @@ private Q_SLOTS:
     void toggleWatchFile();
     void refreshStructure();
 
-    void helpLaTex();
-
     bool resetPart();
     void enableGUI(bool);
     void slotToggleFullScreen();
 
+    void toggleShowMenuBar(bool showMessage = true);
+
     void restoreFilesAndProjects(bool allowRestore);
     void readGUISettings();
     void transformOldUserSettings();
