@@ -76,6 +76,8 @@
 
 #define MAX_NUMBER_OF_STORED_SETTINGS 50
 
+using namespace Qt::Literals::StringLiterals;
+
 namespace KileDocument
 {
 
@@ -305,9 +307,9 @@ KileProjectItem* Manager::itemFor(const QUrl &url, KileProject *project /*=0L*/)
 {
     if (!project) {
         for(QList<KileProject*>::const_iterator it = m_projects.begin(); it != m_projects.end(); ++it) {
-            KileProject *project = *it;
+            KileProject *curProject = *it;
 
-            KileProjectItem *item = project->item(url);
+            KileProjectItem *item = curProject->item(url);
             if(item) {
                 return item;
             }
@@ -323,9 +325,9 @@ KileProjectItem* Manager::itemFor(TextInfo *docinfo, KileProject *project /*=0*/
 {
     if (!project) {
         for(QList<KileProject*>::const_iterator it = m_projects.begin(); it != m_projects.end(); ++it) {
-            KileProject *project = *it;
+            KileProject *curProject = *it;
 
-            KileProjectItem *item = project->item(docinfo);
+            KileProjectItem *item = curProject->item(docinfo);
             if(item) {
                 return item;
             }
@@ -419,13 +421,6 @@ TextInfo* Manager::createTextDocumentInfo(KileDocument::Type type, const QUrl &u
 
     if(!docinfo) {
         switch(type) {
-        case Undefined: // fall through
-        case Text:
-            KILE_DEBUG_MAIN << "CREATING TextInfo for " << url.url();
-            docinfo = new TextInfo(m_ki->extensions(),
-                                   m_ki->abbreviationManager(),
-                                   m_ki->parserManager());
-            break;
         case LaTeX:
             KILE_DEBUG_MAIN << "CREATING LaTeXInfo for " << url.url();
             docinfo = new LaTeXInfo(m_ki->extensions(),
@@ -451,9 +446,16 @@ TextInfo* Manager::createTextDocumentInfo(KileDocument::Type type, const QUrl &u
                                      m_ki->abbreviationManager(),
                                      m_ki->parserManager());
             break;
+        case Undefined: // fall through
+        case Text: // fall through
+        default:
+            KILE_DEBUG_MAIN << "CREATING TextInfo for " << url.url();
+            docinfo = new TextInfo(m_ki->extensions(),
+                                   m_ki->abbreviationManager(),
+                                   m_ki->parserManager());
         }
         docinfo->setBaseDirectory(baseDirectory);
-        emit(documentInfoCreated(docinfo));
+        Q_EMIT(documentInfoCreated(docinfo));
         m_textInfoList.append(docinfo);
     }
 
@@ -475,7 +477,7 @@ void Manager::recreateTextDocumentInfo(TextInfo *oldinfo)
 
     removeTextDocumentInfo(oldinfo);
 
-    emit(updateStructure(false, newinfo));
+    Q_EMIT(updateStructure(false, newinfo));
 }
 
 bool Manager::removeTextDocumentInfo(TextInfo *docinfo, bool closingproject /* = false */)
@@ -498,7 +500,7 @@ bool Manager::removeTextDocumentInfo(TextInfo *docinfo, bool closingproject /* =
 
         m_textInfoList.removeAll(docinfo);
 
-        emit(closingDocument(docinfo));
+        Q_EMIT(closingDocument(docinfo));
 
         cleanupDocumentInfoForProjectItems(docinfo);
         delete docinfo;
@@ -556,7 +558,7 @@ KTextEditor::Document* Manager::createDocument(const QUrl &url, TextInfo *docinf
         }
         // don't add scripts to the recent files
         if(r && docinfo->getType() != Script) {
-            emit(addToRecentFiles(url));
+            Q_EMIT(addToRecentFiles(url));
         }
     }
 
@@ -566,12 +568,8 @@ KTextEditor::Document* Manager::createDocument(const QUrl &url, TextInfo *docinf
     connect(doc, &KTextEditor::Document::readWriteChanged, this, &KileDocument::Manager::documentReadWriteStateChanged);
 
     connect(doc, &KTextEditor::Document::modifiedChanged, this, &KileDocument::Manager::newDocumentStatus);
-    KTextEditor::ModificationInterface *modificationInterface = qobject_cast<KTextEditor::ModificationInterface*>(doc);
-    if(modificationInterface) {
-        modificationInterface->setModifiedOnDiskWarning(true);
-        connect(doc, SIGNAL(modifiedOnDisk(KTextEditor::Document*,bool,KTextEditor::ModificationInterface::ModifiedOnDiskReason)),
-                this, SIGNAL(documentModificationStatusChanged(KTextEditor::Document*,bool,KTextEditor::ModificationInterface::ModifiedOnDiskReason)));
-    }
+    doc->setModifiedOnDiskWarning(true);
+    connect(doc, &KTextEditor::Document::modifiedOnDisk, this, &KileDocument::Manager::documentModificationStatusChanged);
 
     if(!mode.isEmpty()) {
         docinfo->setMode(mode);     // this ensures that mode passed with the mode parameter is actually used
@@ -710,16 +708,16 @@ KTextEditor::View* Manager::createDocumentWithText(const QString& text, KileDocu
 KTextEditor::View* Manager::createNewJScript()
 {
     KTextEditor::View *view = createDocumentWithText(QString(), Script, "js", QUrl::fromLocalFile(m_ki->scriptManager()->getLocalScriptDirectory()));
-    emit(updateStructure(false, Q_NULLPTR));
-    emit(updateModeStatus());
+    Q_EMIT(updateStructure(false, Q_NULLPTR));
+    Q_EMIT(updateModeStatus());
     return view;
 }
 
 KTextEditor::View* Manager::createNewLaTeXDocument()
 {
     KTextEditor::View *view = createDocumentWithText(QString(), LaTeX);
-    emit(updateStructure(false, Q_NULLPTR));
-    emit(updateModeStatus());
+    Q_EMIT(updateStructure(false, Q_NULLPTR));
+    Q_EMIT(updateModeStatus());
     return view;
 }
 
@@ -774,10 +772,10 @@ void Manager::fileNew(KileDocument::Type type)
         KTextEditor::View *view = loadTemplate(nfw->getSelection());
         if(view) {
             if(nfw->useWizard()) {
-                emit(startWizard());
+                Q_EMIT(startWizard());
             }
-            emit(updateStructure(false, Q_NULLPTR));
-            emit(updateModeStatus());
+            Q_EMIT(updateStructure(false, Q_NULLPTR));
+            Q_EMIT(updateModeStatus());
         }
     }
     delete nfw;
@@ -790,8 +788,14 @@ void Manager::fileNewScript()
 
 void Manager::fileNew(const QUrl &url)
 {
-    //create an empty file
     QFile file(url.toLocalFile());
+    
+    //create the directory structure first
+    QFileInfo fileInfo(file);
+    QDir dir = fileInfo.absolutePath();
+    dir.mkpath(".");
+    
+    //create an empty file
     file.open(QIODevice::ReadWrite);
     file.close();
 
@@ -803,7 +807,7 @@ void Manager::fileOpen()
     //determine the starting dir for the file dialog
     QString compileName = m_ki->getCompileName();
     QString currentDir;
-    if(QFileInfo(compileName).exists()) {
+    if(QFileInfo::exists(compileName)) {
         currentDir = QFileInfo(compileName).absolutePath();
     }
     else {
@@ -819,7 +823,7 @@ void Manager::fileOpen()
                                                           });
 
     // try to get the current encoding, this is kind of ugly ...
-    QString encoding = m_ki->toolManager()->config()->group("Kate Document Defaults").readEntry("Encoding","");
+    QString encoding = m_ki->toolManager()->config()->group(u"Kate Document Defaults"_s).readEntry("Encoding","");
 
     //get the URLs
     KEncodingFileDialog::Result result = KEncodingFileDialog::getOpenUrlsAndEncoding(encoding, QUrl::fromLocalFile(currentDir), filter, m_ki->mainWindow(), i18n("Open Files"));
@@ -863,7 +867,7 @@ void Manager::saveURL(const QUrl &url)
 
 void Manager::newDocumentStatus(KTextEditor::Document *doc)
 {
-    KILE_DEBUG_MAIN << "void Manager::newDocumentStatus(Kate::Document)" << endl;
+    KILE_DEBUG_MAIN << "void Manager::newDocumentStatus(Kate::Document)" << Qt::endl;
     if(!doc) {
         return;
     }
@@ -871,7 +875,7 @@ void Manager::newDocumentStatus(KTextEditor::Document *doc)
     // sync terminal
     m_ki->texKonsole()->sync();
 
-    emit(documentModificationStatusChanged(doc, doc->isModified(), KTextEditor::ModificationInterface::OnDiskUnmodified));
+    Q_EMIT(documentModificationStatusChanged(doc, doc->isModified(), KTextEditor::Document::OnDiskUnmodified));
 }
 
 bool Manager::fileSaveAll(bool disUntitled)
@@ -915,7 +919,7 @@ bool Manager::fileSaveAll(bool disUntitled)
      This may look superfluos but actually it is not, in the case of multiple modified docs it ensures that the structure view keeps synchronized with the currentTextView
      And if we only have one masterdoc or none nothing goes wrong.
     */
-    emit(updateStructure(false, Q_NULLPTR));
+    Q_EMIT(updateStructure(false, Q_NULLPTR));
     m_currentlySavingAll = false;
     return !oneSaveFailed;
 }
@@ -997,7 +1001,7 @@ TextInfo* Manager::fileOpen(const QUrl &url, const QString& encoding, int index)
     }
 
     if(itemList.isEmpty()) {
-        emit addToProjectView(realurl);
+        Q_EMIT addToProjectView(realurl);
         loadDocumentAndViewSettings(textInfo);
     }
     else if(view) {
@@ -1005,12 +1009,12 @@ TextInfo* Manager::fileOpen(const QUrl &url, const QString& encoding, int index)
         item->loadDocumentAndViewSettings();
     }
 
-    emit(updateStructure(false, Q_NULLPTR));
-    emit(updateModeStatus());
+    Q_EMIT(updateStructure(false, Q_NULLPTR));
+    Q_EMIT(updateModeStatus());
     // update undefined references in this file
-    emit(updateReferences(textInfoFor(realurl)));
+    Q_EMIT(updateReferences(textInfoFor(realurl)));
     m_currentlyOpeningFile = false;
-    emit documentOpened(textInfo);
+    Q_EMIT documentOpened(textInfo);
     return textInfo;
 }
 
@@ -1038,7 +1042,7 @@ bool Manager::fileSave(KTextEditor::View *view)
     }
     else {
         bool ret = view->document()->documentSave();
-        emit(updateStructure(false, textInfoFor(view->document())));
+        Q_EMIT(updateStructure(false, textInfoFor(view->document())));
         return ret;
     }
 }
@@ -1080,7 +1084,7 @@ bool Manager::fileSaveAs(KTextEditor::View* view)
 
     KILE_DEBUG_MAIN << "startUrl is " << startUrl;
     KEncodingFileDialog::Result result;
-    QUrl saveURL;
+    QUrl saveAsUrl;
     while(true) {
         QString filter = m_ki->extensions()->fileFilterKDEStyle(true, info->getFileFilter());
 
@@ -1088,37 +1092,37 @@ bool Manager::fileSaveAs(KTextEditor::View* view)
         if(result.URLs.isEmpty() || result.URLs.first().isEmpty()) {
             return false;
         }
-        saveURL = result.URLs.first();
+        saveAsUrl = result.URLs.first();
         if(info->getType() == KileDocument::LaTeX) {
-            saveURL = Info::makeValidTeXURL(saveURL, m_ki->mainWindow(),
-                                            m_ki->extensions()->isTexFile(saveURL), false); // don't check for file existence
+            saveAsUrl = Info::makeValidTeXURL(saveAsUrl, m_ki->mainWindow(),
+                                            m_ki->extensions()->isTexFile(saveAsUrl), false); // don't check for file existence
         }
 
-        if(!checkForFileOverwritePermission(saveURL)) {
+        if(!checkForFileOverwritePermission(saveAsUrl)) {
             continue;
         }
         break;
     }
     doc->setEncoding(result.encoding);
-    if(!doc->saveAs(saveURL)) {
+    if(!doc->saveAs(saveAsUrl)) {
         return false;
     }
-    if(oldURL != saveURL) {
+    if(oldURL != saveAsUrl) {
         if(info->isDocumentTypePromotionAllowed()) {
             recreateTextDocumentInfo(info);
             info = textInfoFor(doc);
         }
         m_ki->structureWidget()->updateUrl(info);
-        emit addToRecentFiles(saveURL);
-        emit addToProjectView(doc->url());
+        Q_EMIT addToRecentFiles(saveAsUrl);
+        Q_EMIT addToProjectView(doc->url());
     }
-    emit(documentSavedAs(view, info));
+    Q_EMIT(documentSavedAs(view, info));
     return true;
 }
 
 bool Manager::checkForFileOverwritePermission(const QUrl& url)
 {
-    auto statJob = KIO::stat(url, KIO::StatJob::SourceSide, 0);
+    auto statJob = KIO::stat(url, KIO::StatJob::SourceSide, KIO::StatNoDetails);
     KJobWidgets::setWindow(statJob, m_ki->mainWindow());
     if (statJob->exec()) { // check for writing possibility
         int r =  KMessageBox::warningContinueCancel(m_ki->mainWindow(), i18n("A file with the name \"%1\" exists already. Do you want to overwrite it?",
@@ -1272,8 +1276,8 @@ bool Manager::fileClose(KTextEditor::Document *doc /* = 0L*/, bool closingprojec
         m_ki->structureWidget()->clean(docinfo);
         removeTextDocumentInfo(docinfo, closingproject);
 
-        emit removeFromProjectView(url);
-        emit updateModeStatus();
+        Q_EMIT removeFromProjectView(url);
+        Q_EMIT updateModeStatus();
     }
     else {
         return false;
@@ -1345,15 +1349,15 @@ void Manager::projectNew()
                 //save the new file
                 //FIXME: this needs proper error handling
                 view->document()->saveAs(url);
-                emit(documentModificationStatusChanged(view->document(),
-                                                       false, KTextEditor::ModificationInterface::OnDiskUnmodified));
+                Q_EMIT(documentModificationStatusChanged(view->document(),
+                                                       false, KTextEditor::Document::OnDiskUnmodified));
 
                 //add this file to the project
                 item = new KileProjectItem(project, url);
                 item->setInfo(newTextInfo);
 
                 //docinfo->updateStruct(m_kwStructure->level());
-                emit(updateStructure(false, newTextInfo));
+                Q_EMIT(updateStructure(false, newTextInfo));
             }
 
             m_currentlyOpeningFile = false;
@@ -1363,11 +1367,11 @@ void Manager::projectNew()
         project->save();
         addProject(project);
 
-        emit(updateModeStatus());
-        emit(addToRecentProjects(project->url()));
+        Q_EMIT(updateModeStatus());
+        Q_EMIT(addToRecentProjects(project->url()));
 
         if(newTextInfo) {
-            emit documentOpened(newTextInfo);
+            Q_EMIT documentOpened(newTextInfo);
         }
     }
 }
@@ -1377,7 +1381,7 @@ void Manager::addProject(KileProject *project)
     KILE_DEBUG_MAIN << "==void Manager::addProject(const KileProject *project)==========";
     m_projects.append(project);
     KILE_DEBUG_MAIN << "\tnow " << m_projects.count() << " projects";
-    emit addToProjectView(project);
+    Q_EMIT addToProjectView(project);
     connect(project, SIGNAL(projectTreeChanged(const KileProject*)), this, SIGNAL(projectTreeChanged(const KileProject*)));
 }
 
@@ -1446,7 +1450,7 @@ void Manager::addToProject(KileProject* project, const QUrl &url)
     createTextInfoForProjectItem(item);
     item->setOpenState(m_ki->isOpen(realurl));
     projectOpenItem(item);
-    emit addToProjectView(item);
+    Q_EMIT addToProjectView(item);
     buildProjectTree(project);
 }
 
@@ -1460,7 +1464,7 @@ void Manager::removeFromProject(KileProjectItem *item)
             return;
         }
 
-        emit removeItemFromProjectView(item, m_ki->isOpen(item->url()));
+        Q_EMIT removeItemFromProjectView(item, m_ki->isOpen(item->url()));
 
         KileProject *project = item->project();
         project->remove(item);
@@ -1478,7 +1482,7 @@ void Manager::projectOpenItem(KileProjectItem *item, bool openProjectItemViews)
     KILE_DEBUG_MAIN << "\titem:" << item->url().toLocalFile();
 
     if (m_ki->isOpen(item->url())) { //remove item from projectview (this file was opened before as a normal file)
-        emit removeFromProjectView(item->url());
+        Q_EMIT removeFromProjectView(item->url());
     }
 
     KileDocument::TextInfo* itemInfo = item->getInfo();
@@ -1536,11 +1540,13 @@ void Manager::projectOpen(const QUrl &url, int step, int max, bool openProjectIt
             m_progressDialog->hide();
         }
 
-        if (KMessageBox::warningYesNo(m_ki->mainWindow(), i18n("<p>The project file for the project \"%1\" does not exist or it is not readable.</p>"
-                                      "<p>Do you want to remove this project from the recent projects list?</p>",
-                                      url.fileName()),
-                                      i18n("Could Not Open Project"))  == KMessageBox::Yes) {
-            emit(removeFromRecentProjects(realurl));
+        if (KMessageBox::warningTwoActions(m_ki->mainWindow(),
+                                           i18n("<p>The project file for the project \"%1\" does not exist or it is not readable.</p>"
+                                                "<p>Do you want to remove this project from the recent projects list?</p>",
+                                                url.fileName()),
+                                           i18n("Could Not Open Project"),
+                                           KStandardGuiItem::remove(), KStandardGuiItem::cancel()) == KMessageBox::PrimaryAction) {
+            Q_EMIT(removeFromRecentProjects(realurl));
         }
         return;
     }
@@ -1556,7 +1562,7 @@ void Manager::projectOpen(const QUrl &url, int step, int max, bool openProjectIt
             m_progressDialog->hide();
         }
 
-        KMessageBox::sorry(m_ki->mainWindow(), i18n("<p>The file \"%1\" cannot be opened as it does not appear to be a project file.</p>",
+        KMessageBox::error(m_ki->mainWindow(), i18n("<p>The file \"%1\" cannot be opened as it does not appear to be a project file.</p>",
                            url.fileName()),
                            i18n("Impossible to Open Project File"));
         delete kp;
@@ -1568,7 +1574,7 @@ void Manager::projectOpen(const QUrl &url, int step, int max, bool openProjectIt
             m_progressDialog->hide();
         }
 
-        KMessageBox::sorry(m_ki->mainWindow(), i18n("<p>The project \"%1\" cannot be opened as it was created <br/>by a newer version of Kile.</p>",
+        KMessageBox::error(m_ki->mainWindow(), i18n("<p>The project \"%1\" cannot be opened as it was created <br/>by a newer version of Kile.</p>",
                            url.fileName()),
                            i18n("Impossible to Open Project"));
         delete kp;
@@ -1580,19 +1586,21 @@ void Manager::projectOpen(const QUrl &url, int step, int max, bool openProjectIt
             m_progressDialog->hide();
         }
 
-        if(KMessageBox::questionYesNo(m_ki->mainWindow(), i18n("<p>The project file \"%1\" was created by a previous version of Kile.<br/>"
-                                      "It needs to be updated before it can be opened.</p>"
-                                      "<p>Do you want to update it?</p>", url.fileName()),
-                                      i18n("Project File Needs to be Updated"))  == KMessageBox::No) {
+        if(KMessageBox::questionTwoActions(m_ki->mainWindow(), i18n("<p>The project file \"%1\" was created by a previous version of Kile.<br/>"
+                                           "It needs to be updated before it can be opened.</p>"
+                                           "<p>Do you want to update it?</p>", url.fileName()),
+                                           i18n("Project File Needs to be Updated"),
+                                           KStandardGuiItem::ok(), KStandardGuiItem::cancel())  == KMessageBox::SecondaryAction) {
             delete kp;
             return;
         }
 
         if(!kp->migrateProjectFileToCurrentVersion()) {
-            if (KMessageBox::warningYesNo(m_ki->mainWindow(), i18n("<p>The project file \"%1\" could be not updated.</p>"
-                                          "<p>Do you want to remove this project from the recent projects list?</p>", url.fileName()),
-                                          i18n("Could Not Update Project File"))  == KMessageBox::Yes) {
-                emit(removeFromRecentProjects(realurl));
+            if (KMessageBox::warningTwoActions(m_ki->mainWindow(), i18n("<p>The project file \"%1\" could be not updated.</p>"
+                                               "<p>Do you want to remove this project from the recent projects list?</p>", url.fileName()),
+                                               i18n("Could Not Update Project File"),
+                                               KStandardGuiItem::remove(), KStandardGuiItem::cancel())  == KMessageBox::PrimaryAction) {
+                Q_EMIT(removeFromRecentProjects(realurl));
             }
             delete kp;
             return;
@@ -1611,7 +1619,7 @@ void Manager::projectOpen(const QUrl &url, int step, int max, bool openProjectIt
         return;
     }
 
-    emit(addToRecentProjects(realurl));
+    Q_EMIT(addToRecentProjects(realurl));
 
     QList<KileProjectItem*> list = kp->items();
     int project_steps = list.count();
@@ -1669,15 +1677,15 @@ void Manager::projectOpen(const QUrl &url, int step, int max, bool openProjectIt
 
     kp->buildProjectTree();
 
-    emit(updateStructure(false, Q_NULLPTR));
-    emit(updateModeStatus());
+    Q_EMIT(updateStructure(false, Q_NULLPTR));
+    Q_EMIT(updateModeStatus());
 
     // update undefined references in all project files
     updateProjectReferences(kp);
 
     m_ki->viewManager()->switchToTextView(kp->lastDocument());
 
-    emit(projectOpened(kp));
+    Q_EMIT(projectOpened(kp));
 }
 
 // as all labels are gathered in the project, we can check for unsolved references
@@ -1685,7 +1693,7 @@ void Manager::updateProjectReferences(KileProject *project)
 {
     QList<KileProjectItem*> list = project->items();
     for(QList<KileProjectItem*>::iterator it = list.begin(); it != list.end(); ++it) {
-        emit(updateReferences((*it)->getInfo()));
+        Q_EMIT(updateReferences((*it)->getInfo()));
     }
 }
 
@@ -1921,9 +1929,9 @@ bool Manager::projectClose(const QUrl &url)
 
         if (close) {
             m_projects.removeAll(project);
-            emit removeFromProjectView(project);
+            Q_EMIT removeFromProjectView(project);
             delete project;
-            emit(updateModeStatus());
+            Q_EMIT(updateModeStatus());
             return true;
         }
         else
@@ -2091,8 +2099,8 @@ void Manager::projectShow()
             // called from QAction 'Show projects...': find the first opened
             // LaTeX document or, if that fails, any other opened file
             QStringList extlist = (m_ki->extensions()->latexDocuments() + ' ' + m_ki->extensions()->latexPackages()).split(' ');
-            for(QStringList::Iterator it=extlist.begin(); it!=extlist.end(); ++it) {
-                if(itempath.indexOf( (*it), -(*it).length() ) >= 0)  {
+            for(QStringList::Iterator extIt = extlist.begin(); extIt != extlist.end(); ++extIt) {
+                if(itempath.indexOf( (*extIt), -(*extIt).length() ) >= 0)  {
                     if (m_ki->isOpen(item->url()))  {
                         docitem = item;
                         break;
@@ -2334,7 +2342,7 @@ void Manager::projectAddFile(QString filename, bool graphics)
         }
 
         filename += m_ki->extensions()->latexDocumentDefault();
-        if ( QFileInfo(filename).exists() ) {
+        if (QFileInfo::exists(filename)) {
             return;
         }
     }
@@ -2455,8 +2463,8 @@ void Manager::saveDocumentAndViewSettings(KileDocument::TextInfo *textInfo)
     if(urlList.length() > MAX_NUMBER_OF_STORED_SETTINGS) {
         int excessNumber = urlList.length() - MAX_NUMBER_OF_STORED_SETTINGS;
         for(; excessNumber > 0; --excessNumber) {
-            QUrl url = urlList.takeLast();
-            deleteDocumentAndViewSettingsGroups(url);
+            QUrl removeUrl = urlList.takeLast();
+            deleteDocumentAndViewSettingsGroups(removeUrl);
         }
     }
     configGroup.writeEntry("Documents", url);
@@ -2491,7 +2499,7 @@ void Manager::deleteDocumentAndViewSettingsGroups(const QUrl &url)
 {
     QString urlString = url.url();
     const QStringList groupList = KSharedConfig::openConfig()->groupList();
-    for(auto groupName : groupList) {
+    for (const auto& groupName : groupList) {
         if(!KSharedConfig::openConfig()->hasGroup(groupName)) { // 'groupName' might have been deleted
             continue;                                       // work around bug 384039
         }
@@ -2542,7 +2550,10 @@ QStringList Manager::loadTextURLContents(const QUrl &url, const QString& encodin
     QStringList res;
     QTextStream stream(&localFile);
     if(!encoding.isEmpty()) {
-        stream.setCodec(encoding.toLatin1());
+        auto enc = QStringConverter::encodingForName(encoding.toLatin1());
+        if (enc) {
+            stream.setEncoding(*enc);
+        }
     }
     while(!stream.atEnd()) {
         res.append(stream.readLine());
