@@ -104,7 +104,7 @@ KTextEditor::Document * KileInfo::activeTextDocument() const
 
 QString KileInfo::getName(KTextEditor::Document *doc, bool shrt) const
 {
-    KILE_DEBUG_MAIN << "===KileInfo::getName(KTextEditor::Document *doc, bool " << shrt << ")===" << endl;
+    KILE_DEBUG_MAIN << "===KileInfo::getName(KTextEditor::Document *doc, bool " << shrt << ")===" << Qt::endl;
     QString title;
 
     if (!doc) {
@@ -112,7 +112,7 @@ QString KileInfo::getName(KTextEditor::Document *doc, bool shrt) const
     }
     if (doc) {
         QUrl url = doc->url();
-        KILE_DEBUG_MAIN << "url " << url << endl;
+        KILE_DEBUG_MAIN << "url " << url << Qt::endl;
         if(url.isLocalFile()) {
             title = shrt ? doc->url().fileName() : doc->url().toLocalFile();
         }
@@ -168,7 +168,7 @@ QString KileInfo::getCompileName(bool shrt /* = false */, LaTeXOutputHandler** h
 QString KileInfo::getCompileNameForProject(KileProject *project, bool shrt) const
 {
     if (!project->masterDocument().isEmpty()) {
-        QUrl master(project->masterDocument());
+        QUrl master = QUrl::fromLocalFile(project->masterDocument());
         if(shrt) {
             return master.fileName();
         }
@@ -216,10 +216,10 @@ QString KileInfo::getFullFromPrettyName(const OutputInfo& info, const QString& n
         bool found = false;
         QStringList extlist = (m_extensions->latexDocuments()).split(' ');
         for(QStringList::Iterator it=extlist.begin(); it!=extlist.end(); ++it) {
-            QString name = file + (*it);
-            if(QFileInfo(name).exists()) {
-                file = name;
-                fi.setFile(name);
+            QString extName = file + (*it);
+            if(QFileInfo::exists(extName)) {
+                file = extName;
+                fi.setFile(extName);
                 found = true;
                 break;
             }
@@ -268,9 +268,9 @@ QStringList KileInfo::retrieveList(QStringList (KileDocument::Info::*getit)() co
 
             QStringList toReturn;
             for(QList<KileProjectItem*>::iterator it = children.begin(); it != children.end(); ++it) {
-                const KileProjectItem *item = *it;
-                KileDocument::TextInfo *textInfo = item->getInfo();
-                KILE_DEBUG_MAIN << "\t" << item->url();
+                const KileProjectItem *childItem = *it;
+                KileDocument::TextInfo *textInfo = childItem->getInfo();
+                KILE_DEBUG_MAIN << "\t" << childItem->url();
 
                 if(textInfo) {
                     toReturn << (textInfo->*getit)();
@@ -292,43 +292,43 @@ QStringList KileInfo::retrieveList(QStringList (KileDocument::Info::*getit)() co
 
 QStringList KileInfo::allLabels(KileDocument::TextInfo *info)
 {
-    KILE_DEBUG_MAIN << "Kile::allLabels()" << endl;
+    KILE_DEBUG_MAIN << "Kile::allLabels()" << Qt::endl;
     return retrieveList(&KileDocument::Info::labels, info);
 }
 
 QStringList KileInfo::allBibItems(KileDocument::TextInfo *info)
 {
-    KILE_DEBUG_MAIN << "Kile::allBibItems()" << endl;
+    KILE_DEBUG_MAIN << "Kile::allBibItems()" << Qt::endl;
     return retrieveList(&KileDocument::Info::bibItems, info);
 }
 
 QStringList KileInfo::allBibliographies(KileDocument::TextInfo *info)
 {
-    KILE_DEBUG_MAIN << "Kile::bibliographies()" << endl;
+    KILE_DEBUG_MAIN << "Kile::bibliographies()" << Qt::endl;
     return retrieveList(&KileDocument::Info::bibliographies, info);
 }
 
 QStringList KileInfo::allDependencies(KileDocument::TextInfo *info)
 {
-    KILE_DEBUG_MAIN << "Kile::dependencies()" << endl;
+    KILE_DEBUG_MAIN << "Kile::dependencies()" << Qt::endl;
     return retrieveList(&KileDocument::Info::dependencies, info);
 }
 
 QStringList KileInfo::allNewCommands(KileDocument::TextInfo *info)
 {
-    KILE_DEBUG_MAIN << "Kile::newCommands()" << endl;
+    KILE_DEBUG_MAIN << "Kile::newCommands()" << Qt::endl;
     return retrieveList(&KileDocument::Info::newCommands, info);
 }
 
 QStringList KileInfo::allAsyFigures(KileDocument::TextInfo *info)
 {
-    KILE_DEBUG_MAIN << "Kile::asyFigures()" << endl;
+    KILE_DEBUG_MAIN << "Kile::asyFigures()" << Qt::endl;
     return retrieveList(&KileDocument::Info::asyFigures, info);
 }
 
 QStringList KileInfo::allPackages(KileDocument::TextInfo *info)
 {
-    KILE_DEBUG_MAIN << "Kile::allPackages()" << endl;
+    KILE_DEBUG_MAIN << "Kile::allPackages()" << Qt::endl;
     return retrieveList(&KileDocument::Info::packages, info);
 }
 
@@ -375,7 +375,7 @@ bool KileInfo::similarOrEqualURL(const QUrl &validurl, const QUrl &testurl)
 
 bool KileInfo::isOpen(const QUrl &url)
 {
-    KILE_DEBUG_MAIN << "==bool KileInfo::isOpen(const QUrl &url)=============" << endl;
+    KILE_DEBUG_MAIN << "==bool KileInfo::isOpen(const QUrl &url)=============" << Qt::endl;
 
     for (int i = 0; i < viewManager()->textViewCount(); ++i) {
         KTextEditor::View *view = viewManager()->textView(i);
@@ -417,18 +417,21 @@ void KileInfo::clearSelection() const
 
 QString KileInfo::expandEnvironmentVars(const QString &str)
 {
-    static QRegExp reEnvVars("\\$(\\w+)");
+    static QRegularExpression reEnvVars("\\$(\\w+)");
     QString result = str;
-    int index = -1;
-    while ( (index = str.indexOf(reEnvVars, index + 1)) != -1 )
-        result.replace(reEnvVars.cap(0),qgetenv(reEnvVars.cap(1).toLocal8Bit()));
+    auto matches = reEnvVars.globalMatch(str);
+    while (matches.hasNext()) {
+        const auto match = matches.next();
+
+        result.replace(match.captured(0), qgetenv(match.captured(1).toLocal8Bit()));
+    }
 
     return result;
 }
 
 QString KileInfo::checkOtherPaths(const QString &path,const QString &file, int type)
 {
-    KILE_DEBUG_MAIN << "QString KileInfo::checkOtherPaths(const QString &path,const QString &file, int type)" << endl;
+    KILE_DEBUG_MAIN << "QString KileInfo::checkOtherPaths(const QString &path,const QString &file, int type)" << Qt::endl;
     QStringList inputpaths;
     QString configpaths;
     QFileInfo info;
@@ -445,7 +448,7 @@ QString KileInfo::checkOtherPaths(const QString &path,const QString &file, int t
         configpaths = KileConfig::bstInputPaths() + LIST_SEPARATOR + "$BSTINPUTS";
         break;
     default:
-        KILE_DEBUG_MAIN << "Unknown type in checkOtherPaths" << endl;
+        KILE_DEBUG_MAIN << "Unknown type in checkOtherPaths" << Qt::endl;
         return QString();
         break;
     }
@@ -455,10 +458,10 @@ QString KileInfo::checkOtherPaths(const QString &path,const QString &file, int t
 
     // the first match is supposed to be the correct one
     foreach(const QString &string, inputpaths) {
-        KILE_DEBUG_MAIN << "path is " << string << "and file is " << file << endl;
+        KILE_DEBUG_MAIN << "path is " << string << "and file is " << file << Qt::endl;
         info.setFile(string + '/' + file);
         if(info.exists()) {
-            KILE_DEBUG_MAIN << "filepath after correction is: " << info.path() << endl;
+            KILE_DEBUG_MAIN << "filepath after correction is: " << info.path() << Qt::endl;
             return info.absoluteFilePath();
         }
     }
