@@ -1,6 +1,6 @@
 /****************************************************************************************
     Copyright (C) 2003 by Jeroen Wijnhout (Jeroen.Wijnhout@kdemail.net)
-                  2008-2018 by Michel Ludwig (michel.ludwig@kdemail.net)
+                  2008-2024 by Michel Ludwig (michel.ludwig@kdemail.net)
  ****************************************************************************************/
 
 /***************************************************************************
@@ -16,7 +16,6 @@
 
 #include <config.h>
 
-#include "docpart.h"
 #include "kileconfig.h"
 #include "kileinfo.h"
 #include "kiletool.h"
@@ -29,11 +28,9 @@
 #include <QFileInfo>
 
 #include "kiledebug.h"
-#include <KRun>
+#include <KIO/DesktopExecParser>
 #include <KProcess>
 #include <KLocalizedString>
-#include <KPluginFactory>
-#include <KPluginLoader>
 #include <KShell>
 
 #include <KParts/Part>
@@ -61,9 +58,9 @@ ProcessLauncher::ProcessLauncher() :
     m_proc->setOutputChannelMode(KProcess::MergedChannels);
     m_proc->setReadChannel(QProcess::StandardOutput);
 
-    connect(m_proc, SIGNAL(readyReadStandardOutput()), this, SLOT(slotProcessOutput()));
-    connect(m_proc, SIGNAL(finished(int,QProcess::ExitStatus)), this, SLOT(slotProcessExited(int,QProcess::ExitStatus)));
-    connect(m_proc, SIGNAL(error(QProcess::ProcessError)), this, SLOT(slotProcessError(QProcess::ProcessError)));
+    connect(m_proc, &KProcess::readyReadStandardOutput, this, &ProcessLauncher::slotProcessOutput);
+    connect(m_proc, &KProcess::finished, this, &ProcessLauncher::slotProcessExited);
+    connect(m_proc, &KProcess::errorOccurred, this, &ProcessLauncher::slotProcessError);
 }
 
 ProcessLauncher::~ProcessLauncher()
@@ -128,7 +125,6 @@ bool ProcessLauncher::launch()
         out += QString("*****     cd \"") + m_wd + QString("\"\n");
     }
 
-    QString str;
     tool()->translate(m_cmd);
     tool()->translate(m_options, true); // quote the substituted strings using 'KShell::quoteArg'
     // (see bug 314109)
@@ -166,7 +162,7 @@ bool ProcessLauncher::launch()
 
     msg += " (" + m_cmd + ')';
 
-    emit(message(Info, msg));
+    Q_EMIT(message(Info, msg));
 
     QString teXInputPaths = tool()->teXInputPaths();
     QString bibInputPaths = tool()->bibInputPaths();
@@ -197,7 +193,7 @@ bool ProcessLauncher::launch()
     }
 
     out += "*****\n";
-    emit(output(out));
+    Q_EMIT(output(out));
 
     if(tool()->manager()->shouldBlock()) {
         KILE_DEBUG_MAIN << "About to execute: " << m_proc->program();
@@ -221,8 +217,8 @@ void ProcessLauncher::kill(bool emitSignals)
     else {
         KILE_DEBUG_MAIN << "\tno process or process not running";
         if(emitSignals) {
-            emit(message(Error, i18n("terminated")));
-            emit(done(AbnormalExit));
+            Q_EMIT(message(Error, i18n("terminated")));
+            Q_EMIT(done(AbnormalExit));
         }
     }
 }
@@ -230,43 +226,43 @@ void ProcessLauncher::kill(bool emitSignals)
 // FIXME: this should be done in the 'launch()' method itself
 bool ProcessLauncher::selfCheck()
 {
-    emit(message(Error, i18n("Launching failed, diagnostics:")));
+    Q_EMIT(message(Error, i18n("Launching failed, diagnostics:")));
 
     KShell::Errors err;
     QStringList arguments = KShell::splitArgs(m_options, KShell::AbortOnMeta | KShell::TildeExpand, &err);
     if(err == KShell::BadQuoting) {
-        emit(message(Error, i18n("An error occurred while parsing the options given to the tool.")));
+        Q_EMIT(message(Error, i18n("An error occurred while parsing the options given to the tool.")));
         return false;
     }
     else if(err == KShell::FoundMeta) {
-        emit(message(Error, i18n("Shell meta characters that cannot be handled are present in the options given to the tool.")));
+        Q_EMIT(message(Error, i18n("Shell meta characters that cannot be handled are present in the options given to the tool.")));
         return false;
     }
 
 
-    QString exe = KRun::binaryName(tool()->readEntry("command"), false);
+    QString exe = KIO::DesktopExecParser::executablePath(tool()->readEntry("command"));
     QString path = QStandardPaths::findExecutable(exe);
 
     if(path.isEmpty()) {
-        emit(message(Error, i18n("There is no executable named \"%1\" in your path.", exe)));
+        Q_EMIT(message(Error, i18n("There is no executable named \"%1\" in your path.", exe)));
         return false;
     }
     else {
         QFileInfo fi(path);
         if(!fi.isExecutable()) {
-            emit(message(Error, i18n("You do not have permission to run %1.", path)));
+            Q_EMIT(message(Error, i18n("You do not have permission to run %1.", path)));
             return false;
         }
     }
 
-    emit(message(Info, i18n("Diagnostics could not find any obvious problems.")));
+    Q_EMIT(message(Info, i18n("Diagnostics could not find any obvious problems.")));
     return true;
 }
 
 void ProcessLauncher::slotProcessOutput()
 {
     QByteArray buf = m_proc->readAllStandardOutput();
-    emit output(QString::fromLocal8Bit(buf, buf.size()));
+    Q_EMIT output(QString::fromLocal8Bit(buf, buf.size()));
 }
 
 void ProcessLauncher::slotProcessExited(int exitCode, QProcess::ExitStatus exitStatus)
@@ -280,25 +276,25 @@ void ProcessLauncher::slotProcessExited(int exitCode, QProcess::ExitStatus exitS
             int type = Info;
             if(exitCode != 0) {
                 type = Error;
-                emit(message(type, i18n("finished with exit code %1", exitCode)));
+                Q_EMIT(message(type, i18n("finished with exit code %1", exitCode)));
             }
 
             if (type == Info) {
-                emit(done(Success));
+                Q_EMIT(done(Success));
             }
             else {
-                emit(done(Failed));
+                Q_EMIT(done(Failed));
             }
         }
         else {
             KILE_DEBUG_MAIN << "\tabnormal exit";
-            emit(message(Error, i18n("finished abruptly")));
-            emit(done(AbnormalExit));
+            Q_EMIT(message(Error, i18n("finished abruptly")));
+            Q_EMIT(done(AbnormalExit));
         }
     }
     else {
         qWarning() << "\tNO PROCESS, emitting done";
-        emit(done(Success));
+        Q_EMIT(done(Success));
     }
 }
 
@@ -317,8 +313,8 @@ void ProcessLauncher::slotProcessError(QProcess::ProcessError error)
         errorString = i18n("failed (error code %1)", error);
         break;
     }
-    emit(message(Error, errorString));
-    emit(done(AbnormalExit));
+    Q_EMIT(message(Error, errorString));
+    Q_EMIT(done(AbnormalExit));
 }
 
 KonsoleLauncher::KonsoleLauncher() : ProcessLauncher()
@@ -331,7 +327,7 @@ bool KonsoleLauncher::launch()
     QString noclose = (tool()->readEntry("close") == "no") ? "--noclose" : "";
     setCommand("konsole");
     setOptions(noclose + " -e " + cmd + ' ' + tool()->readEntry("options"));
-    if(QStandardPaths::findExecutable(KRun::binaryName(cmd, false)).isEmpty()) {
+    if(QStandardPaths::findExecutable(KIO::DesktopExecParser::executablePath(cmd)).isEmpty()) {
         return false;
     }
 
@@ -355,11 +351,11 @@ bool DocumentViewerLauncher::selfCheck()
 bool DocumentViewerLauncher::launch()
 {
     if(!tool()->manager()->viewManager()->viewerPart()) {
-        emit(message(Error, i18n("The document viewer is not available")));
+        Q_EMIT(message(Error, i18n("The document viewer is not available")));
         return false;
     }
     if(tool()->manager()->livePreviewManager() && tool()->manager()->livePreviewManager()->isLivePreviewActive()) {
-        emit(message(Error, i18n("Please disable the live preview before launching this tool")));
+        Q_EMIT(message(Error, i18n("Please disable the live preview before launching this tool")));
         return false;
     }
     const QString fileName = tool()->paramDict()["%dir_target"] + '/' + tool()->paramDict()["%target"];
@@ -370,7 +366,7 @@ bool DocumentViewerLauncher::launch()
         const QString lineString = tool()->paramDict()["%sourceLine"];
         tool()->manager()->viewManager()->showSourceLocationInDocumentViewer(sourceFileName, lineString.toInt(), 0);
     }
-    emit(done(Success));
+    Q_EMIT(done(Success));
 
     return true;
 }
