@@ -32,7 +32,7 @@
 #include <QFile>
 #include <QFileInfo>
 #include <QSocketNotifier>
-#include <QRegExp>
+#include <QRegularExpression>
 
 #include <KLocalizedString>
 
@@ -48,7 +48,7 @@ KileLyxServer::KileLyxServer(bool startMe) :
 
     m_tempDir = new QTemporaryDir();
     if(!m_tempDir->isValid()) {
-        KILE_DEBUG_MAIN << "an error ocurred while creating a tempfile" ;
+        KILE_DEBUG_MAIN << "an error occurred while creating a tempfile" ;
         return;
     }
 
@@ -116,7 +116,7 @@ bool KileLyxServer::openPipes()
 
 #ifdef Q_OS_WIN
     qCritical() << "kile's lyx server can not work on windows since we don't have pipes";
-    qCritical() << "And also lyx itself does not support it, see  http://wiki.lyx.org/LyX/LyXServer";
+    qCritical() << "And also lyx itself does not support it, see  https://wiki.lyx.org/LyX/LyXServer";
     return false;
 #else
     bool opened = false;
@@ -143,12 +143,12 @@ bool KileLyxServer::openPipes()
         QFile::remove(linkInfo.absoluteFilePath());
         linkInfo.refresh();
 
-        KILE_DEBUG_MAIN << "pipe=" << m_pipes[i] << endl;
-        KILE_DEBUG_MAIN << "link=" << m_links[i] << endl;
+        KILE_DEBUG_MAIN << "pipe=" << m_pipes[i] << Qt::endl;
+        KILE_DEBUG_MAIN << "link=" << m_links[i] << Qt::endl;
 
         if(!pipeInfo.exists()) {
             //create the dir first
-            if(!QFileInfo(pipeInfo.absolutePath()).exists()) {
+            if(!QFileInfo::exists(pipeInfo.absolutePath())) {
                 if(mkdir(QFile::encodeName( pipeInfo.path() ), m_perms | S_IXUSR) == -1) {
                     qCritical() << "Could not create directory for pipe";
                     continue;
@@ -188,7 +188,7 @@ bool KileLyxServer::openPipes()
                 m_pipeIn.append(file);
                 m_file.insert(file->handle(), file);
                 opened = true;
-                KILE_DEBUG_MAIN << "everything is correct :)" << endl;
+                KILE_DEBUG_MAIN << "everything is correct :)" << Qt::endl;
             }
         }
         else {
@@ -232,18 +232,24 @@ void KileLyxServer::processLine(const QString &line)
 {
     KILE_DEBUG_MAIN << "===void KileLyxServer::processLine(const QString " << line << ")===";
 
-    QRegExp reCite(":citation-insert:(.*)$");
-    QRegExp reBibtexdbadd(":bibtex-database-add:(.*)$");
-    QRegExp rePaste(":paste:(.*)$");
+    static QRegularExpression reCite(":citation-insert:(.*)$");
+    static QRegularExpression reBibtexdbadd(":bibtex-database-add:(.*)$");
+    static QRegularExpression rePaste(":paste:(.*)$");
 
-    if(line.indexOf(reCite) != -1) {
-        emit(insert(KileAction::TagData(i18n("Cite"), "\\cite{"+reCite.cap(1)+'}')));
+    auto match = reCite.match(line);
+    if(match.hasMatch()) {
+        Q_EMIT(insert(KileAction::TagData(i18n("Cite"), "\\cite{"+match.captured(1)+'}')));
+        return;
     }
-    else if(line.indexOf(reBibtexdbadd) != -1) {
-        emit(insert(KileAction::TagData(i18n("Add BibTeX database"), "\\bibliography{"+ reBibtexdbadd.cap(1) + '}')));
+
+    match = reBibtexdbadd.match(line);
+    if(match.hasMatch()) {
+        Q_EMIT(insert(KileAction::TagData(i18n("Add BibTeX database"), "\\bibliography{"+ match.captured(1) + '}')));
     }
-    else if(line.indexOf(rePaste) != -1) {
-        emit(insert(KileAction::TagData(i18n("Paste"), rePaste.cap(1))));
+
+    match = rePaste.match(line);
+    if (match.hasMatch()) {
+        Q_EMIT(insert(KileAction::TagData(i18n("Paste"), match.captured(1))));
     }
 }
 
