@@ -17,6 +17,7 @@
 
 #include <QFileInfo>
 #include <QRegExp>
+#include <QRegularExpression>
 
 #include <QAction>
 #include <KActionCollection>
@@ -126,14 +127,14 @@ void Factory::resetToolConfigurations()
     m_config->deleteGroup(QLatin1String("ToolsGUI"));
 
     // we delete all the groups whose names start with "Tool/";
-    for(QString groupName : m_config->groupList()) {
+    for (const QString& groupName : m_config->groupList()) {
         if(groupName.startsWith(QLatin1String("Tool/"))) {
             m_config->deleteGroup(groupName);
         }
     }
 
     // now we copy all the "Tool/" groups, the "Tools", and "ToolsGUI" groups over
-    for(QString groupName : stdToolConfig.groupList()) {
+    for (const QString& groupName : stdToolConfig.groupList()) {
         if(groupName != SHORTCUTS_GROUP_NAME) {
             KConfigGroup configGroup = stdToolConfig.group(groupName);
             m_config->deleteGroup(groupName);
@@ -146,7 +147,7 @@ void Factory::resetToolConfigurations()
 static void transferKeyStringPairsStartingWith(KConfigGroup& src, KConfigGroup& target, const QString& startsWith)
 {
     const QStringList keyList = src.keyList();
-    for(QString key : keyList) {
+    for (const QString& key : keyList) {
         if(key.startsWith(startsWith)) {
             QString value = src.readEntry(key, QString());
             target.writeEntry(key, value);
@@ -159,7 +160,7 @@ void Factory::installStandardLivePreviewTools()
     KConfig stdToolConfig(m_standardToolConfigurationFileName, KConfig::NoGlobals);
 
     const QStringList groupList = stdToolConfig.groupList();
-    for(QString groupName : groupList) {
+    for (const QString& groupName : groupList) {
         if(groupName.startsWith(QStringLiteral("Tool/LivePreview"))) {
             KConfigGroup configGroup = stdToolConfig.group(groupName);
             m_config->deleteGroup(groupName);
@@ -334,7 +335,7 @@ void LaTeX::checqCriticals()
     // jump to first error
     if(!isPartOfLivePreview() && m_nErrors > 0 && (readEntry("jumpToFirstError") == "yes")) {
         connect(this, SIGNAL(jumpToFirstError()), manager(), SIGNAL(jumpToFirstError()));
-        emit(jumpToFirstError());
+        Q_EMIT(jumpToFirstError());
     }
 }
 
@@ -517,8 +518,8 @@ void LaTeX::checkAutoRun()
     if(index) {
         KILE_DEBUG_MAIN << "need to run MakeIndex";
         Base *tool = manager()->createTool("MakeIndex", QString());
-        KILE_DEBUG_MAIN << targetDir() << S() << tool->from();
         if(tool) {
+            KILE_DEBUG_MAIN << targetDir() << S() << tool->from();
             configureMakeIndex(tool, targetDir() + '/' + S() + '.' + tool->from());
             // e.g. for LivePreview, it is necessary that the paths are copied to child processes
             tool->copyPaths(this);
@@ -641,14 +642,14 @@ bool ForwardDVI::checkPrereqs ()
 
     if (okularVersionTester.waitForFinished()) {
         QString output = okularVersionTester.readAll();
-        QRegExp regExp = QRegExp("Okular: (\\d+).(\\d+).(\\d+)");
-
+        static const QRegularExpression regExp("Okular: (\\d+).(\\d+).(\\d+)");
+        const auto match = regExp.match(output);
         if(output.contains(regExp)) {
-            int majorVersion = regExp.cap(1).toInt();
-            int minorVersion = regExp.cap(2).toInt();
-            int veryMinorVersion = regExp.cap(3).toInt();
+            int majorVersion = match.captured(1).toInt();
+            int minorVersion = match.captured(2).toInt();
+            int veryMinorVersion = match.captured(3).toInt();
 
-            //  see http://mail.kde.org/pipermail/okular-devel/2009-May/003741.html
+            //  see https://mail.kde.org/pipermail/okular-devel/2009-May/003741.html
             // 	the required okular version is > 0.8.5
             if(  majorVersion > 0  ||
                     ( majorVersion == 0 && minorVersion > 8 ) ||
@@ -773,8 +774,8 @@ bool ViewHTML::determineTarget()
 
         //auto-detect the file to view
         if(dir.isEmpty() && trg.isEmpty()) {
-            QFileInfo file1 = QFileInfo(baseDir() + '/' + S() + "/index.html");
-            QFileInfo file2 = QFileInfo(baseDir() + '/' + S() + ".html");
+            QFileInfo file1 = QFileInfo(baseDir() + '/' + S() + QLatin1String("/index.html"));
+            QFileInfo file2 = QFileInfo(baseDir() + '/' + S() + QLatin1String(".html"));
 
             bool read1 = file1.isReadable();
             bool read2 = file2.isReadable();
@@ -793,12 +794,17 @@ bool ViewHTML::determineTarget()
             if(read1) {
                 dir = S();
                 trg = "index.html";
-
-                translate(dir);
-                setRelativeBaseDir(dir);
-                translate(trg);
-                setTarget(trg);
             }
+            else if(read2) {
+                dir = QLatin1String(".");
+                trg = S() + QLatin1String(".html");
+            }
+
+            translate(dir);
+            setRelativeBaseDir(dir);
+            translate(trg);
+            setTarget(trg);
+
         }
     }
 
