@@ -1,6 +1,6 @@
 /***************************************************************************
   Copyright (C) 2003 by Jeroen Wijnhout (jeroen.wijnhout@kdemail.net)
-                2010-2014 by Michel Ludwig (michel.ludwig@kdemail.net)
+                2010-2022 by Michel Ludwig (michel.ludwig@kdemail.net)
  ***************************************************************************/
 
 /***************************************************************************
@@ -17,7 +17,6 @@
 #include <QDir>
 #include <QFileInfo>
 #include <QMetaObject>
-#include <QRegExp>
 #include <QTimer>
 
 #include <KConfig>
@@ -71,7 +70,7 @@ Base::Base(const QString &name, Manager *manager, bool prepare /* = true */) :
 Base::~Base()
 {
     KILE_DEBUG_MAIN << "DELETING TOOL: " << name() << this;
-    emit(aboutToBeDestroyed(this));
+    Q_EMIT(aboutToBeDestroyed(this));
     delete m_launcher;
 }
 
@@ -182,39 +181,39 @@ int Base::run()
     KILE_DEBUG_MAIN << "==KileTool::Base::run()=================";
 
     if(m_nPreparationResult != 0) {
-        emit(failedToRun(this, m_nPreparationResult));
+        Q_EMIT(failedToRun(this, m_nPreparationResult));
         return m_nPreparationResult;
     }
 
     if(!checkSource()) {
-        emit(failedToRun(this, NoValidSource));
+        Q_EMIT(failedToRun(this, NoValidSource));
         return NoValidSource;
     }
 
     if(!checkTarget()) {
-        emit(failedToRun(this, TargetHasWrongPermissions));
+        Q_EMIT(failedToRun(this, TargetHasWrongPermissions));
         return TargetHasWrongPermissions;
     }
 
     if (!checkPrereqs()) {
-        emit(failedToRun(this, NoValidPrereqs));
+        Q_EMIT(failedToRun(this, NoValidPrereqs));
         return NoValidPrereqs;
     }
 
-    emit(start(this));
+    Q_EMIT(start(this));
 
     if (!m_launcher || !m_launcher->launch()) {
         KILE_DEBUG_MAIN << "\tlaunching failed";
         if(!m_launcher) {
-            emit(failedToRun(this, CouldNotLaunch));
+            Q_EMIT(failedToRun(this, CouldNotLaunch));
             return CouldNotLaunch;
         }
         if(!m_launcher->selfCheck()) {
-            emit(failedToRun(this, SelfCheckFailed));
+            Q_EMIT(failedToRun(this, SelfCheckFailed));
             return SelfCheckFailed;
         }
         else {
-            emit(failedToRun(this, CouldNotLaunch));
+            Q_EMIT(failedToRun(this, CouldNotLaunch));
             return CouldNotLaunch;
         }
     }
@@ -298,7 +297,7 @@ void Base::setSource(const QString &source, const QString& workingDir)
     if(!from().isEmpty()) {
         QString src = source;
         if(info.suffix().length() > 0) {
-            src.replace(QRegExp(info.suffix() + '$'), from());
+            src.replace(QRegularExpression(info.suffix() + '$'), from());
         }
         info.setFile(src);
     }
@@ -467,7 +466,7 @@ void Base::stop()
         m_launcher->kill();
     }
 
-    emit(done(this, Aborted, m_childToolSpawned));
+    Q_EMIT(done(this, Aborted, m_childToolSpawned));
 }
 
 bool Base::finish(int result)
@@ -485,7 +484,7 @@ bool Base::finish(int result)
         sendMessage(Info,"Done!");
 
     KILE_DEBUG_MAIN << "\temitting done(KileTool::Base*, int) " << name();
-    emit(done(this, result, m_childToolSpawned));
+    Q_EMIT(done(this, result, m_childToolSpawned));
 
     //we will only get here if the done() signal is not connected to the manager (who will destroy this object)
     if (result == Success) {
@@ -564,7 +563,7 @@ void Base::setupAsChildTool(KileTool::Base *child)
 
 void Base::sendMessage(int type, const QString &msg)
 {
-    emit(message(type, msg, name()));
+    Q_EMIT(message(type, msg, name()));
 }
 
 void Base::filterOutput(const QString & str)
@@ -575,7 +574,7 @@ void Base::filterOutput(const QString & str)
     //idea: store the buffer until a complete line (or more) has been received then parse these lines
     //just send the buf immediately to the output widget, the results of the parsing are displayed in
     //the log widget anyway.
-    emit(output(str));
+    Q_EMIT(output(str));
 }
 
 bool Base::addDict(const QString & key, const QString & value)
@@ -705,7 +704,7 @@ void Archive::setSource(const QString &source, const QString& workingDir)
     addDict("%AFL", m_fileList);
 
     KILE_DEBUG_MAIN << "===KileTool::Archive::setSource("<< source << ")==============";
-    KILE_DEBUG_MAIN << "m_fileList="<<m_fileList<<endl;
+    KILE_DEBUG_MAIN << "m_fileList="<<m_fileList<< Qt::endl;
 }
 
 Convert::Convert(const QString &name, Manager * manager, bool prepare /*= true*/)
@@ -768,8 +767,8 @@ bool Sequence::requestSaveAll()
 {
     // if one of the tools in the sequence requests save-all, then we also
     // request it
-    for(QLinkedList<Base*>::iterator i = m_tools.begin(); i != m_tools.end(); ++i) {
-        if((*i)->requestSaveAll()) {
+    for(Base *tool : m_tools) {
+        if(tool->requestSaveAll()) {
             return true;
         }
     }
@@ -781,17 +780,16 @@ void Sequence::setupSequenceTools()
 {
     QStringList toolNameList = readEntry("sequence").split(',');
     QString tl, cfg;
-    Base *tool;
     for(QStringList::iterator i = toolNameList.begin(); i != toolNameList.end(); ++i) {
         QString fullToolSpec = (*i).trimmed();
         extract(fullToolSpec, tl, cfg);
 
-        tool = manager()->createTool(tl, cfg, false); // create tool with delayed preparation
+        Base *tool = manager()->createTool(tl, cfg, false); // create tool with delayed preparation
         if (tool) {
             KILE_DEBUG_MAIN << "===tool created with name " << tool->name();
             if(!(manager()->info()->watchFile() && tool->isViewer())) { // FIXME: why this?
                 KILE_DEBUG_MAIN << "\tqueueing " << tl << "(" << cfg << ") with " << source();
-                m_tools << tool;
+                m_tools.push_back(tool);
             }
             else {
                 delete tool;
@@ -819,12 +817,11 @@ int Sequence::run()
     if(!m_unknownToolSpec.isEmpty()) {
         // 'm_tools' is empty
         sendMessage(Error, i18n("Unknown tool %1.", m_unknownToolSpec));
-        emit(done(this, Failed, m_childToolSpawned));
+        Q_EMIT(done(this, Failed, m_childToolSpawned));
         return ConfigureFailed;
     }
 
-    for(QLinkedList<Base*>::iterator i = m_tools.begin(); i != m_tools.end(); ++i) {
-        Base *tool = *i;
+    for(Base *tool : m_tools) {
         tool->setSource(source());
 
         // if we are running a 'LaTeX' tool here, we still have to set the
@@ -840,7 +837,7 @@ int Sequence::run()
     }
 
     m_tools.clear(); // the tools will be deleted by the tool manager from now on
-    emit(done(this, Silent, m_childToolSpawned));
+    Q_EMIT(done(this, Silent, m_childToolSpawned));
 
     return Success;
 }
