@@ -1,6 +1,6 @@
 /****************************************************************************************
   Copyright (C) 2003 by Jeroen Wijnhout (Jeroen.Wijnhout@kdemail.net)
-            (C) 2011-2019 by Michel Ludwig (michel.ludwig@kdemail.net)
+            (C) 2011-2022 by Michel Ludwig (michel.ludwig@kdemail.net)
  ****************************************************************************************/
 
 /***************************************************************************
@@ -16,7 +16,6 @@
 #define KILETOOL_H
 
 #include <QHash>
-#include <QLinkedList>
 #include <QMap>
 #include <QObject>
 #include <QString>
@@ -87,7 +86,7 @@ public:
     /**
      * Allows you to set the source file and working directory explicitly (absolute path).
      **/
-    virtual void setSource(const QString& source, const QString& workingDir = "");
+    virtual void setSource(const QString& source, const QString& workingDir = QString());
 
     /**
      * @returns the source file that is used to run the tool on.
@@ -107,10 +106,10 @@ public:
         return m_targetdir;
     }
     inline QString from() const {
-        return readEntry("from");
+        return readEntry(QStringLiteral("from"));
     }
     inline QString to() const {
-        return readEntry("to");
+        return readEntry(QStringLiteral("to"));
     }
     QString target() const {
         return m_target;
@@ -434,7 +433,7 @@ protected:
 public:
     ~Archive();
     virtual bool checkPrereqs() override;
-    virtual void setSource(const QString & source, const QString& workingDir = "") override;
+    virtual void setSource(const QString & source, const QString& workingDir = QString()) override;
 private:
     KileProject *m_project;
     QString m_fileList;
@@ -462,7 +461,7 @@ protected:
     // will also determine the current LaTeXOutputHandler
     virtual bool determineSource() override;
 
-    QLinkedList<Base*> m_tools;
+    std::list<Base*> m_tools;
     QString m_unknownToolSpec;
     LaTeXOutputHandler *m_latexOutputHandler;
 };
