@@ -82,12 +82,12 @@ void Queue::enqueueNext(QueueItem *item)
         Queue *oldqueue = new Queue(*this);
 
         clear();
-        KILE_DEBUG_MAIN << "\tenqueueing: " << headitem->tool()->name() << endl;
+        KILE_DEBUG_MAIN << "\tenqueueing: " << headitem->tool()->name() << Qt::endl;
         enqueue(headitem);
-        KILE_DEBUG_MAIN << "\tenqueueing: " << item->tool()->name() << endl;
+        KILE_DEBUG_MAIN << "\tenqueueing: " << item->tool()->name() << Qt::endl;
         enqueue(item);
         while(!oldqueue->isEmpty()) {
-            KILE_DEBUG_MAIN << "\tenqueueing: " << oldqueue->head()->tool()->name() << endl;
+            KILE_DEBUG_MAIN << "\tenqueueing: " << oldqueue->head()->tool()->name() << Qt::endl;
             enqueue(oldqueue->dequeue());
         }
     }
@@ -104,21 +104,20 @@ Manager::Manager(KileInfo *ki, KConfig *config, KileWidget::OutputView *output,
     m_nTimeout(to),
     m_bibliographyBackendSelectAction(Q_NULLPTR)
 {
-    connect(m_ki->parserManager(), SIGNAL(documentParsingComplete()), this, SLOT(handleDocumentParsingComplete()));
+    connect(m_ki->parserManager(), &KileParser::Manager::documentParsingComplete, this, &Manager::handleDocumentParsingComplete);
 
-    connect(this, SIGNAL(childToolSpawned(KileTool::Base*,KileTool::Base*)),
-            m_ki->errorHandler(), SLOT(handleSpawnedChildTool(KileTool::Base*,KileTool::Base*)));
+    connect(this, &Manager::childToolSpawned, m_ki->errorHandler(), &KileErrorHandler::handleSpawnedChildTool);
 
     m_timer = new QTimer(this);
-    connect(m_timer, SIGNAL(timeout()), this, SLOT(enableClear()));
+    connect(m_timer, &QTimer::timeout, this, &Manager::enableClear);
 
-    connect(m_ki->errorHandler(), SIGNAL(currentLaTeXOutputHandlerChanged(LaTeXOutputHandler*)), SLOT(currentLaTeXOutputHandlerChanged(LaTeXOutputHandler*)));
+    connect(m_ki->errorHandler(), &KileErrorHandler::currentLaTeXOutputHandlerChanged, this, &Manager::currentLaTeXOutputHandlerChanged);
 
     //create actions must be invoked before buildBibliographyBackendSelection()!
     createActions(ac);
     buildBibliographyBackendSelection();
 
-    connect(m_ki->configurationManager(), SIGNAL(configChanged()), SLOT(buildBibliographyBackendSelection()));
+    connect(m_ki->configurationManager(), &KileConfiguration::Manager::configChanged, this, &Manager::buildBibliographyBackendSelection);
 }
 
 Manager::~Manager()
@@ -155,7 +154,7 @@ void Manager::enableClear()
 
 bool Manager::queryContinue(const QString & question, const QString & caption /*= QString()*/)
 {
-    return (KMessageBox::warningContinueCancel(m_stack, question, caption, KStandardGuiItem::cont(), KStandardGuiItem::no(), "showNotALaTeXRootDocumentWarning") == KMessageBox::Continue);
+    return (KMessageBox::warningContinueCancel(m_stack, question, caption, KStandardGuiItem::cont(), KStandardGuiItem::cancel(), "showNotALaTeXRootDocumentWarning") == KMessageBox::Continue);
 }
 
 void Manager::run(Base *tool)
@@ -167,8 +166,8 @@ void Manager::run(Base *tool)
         runImmediately(tool);
         return;
     }
-    connect(tool, SIGNAL(aboutToBeDestroyed(KileTool::Base*)),
-            this, SLOT(toolScheduledAfterParsingDestroyed(KileTool::Base*)), Qt::UniqueConnection);
+    connect(tool, &Base::aboutToBeDestroyed,
+            this, &Manager::toolScheduledAfterParsingDestroyed, Qt::UniqueConnection);
     if(!m_toolsScheduledAfterParsingList.contains(tool)) {
         m_toolsScheduledAfterParsingList.push_back(tool);
     }
@@ -181,9 +180,9 @@ void Manager::toolScheduledAfterParsingDestroyed(KileTool::Base *tool)
 
 void Manager::handleDocumentParsingComplete()
 {
-    Q_FOREACH(Base *tool, m_toolsScheduledAfterParsingList) {
-        disconnect(tool, SIGNAL(aboutToBeDestroyed(KileTool::Base*)),
-                   this, SLOT(toolScheduledAfterParsingDestroyed(KileTool::Base*)));
+    for(Base *tool : std::as_const(m_toolsScheduledAfterParsingList)) {
+        disconnect(tool, &Base::aboutToBeDestroyed,
+                   this, &Manager::toolScheduledAfterParsingDestroyed);
         runImmediately(tool);
     }
     m_toolsScheduledAfterParsingList.clear();
@@ -191,15 +190,15 @@ void Manager::handleDocumentParsingComplete()
 
 int Manager::runImmediately(Base *tool, bool insertNext /*= false*/, bool block /*= false*/, Base *parent /*= Q_NULLPTR*/)
 {
-    KILE_DEBUG_MAIN << "==KileTool::Manager::runImmediately(Base *)============" << endl;
+    KILE_DEBUG_MAIN << "==KileTool::Manager::runImmediately(Base *)============" << Qt::endl;
     if(m_bClear && (m_queue.count() == 0)) {
         m_ki->errorHandler()->clearMessages();
         m_output->clear();
     }
 
     if(dynamic_cast<KileTool::LaTeX*>(tool)) {
-        connect(tool, SIGNAL(done(KileTool::Base*,int,bool)),
-                m_ki->errorHandler(), SLOT(handleLaTeXToolDone(KileTool::Base*,int,bool)));
+        connect(tool, &KileTool::LaTeX::done,
+                m_ki->errorHandler(), &KileErrorHandler::handleLaTeXToolDone);
     }
 
     if(tool->needsToBePrepared()) {
@@ -219,10 +218,10 @@ int Manager::runImmediately(Base *tool, bool insertNext /*= false*/, bool block
     }
 
     if(parent) {
-        emit(childToolSpawned(parent,tool));
+        Q_EMIT(childToolSpawned(parent,tool));
     }
 
-    KILE_DEBUG_MAIN << "\tin queue: " << m_queue.count() << endl;
+    KILE_DEBUG_MAIN << "\tin queue: " << m_queue.count() << Qt::endl;
     if(m_queue.count() == 1) {
         return runNextInQueue();
     }
@@ -265,7 +264,7 @@ int Manager::runNextInQueue()
         }
 
         m_ki->errorHandler()->startToolLogOutput();
-        emit(toolStarted());
+        Q_EMIT(toolStarted());
 
         return Running;
     }
@@ -302,7 +301,7 @@ void Manager::initTool(Base *tool)
 
 void Manager::started(Base *tool)
 {
-    KILE_DEBUG_MAIN << "STARTING tool: " << tool->name() << endl;
+    KILE_DEBUG_MAIN << "STARTING tool: " << tool->name() << Qt::endl;
     setEnabledStopButton(true);
 
     if (tool->isViewer()) {
@@ -434,8 +433,8 @@ bool Manager::retrieveEntryMap(const QString & name, Config & map, bool usequeue
 {
     QString group = (cfg.isEmpty()) ? currentGroup(name, usequeue, useproject) : groupFor(name, cfg);
 
-    KILE_DEBUG_MAIN << "==KileTool::Manager::retrieveEntryMap=============" << endl;
-    KILE_DEBUG_MAIN << "\t" << name << " => " << group << endl;
+    KILE_DEBUG_MAIN << "==KileTool::Manager::retrieveEntryMap=============" << Qt::endl;
+    KILE_DEBUG_MAIN << "\t" << name << " => " << group << Qt::endl;
     if(m_config->hasGroup(group)) {
         map = m_config->entryMap(group);
 
@@ -461,9 +460,9 @@ bool Manager::retrieveEntryMap(const QString & name, Config & map, bool usequeue
 
 void Manager::saveEntryMap(const QString & name, Config & map, bool usequeue, bool useproject)
 {
-    KILE_DEBUG_MAIN << "==KileTool::Manager::saveEntryMap=============" << endl;
+    KILE_DEBUG_MAIN << "==KileTool::Manager::saveEntryMap=============" << Qt::endl;
     QString group = currentGroup(name, usequeue, useproject);
-    KILE_DEBUG_MAIN << "\t" << name << " => " << group << endl;
+    KILE_DEBUG_MAIN << "\t" << name << " => " << group << Qt::endl;
     KConfigGroup configGroup = m_config->group(group);
 
     Config::Iterator it;
@@ -476,7 +475,7 @@ void Manager::saveEntryMap(const QString & name, Config & map, bool usequeue, bo
 
 bool Manager::configure(Base *tool, const QString& cfg /* = QString() */)
 {
-    KILE_DEBUG_MAIN << "==KileTool::Manager::configure()===============" << endl;
+    KILE_DEBUG_MAIN << "==KileTool::Manager::configure()===============" << Qt::endl;
     //configure the tool
 
     Config map;
@@ -494,8 +493,8 @@ bool Manager::configure(Base *tool, const QString& cfg /* = QString() */)
 
 void Manager::wantGUIState(const QString & state)
 {
-    KILE_DEBUG_MAIN << "REQUESTED state: " << state << endl;
-    emit(requestGUIState(state));
+    KILE_DEBUG_MAIN << "REQUESTED state: " << state << Qt::endl;
+    Q_EMIT(requestGUIState(state));
 }
 
 KileView::Manager* Manager::viewManager()
@@ -515,7 +514,7 @@ KileParser::Manager* Manager::parserManager()
 
 QStringList toolList(KConfig *config, bool menuOnly)
 {
-    KILE_DEBUG_MAIN << "==KileTool::toolList()==================" << endl;
+    KILE_DEBUG_MAIN << "==KileTool::toolList()==================" << Qt::endl;
 
     const QStringList groups = config->groupList();
     QStringList tools;
@@ -523,7 +522,7 @@ QStringList toolList(KConfig *config, bool menuOnly)
     QRegExp re = QRegExp("Tool/(.+)/.+");
     QString name;
 
-    for(auto group : groups) {
+    for (const auto& group : groups) {
         if(!config->hasGroup(group)) { // 'group' might have been deleted
             continue;                // work around bug 384039
         }
@@ -549,12 +548,11 @@ QStringList toolList(KConfig *config, bool menuOnly)
 QList<ToolConfigPair> toolsWithConfigurationsBasedOnClass(KConfig *config, const QString& className)
 {
     const QStringList groups = config->groupList();
-    QStringList tools;
 
     QRegExp re = QRegExp("Tool/(.+)/(.+)");
     QList<ToolConfigPair> toReturn;
 
-    for(auto group : groups) {
+    for (const auto& group : groups) {
         if(!config->hasGroup(group)) { // 'group' might have been deleted
             continue;                // work around bug 384039
         }
@@ -587,7 +585,7 @@ void Manager::setConfigName(const QString &tool, const QString &name)
 
 void setConfigName(const QString &tool, const QString &name, KConfig *config)
 {
-    KILE_DEBUG_MAIN << "==KileTool::Manager::setConfigName(" << tool << "," << name << ")===============" << endl;
+    KILE_DEBUG_MAIN << "==KileTool::Manager::setConfigName(" << tool << "," << name << ")===============" << Qt::endl;
     config->group("Tools").writeEntry(tool, name);
 }
 
@@ -615,7 +613,7 @@ void extract(const QString &str, QString &tool, QString &cfg)
     else {
         tool = lcl;
     }
-    KILE_DEBUG_MAIN << "===void extract(const QString &str = " << str << " , QString &tool = " << tool << ", QString &cfg = " << cfg << " )===" << endl;
+    KILE_DEBUG_MAIN << "===void extract(const QString &str = " << str << " , QString &tool = " << tool << ", QString &cfg = " << cfg << " )===" << Qt::endl;
 }
 
 QString format(const QString & tool, const QString &cfg)
@@ -635,7 +633,7 @@ QStringList configNames(const QString &tool, KConfig *config)
 
     QRegExp re = QRegExp("Tool/"+ tool +"/(.+)");
 
-    for(auto group : groups) {
+    for (const auto& group : groups) {
         if(!config->hasGroup(group)) { // 'group' might have been deleted
             continue;                // work around bug 384039
         }
@@ -699,7 +697,7 @@ bool KileTool::Manager::containsBibliographyTool(const ToolConfigPair& p) const
 KileTool::ToolConfigPair KileTool::Manager::findFirstBibliographyToolForCommand(const QString& command) const
 {
     // for now we will just select the first suitable tool
-    Q_FOREACH(const KileTool::ToolConfigPair& tool, m_bibliographyToolsList) {
+    for(const KileTool::ToolConfigPair& tool : m_bibliographyToolsList) {
         const QString toolCommand = commandFor(tool, m_config);
         if (QString::compare(command, toolCommand, Qt::CaseInsensitive) == 0) {
             return tool;
@@ -724,10 +722,10 @@ void KileTool::Manager::buildBibliographyBackendSelection()
     m_bibliographyToolsList = toolsWithConfigurationsBasedOnClass(m_config, BibliographyCompile::ToolClass);
     std::sort(m_bibliographyToolsList.begin(), m_bibliographyToolsList.end()); // necessary for the user-visible actions in the menu bar
 
-    Q_FOREACH(const ToolConfigPair& tool, m_bibliographyToolsList) {
+    for(const ToolConfigPair& tool : m_bibliographyToolsList) {
         // create an action for backend selection
         QAction * action = m_bibliographyBackendSelectAction->addAction(tool.userStringRepresentation());
-        action->setData(qVariantFromValue(tool));
+        action->setData(QVariant::fromValue(tool));
         m_bibliographyBackendActionMap[tool] = action;
     }
 
@@ -759,10 +757,14 @@ void KileTool::Manager::createActions(KActionCollection *ac)
     m_bibliographyBackendResetAutodetectedAction = new QAction(i18n("Reset Auto-Detected Back End"), this);
     m_bibliographyBackendResetAutodetectedAction->setEnabled(false);
 
-    connect(m_bibliographyBackendSelectAction, SIGNAL(triggered(QAction*)), SLOT(bibliographyBackendSelectedByUser()));
-    connect(m_bibliographyBackendResetAutodetectedAction, SIGNAL(triggered(bool)), SLOT(resetAutodetectedBibliographyBackend()));
-    connect(m_bibliographyBackendAutodetectAction, SIGNAL(toggled(bool)),
-            m_bibliographyBackendResetAutodetectedAction, SLOT(setEnabled(bool)));
+    connect(m_bibliographyBackendSelectAction, &QAction::triggered, this, [this]() {
+        bibliographyBackendSelectedByUser();
+    });
+    connect(m_bibliographyBackendResetAutodetectedAction, &QAction::triggered, this, [this] {
+        resetAutodetectedBibliographyBackend();
+    });
+    connect(m_bibliographyBackendAutodetectAction, &QAction::toggled,
+            m_bibliographyBackendResetAutodetectedAction, &QAction::setEnabled);
 }
 
 
