@@ -24,8 +24,8 @@
 #include <kio/global.h>
 #include <KLocalizedString>
 #include <KMessageBox>
+#include <KPluginFactory>
 #include <KTextEditor/Application>
-#include <KTextEditor/CodeCompletionInterface>
 #include <KTextEditor/Document>
 #include <KTextEditor/Editor>
 #include <KTextEditor/MainWindow>
@@ -66,6 +66,8 @@
 #include "codecompletion.h"
 
 
+using namespace Qt::Literals::StringLiterals;
+
 namespace KileView
 {
 
@@ -88,13 +90,13 @@ DocumentViewerWindow::~DocumentViewerWindow()
 void DocumentViewerWindow::showEvent(QShowEvent *event)
 {
     KMainWindow::showEvent(event);
-    emit visibilityChanged(true);
+    Q_EMIT visibilityChanged(true);
 }
 
 void DocumentViewerWindow::closeEvent(QCloseEvent *event)
 {
     KMainWindow::closeEvent(event);
-    emit visibilityChanged(false);
+    Q_EMIT visibilityChanged(false);
 }
 
 //END DocumentViewerWindow
@@ -199,7 +201,7 @@ void Manager::readConfig(QSplitter *splitter)
 
     m_synchronizeViewWithCursorAction->setChecked(KileConfig::synchronizeCursorWithView());
 
-    Okular::ViewerInterface *viewerInterface = dynamic_cast<Okular::ViewerInterface*>(m_viewerPart.data());
+    Okular::ViewerInterface *viewerInterface = qobject_cast<Okular::ViewerInterface*>(m_viewerPart.data());
     if(viewerInterface && !m_ki->livePreviewManager()->isLivePreviewActive()) {
         viewerInterface->setWatchFileModeEnabled(KileConfig::watchFileForDocumentViewer());
         // also reload the document; this is necessary for switching back on watch-file mode as otherwise
@@ -216,7 +218,7 @@ void Manager::writeConfig()
         KileConfig::setShowDocumentViewer(isViewerPartShown());
     }
     if(m_viewerPartWindow) {
-        KConfigGroup group(KSharedConfig::openConfig(), "KileDocumentViewerWindow");
+        KConfigGroup group(KSharedConfig::openConfig(), u"KileDocumentViewerWindow"_s);
         m_viewerPartWindow->saveMainWindowSettings(group);
     }
 
@@ -230,6 +232,7 @@ void Manager::setTabsAndEditorVisible(bool b)
 
 QWidget * Manager::createTabs(QWidget *parent)
 {
+    delete m_widgetStack;
     m_widgetStack = new QStackedWidget(parent);
     DropWidget *emptyDropWidget = new DropWidget(m_widgetStack);
     m_widgetStack->insertWidget(0, emptyDropWidget);
@@ -339,10 +342,10 @@ void Manager::currentTabChanged(int index)
     }
     m_widgetStack->insertWidget(1, newlyActivatedWidget);
     m_widgetStack->setCurrentIndex(1);
-    emit currentViewChanged(newlyActivatedWidget);
+    Q_EMIT currentViewChanged(newlyActivatedWidget);
     KTextEditor::View *view = dynamic_cast<KTextEditor::View*>(newlyActivatedWidget);
     if(view) {
-        emit textViewActivated(view);
+        Q_EMIT textViewActivated(view);
     }
 }
 
@@ -400,10 +403,7 @@ KTextEditor::View * Manager::createTextView(KileDocument::TextInfo *info, int in
     connect(this, &KileView::Manager::textViewClosed, m_cursorPositionChangedTimer, &QTimer::stop);
 
     // code completion
-    KTextEditor::CodeCompletionInterface *completionInterface = qobject_cast<KTextEditor::CodeCompletionInterface*>(view);
-    if(completionInterface) {
-        completionInterface->setAutomaticInvocationEnabled(true);
-    }
+    view->setAutomaticInvocationEnabled(true);
 
     // install a working text editor part popup dialog thingy
     installContextMenu(view);
@@ -432,6 +432,16 @@ KTextEditor::View * Manager::createTextView(KileDocument::TextInfo *info, int in
             m_ki->docManager()->fileSaveAs();
         });
     }
+
+    // use Kile's smart-new-line feature
+    action = view->actionCollection()->action("smart_newline");
+    if(action) {
+        disconnect(action, &QAction::triggered, 0, 0);
+        connect(action, &QAction::triggered, [=]() {
+            m_ki->editorExtension()->insertIntelligentNewline();
+        });
+    }
+
     updateTabTexts(doc);
     // we do this twice as otherwise the tool tip for the first view did not appear (Qt issue ?)
     // (BUG 205245)
@@ -443,11 +453,11 @@ KTextEditor::View * Manager::createTextView(KileDocument::TextInfo *info, int in
     }
 
     //activate the newly created view
-    emit(textViewCreated(view));
-    emit(activateView(view, false));
-    emit(updateCaption());  //make sure the caption gets updated
+    Q_EMIT(textViewCreated(view));
+    Q_EMIT(activateView(view, false));
+    Q_EMIT(updateCaption());  //make sure the caption gets updated
 
-    reflectDocumentModificationStatus(view->document(), false, KTextEditor::ModificationInterface::OnDiskUnmodified);
+    reflectDocumentModificationStatus(view->document(), false, KTextEditor::Document::OnDiskUnmodified);
 
     return view;
 }
@@ -507,13 +517,13 @@ void Manager::tabContext(const QPoint &pos)
     // 'action1' can become null if it belongs to a view that has been closed, for example
     QPointer<QAction> action1 = m_ki->mainWindow()->action("move_view_tab_left");
     if(action1) {
-        action1->setData(qVariantFromValue(view));
+        action1->setData(QVariant::fromValue(view));
         tabMenu.addAction(action1);
     }
 
     QPointer<QAction> action2 = m_ki->mainWindow()->action("move_view_tab_right");
     if(action2) {
-        action2->setData(qVariantFromValue(view));
+        action2->setData(QVariant::fromValue(view));
         tabMenu.addAction(action2);
     }
 
@@ -523,14 +533,14 @@ void Manager::tabContext(const QPoint &pos)
     if(view->document()->isModified()) {
         action3 = view->actionCollection()->action(KStandardAction::name(KStandardAction::Save));
         if(action3) {
-            action3->setData(qVariantFromValue(view));
+            action3->setData(QVariant::fromValue(view));
             tabMenu.addAction(action3);
         }
     }
 
     QPointer<QAction> action4 = view->actionCollection()->action(KStandardAction::name(KStandardAction::SaveAs));
     if(action4) {
-        action4->setData(qVariantFromValue(view));
+        action4->setData(QVariant::fromValue(view));
         tabMenu.addAction(action4);
     }
 
@@ -543,13 +553,13 @@ void Manager::tabContext(const QPoint &pos)
 
     QPointer<QAction> action6 = m_ki->mainWindow()->action("file_close");
     if(action6) {
-        action6->setData(qVariantFromValue(view));
+        action6->setData(QVariant::fromValue(view));
         tabMenu.addAction(action6);
     }
 
     QPointer<QAction> action7 = m_ki->mainWindow()->action("file_close_all_others");
     if(action7) {
-        action7->setData(qVariantFromValue(view));
+        action7->setData(QVariant::fromValue(view));
         tabMenu.addAction(action7);
     }
     /*
@@ -592,13 +602,13 @@ void Manager::removeView(KTextEditor::View *view)
         const bool isActiveView = (KTextEditor::Editor::instance()->application()->activeMainWindow()->activeView() == view);
         m_tabBar->removeTab(tabIndexOf(view));
 
-        emit(updateCaption());  //make sure the caption gets updated
+        Q_EMIT(updateCaption());  //make sure the caption gets updated
         if(m_tabBar->count() == 0) {
             m_ki->structureWidget()->clear();
             m_widgetStack->setCurrentIndex(0); // if there are no open views, then show the DropWidget
         }
 
-        emit(textViewClosed(view, isActiveView));
+        Q_EMIT(textViewClosed(view, isActiveView));
         delete view;
     }
     else {
@@ -794,19 +804,19 @@ void Manager::moveTabRight(QWidget *widget)
 
 void Manager::reflectDocumentModificationStatus(KTextEditor::Document *doc,
         bool isModified,
-        KTextEditor::ModificationInterface::ModifiedOnDiskReason reason)
+        KTextEditor::Document::ModifiedOnDiskReason reason)
 {
     QIcon icon;
-    if(reason == KTextEditor::ModificationInterface::OnDiskUnmodified && isModified) { //nothing
+    if(reason == KTextEditor::Document::OnDiskUnmodified && isModified) { //nothing
         icon = QIcon::fromTheme("modified"); // This icon is taken from Kate. Therefore
         // our thanks go to the authors of Kate.
     }
-    else if(reason == KTextEditor::ModificationInterface::OnDiskModified
-            || reason == KTextEditor::ModificationInterface::OnDiskCreated) { //dirty file
+    else if(reason == KTextEditor::Document::OnDiskModified
+            || reason == KTextEditor::Document::OnDiskCreated) { //dirty file
         icon = QIcon::fromTheme("emblem-warning"); // This icon is taken from Kate. Therefore
         // our thanks go to the authors of Kate.
     }
-    else if(reason == KTextEditor::ModificationInterface::OnDiskDeleted) { //file deleted
+    else if(reason == KTextEditor::Document::OnDiskDeleted) { //file deleted
         icon = QIcon::fromTheme("emblem-warning");
     }
     else if(m_ki->extensions()->isScriptFile(doc->url())) {
@@ -983,13 +993,13 @@ void Manager::quickPreviewPopup()
     }
 
     if(view->selection()) {
-        emit(startQuickPreview(KileTool::qpSelection));
+        Q_EMIT(startQuickPreview(KileTool::qpSelection));
     }
     else if(m_ki->editorExtension()->hasMathgroup(view)) {
-        emit(startQuickPreview(KileTool::qpMathgroup));
+        Q_EMIT(startQuickPreview(KileTool::qpMathgroup));
     }
     else if(m_ki->editorExtension()->hasEnvironment(view)) {
-        emit(startQuickPreview(KileTool::qpEnvironment));
+        Q_EMIT(startQuickPreview(KileTool::qpEnvironment));
     }
 }
 
@@ -1055,7 +1065,7 @@ DropWidget::~DropWidget()
 void DropWidget::dragEnterEvent(QDragEnterEvent *e)
 {
     bool b;
-    emit testCanDecode(e, b);
+    Q_EMIT testCanDecode(e, b);
     if(b) {
         e->acceptProposedAction();
     }
@@ -1063,13 +1073,13 @@ void DropWidget::dragEnterEvent(QDragEnterEvent *e)
 
 void DropWidget::dropEvent(QDropEvent *e)
 {
-    emit receivedDropEvent(e);
+    Q_EMIT receivedDropEvent(e);
 }
 
 void DropWidget::mouseDoubleClickEvent(QMouseEvent *e)
 {
     Q_UNUSED(e);
-    emit mouseDoubleClick();
+    Q_EMIT mouseDoubleClick();
 }
 
 void Manager::installEventFilter(KTextEditor::View *view, QObject *eventFilter)
@@ -1100,18 +1110,17 @@ void Manager::createViewerPart(KActionCollection *actionCollection)
 {
     m_viewerPart = Q_NULLPTR;
 
-    KPluginLoader pluginLoader(OKULAR_LIBRARY_NAME);
-    KPluginFactory *factory = pluginLoader.factory();
-    if(!factory) {
-        KILE_DEBUG_MAIN << "Could not find the Okular library.";
+    const KPluginMetaData okularPart(QStringLiteral(OKULAR_LIBRARY_NAME));
+    const QVariantList args {"ViewerWidget", "ConfigFileName=kile-livepreview-okularpartrc"};
+
+    auto result = KPluginFactory::instantiatePlugin<KParts::ReadOnlyPart>(okularPart, nullptr, args);
+    if(!result) {
+        KILE_DEBUG_MAIN << "Could not load the Okular library:" << result.errorString;
         m_viewerPart = Q_NULLPTR;
         return;
-    }
-    else {
-        QVariantList argList;
-        argList << "ViewerWidget" << "ConfigFileName=kile-livepreview-okularpartrc";
-        m_viewerPart = factory->create<KParts::ReadOnlyPart>(this, argList);
-        Okular::ViewerInterface *viewerInterface = dynamic_cast<Okular::ViewerInterface*>(m_viewerPart.data());
+    } else {
+        m_viewerPart = result.plugin;
+        Okular::ViewerInterface *viewerInterface = qobject_cast<Okular::ViewerInterface*>(m_viewerPart.data());
         if(!viewerInterface) {
             // OkularPart doesn't provide the ViewerInterface
             delete m_viewerPart;
@@ -1256,7 +1265,7 @@ bool Manager::isViewerPartShown() const
 
 bool Manager::openInDocumentViewer(const QUrl &url)
 {
-    Okular::ViewerInterface *v = dynamic_cast<Okular::ViewerInterface*>(m_viewerPart.data());
+    Okular::ViewerInterface *v = qobject_cast<Okular::ViewerInterface*>(m_viewerPart.data());
     if(!v) {
         return false;
     }
@@ -1267,7 +1276,7 @@ bool Manager::openInDocumentViewer(const QUrl &url)
 
 void Manager::clearLastShownSourceLocationInDocumentViewer()
 {
-    Okular::ViewerInterface *v = dynamic_cast<Okular::ViewerInterface*>(m_viewerPart.data());
+    Okular::ViewerInterface *v = qobject_cast<Okular::ViewerInterface*>(m_viewerPart.data());
     if(v) {
         v->clearLastShownSourceLocation();
     }
@@ -1275,7 +1284,7 @@ void Manager::clearLastShownSourceLocationInDocumentViewer()
 
 void Manager::showSourceLocationInDocumentViewer(const QString& fileName, int line, int column)
 {
-    Okular::ViewerInterface *v = dynamic_cast<Okular::ViewerInterface*>(m_viewerPart.data());
+    Okular::ViewerInterface *v = qobject_cast<Okular::ViewerInterface*>(m_viewerPart.data());
     if(v) {
         m_clearLastShownSourceLocationTimer->stop();
         v->showSourceLocation(fileName, line, column, true);
@@ -1285,7 +1294,7 @@ void Manager::showSourceLocationInDocumentViewer(const QString& fileName, int li
 
 void Manager::setLivePreviewModeForDocumentViewer(bool b)
 {
-    Okular::ViewerInterface *viewerInterface = dynamic_cast<Okular::ViewerInterface*>(m_viewerPart.data());
+    Okular::ViewerInterface *viewerInterface = qobject_cast<Okular::ViewerInterface*>(m_viewerPart.data());
     if(viewerInterface) {
         if(b) {
             viewerInterface->setWatchFileModeEnabled(false);
