@@ -16,6 +16,7 @@
 
 #include <QDir>
 #include <QFileInfo>
+#include <QRegularExpression>
 
 #include <KLocalizedString>
 
@@ -121,7 +122,7 @@ bool LaTeXOutputParser::fileExists(const QString & name)
 //	from the context.
 void LaTeXOutputParser::updateFileStack(const QString &strLine, short& dwCookie)
 {
-    //qCDebug(LOG_KILE_PARSER) << "==LaTeXOutputParser::updateFileStack()================" << endl;
+    //qCDebug(LOG_KILE_PARSER) << "==LaTeXOutputParser::updateFileStack()================" << Qt::endl;
     static QString strPartialFileName;
 
     switch (dwCookie) {
@@ -130,7 +131,7 @@ void LaTeXOutputParser::updateFileStack(const QString &strLine, short& dwCookie)
     case FileNameHeuristic :
         //TeX is opening a file
         if(strLine.startsWith(":<+ ")) {
-// 				qCDebug(LOG_KILE_PARSER) << "filename detected" << endl;
+// 				qCDebug(LOG_KILE_PARSER) << "filename detected" << Qt::endl;
             //grab the filename, it might be a partial name (i.e. continued on the next line)
             strPartialFileName = strLine.mid(4).trimmed();
 
@@ -139,7 +140,7 @@ void LaTeXOutputParser::updateFileStack(const QString &strLine, short& dwCookie)
         }
         //TeX closed a file
         else if(strLine.contains(":<-")) {
-// 				qCDebug(LOG_KILE_PARSER) << "\tpopping : " << m_stackFile.top().file() << endl;
+// 				qCDebug(LOG_KILE_PARSER) << "\tpopping : " << m_stackFile.top().file() << Qt::endl;
             if(!m_stackFile.isEmpty()) {
                 m_stackFile.pop();
             }
@@ -158,27 +159,27 @@ void LaTeXOutputParser::updateFileStack(const QString &strLine, short& dwCookie)
         if(strLine.startsWith('(') || strLine.startsWith(QLatin1String("\\openout"))) {
             //push the filename on the stack and mark it as 'reliable'
             m_stackFile.push(LOFStackItem(strPartialFileName, true));
-// 				qCDebug(LOG_KILE_PARSER) << "\tpushed : " << strPartialFileName << endl;
+// 				qCDebug(LOG_KILE_PARSER) << "\tpushed : " << strPartialFileName << Qt::endl;
             strPartialFileName.clear();
             dwCookie = Start;
         }
         //The partial filename was followed by an TeX error, meaning the file doesn't exist.
         //Don't push it on the stack, instead try to detect the error.
         else if(strLine.startsWith('!')) {
-// 				qCDebug(LOG_KILE_PARSER) << "oops!" << endl;
+// 				qCDebug(LOG_KILE_PARSER) << "oops!" << Qt::endl;
             dwCookie = Start;
             strPartialFileName.clear();
             detectError(strLine, dwCookie);
         }
         else if(strLine.startsWith(QLatin1String("No file"))) {
-// 				qCDebug(LOG_KILE_PARSER) << "No file: " << strLine << endl;
+// 				qCDebug(LOG_KILE_PARSER) << "No file: " << strLine << Qt::endl;
             dwCookie = Start;
             strPartialFileName.clear();
             detectWarning(strLine, dwCookie);
         }
         //Partial filename still isn't complete.
         else {
-// 				qCDebug(LOG_KILE_PARSER) << "\tpartial file name, adding" << endl;
+// 				qCDebug(LOG_KILE_PARSER) << "\tpartial file name, adding" << Qt::endl;
             strPartialFileName = strPartialFileName + strLine.trimmed();
         }
         break;
@@ -209,10 +210,10 @@ void LaTeXOutputParser::updateFileStackHeuristic(const QString &strLine, short &
         We're expecting a filename. If a filename really ends at this position one of the following must be true:
         	1) Next character is a space (indicating the end of a filename (yes, there can't be spaces in the
         	path, this is a TeX limitation).
-        comment by tbraun: there is a workround \include{{"file name"}} according to http://groups.google.com/group/comp.text.tex/browse_thread/thread/af873534f0644e4f/cd7e0cdb61a8b837?lnk=st&q=include+space+tex#cd7e0cdb61a8b837,
+        comment by tbraun: there is a workaround \include{{"file name"}} according to https://groups.google.com/forum/#!topic/comp.text.tex/r4c1NPBkTk8,
         but this is currently not supported by kile.
         	2) We're at the end of the line, the filename is probably continued on the next line.
-        	3) The TeX was closed already, signalled by the ')'.
+        	3) The TeX was closed already, signaled by the ')'.
         */
 
         bool isLastChar = (i+1 == strLine.length());
@@ -237,12 +238,12 @@ void LaTeXOutputParser::updateFileStackHeuristic(const QString &strLine, short &
             else if(isLastChar) {
                 if(fileExists(strPartialFileName)) {
                     m_stackFile.push(LOFStackItem(strPartialFileName));
-                    qCDebug(LOG_KILE_PARSER) << "pushed (i = " << i << " length = " << strLine.length() << "): " << strPartialFileName << endl;
+                    qCDebug(LOG_KILE_PARSER) << "pushed (i = " << i << " length = " << strLine.length() << "): " << strPartialFileName << Qt::endl;
                     expectFileName = false;
                     dwCookie = Start;
                 }
                 else {
-                    qCDebug(LOG_KILE_PARSER) << "Filename spans more than one line." << endl;
+                    qCDebug(LOG_KILE_PARSER) << "Filename spans more than one line." << Qt::endl;
                     dwCookie = FileNameHeuristic;
                 }
             }
@@ -282,7 +283,7 @@ void LaTeXOutputParser::updateFileStackHeuristic(const QString &strLine, short &
 
 void LaTeXOutputParser::flushCurrentItem()
 {
-    //qCDebug(LOG_KILE_PARSER) << "==LaTeXOutputParser::flushCurrentItem()================" << endl;
+    //qCDebug(LOG_KILE_PARSER) << "==LaTeXOutputParser::flushCurrentItem()================" << Qt::endl;
     int nItemType = m_currentItem.type();
 
     while( m_stackFile.count() > 0 && !fileExists(m_stackFile.top().file()) ) {
@@ -297,19 +298,19 @@ void LaTeXOutputParser::flushCurrentItem()
     case itmError:
         ++m_nErrors;
         m_infoList->push_back(m_currentItem);
-        //qCDebug(LOG_KILE_PARSER) << "Flushing Error in" << m_currentItem.source() << "@" << m_currentItem.sourceLine() << " reported in line " << m_currentItem.outputLine() <<  endl;
+        //qCDebug(LOG_KILE_PARSER) << "Flushing Error in" << m_currentItem.source() << "@" << m_currentItem.sourceLine() << " reported in line " << m_currentItem.outputLine() << Qt::endl;
         break;
 
     case itmWarning:
         ++m_nWarnings;
         m_infoList->push_back(m_currentItem);
-        //qCDebug(LOG_KILE_PARSER) << "Flushing Warning in " << m_currentItem.source() << "@" << m_currentItem.sourceLine() << " reported in line " << m_currentItem.outputLine() << endl;
+        //qCDebug(LOG_KILE_PARSER) << "Flushing Warning in " << m_currentItem.source() << "@" << m_currentItem.sourceLine() << " reported in line " << m_currentItem.outputLine() << Qt::endl;
         break;
 
     case itmBadBox:
         ++m_nBadBoxes;
         m_infoList->push_back(m_currentItem);
-        //qCDebug(LOG_KILE_PARSER) << "Flushing BadBox in " << m_currentItem.source() << "@" << m_currentItem.sourceLine() << " reported in line " << m_currentItem.outputLine() << endl;
+        //qCDebug(LOG_KILE_PARSER) << "Flushing BadBox in " << m_currentItem.source() << "@" << m_currentItem.sourceLine() << " reported in line " << m_currentItem.outputLine() << Qt::endl;
         break;
 
     default:
@@ -320,67 +321,71 @@ void LaTeXOutputParser::flushCurrentItem()
 
 bool LaTeXOutputParser::detectError(const QString & strLine, short &dwCookie)
 {
-    //qCDebug(LOG_KILE_PARSER) << "==LaTeXOutputParser::detectError(" << strLine.length() << ")================" << endl;
+    //qCDebug(LOG_KILE_PARSER) << "==LaTeXOutputParser::detectError(" << strLine.length() << ")================" << Qt::endl;
 
     bool found = false, flush = false;
 
-    static QRegExp reLaTeXError("^! LaTeX Error: (.*)$", Qt::CaseInsensitive);
-    static QRegExp rePDFLaTeXError("^Error: pdflatex (.*)$", Qt::CaseInsensitive);
-    static QRegExp reTeXError("^! (.*)\\.$");
-    static QRegExp reLineNumber("^l\\.([0-9]+)(.*)");
+    static QRegularExpression reLaTeXError("^! LaTeX Error: (.*)$", QRegularExpression::CaseInsensitiveOption);
+    static QRegularExpression rePDFLaTeXError("^Error: pdflatex (.*)$", QRegularExpression::CaseInsensitiveOption);
+    static QRegularExpression reTeXError("^! (.*)\\.$");
+    static QRegularExpression reLineNumber("^l\\.([0-9]+)(.*)");
+
+    QRegularExpressionMatch match;
 
     switch (dwCookie) {
     case Start :
-        if(reLaTeXError.indexIn(strLine) != -1) {
-            //qCDebug(LOG_KILE_PARSER) << "\tError : " <<  reLaTeXError.cap(1) << endl;
-            m_currentItem.setMessage(reLaTeXError.cap(1));
+        if(strLine.indexOf(reLaTeXError, 0, &match) != -1) {
+            //qCDebug(LOG_KILE_PARSER) << "\tError : " <<  reLaTeXError.cap(1) << Qt::endl;
+            m_currentItem.setMessage(match.captured(1));
             found = true;
         }
-        else if(rePDFLaTeXError.indexIn(strLine) != -1) {
-            //qCDebug(LOG_KILE_PARSER) << "\tError : " <<  rePDFLaTeXError.cap(1) << endl;
-            m_currentItem.setMessage(rePDFLaTeXError.cap(1));
+        else if(strLine.indexOf(rePDFLaTeXError, 0, &match) != -1) {
+            //qCDebug(LOG_KILE_PARSER) << "\tError : " <<  rePDFLaTeXError.cap(1) << Qt::endl;
+            m_currentItem.setMessage(match.captured(1));
             found = true;
         }
-        else if(reTeXError.indexIn(strLine) != -1) {
-            //qCDebug(LOG_KILE_PARSER) << "\tError : " <<  reTeXError.cap(1) << endl;
-            m_currentItem.setMessage(reTeXError.cap(1));
+        else if(strLine.indexOf(reTeXError, 0, &match) != -1) {
+            //qCDebug(LOG_KILE_PARSER) << "\tError : " <<  reTeXError.cap(1) << Qt::endl;
+            m_currentItem.setMessage(match.captured(1));
             found = true;
         }
+
         if(found) {
             dwCookie = strLine.endsWith('.') ? LineNumber : Error;
             m_currentItem.setOutputLine(GetCurrentOutputLine());
         }
         break;
-
     case Error :
-        //qCDebug(LOG_KILE_PARSER) << "\tError (cont'd): " << strLine << endl;
+        //qCDebug(LOG_KILE_PARSER) << "\tError (cont'd): " << strLine << Qt::endl;
         if(strLine.endsWith('.')) {
             dwCookie = LineNumber;
             m_currentItem.setMessage(m_currentItem.message() + strLine);
         }
         else if(GetCurrentOutputLine() - m_currentItem.outputLine() > 3) {
-            qWarning() << "\tBAILING OUT: error description spans more than three lines" << endl;
+            qWarning() << "\tBAILING OUT: error description spans more than three lines" << Qt::endl;
             dwCookie = Start;
             flush = true;
         }
         break;
 
-    case LineNumber :
-        //qCDebug(LOG_KILE_PARSER) << "\tLineNumber " << endl;
-        if(reLineNumber.indexIn(strLine) != -1) {
+    case LineNumber: {
+        //qCDebug(LOG_KILE_PARSER) << "\tLineNumber " << Qt::endl;
+        QRegularExpressionMatch lineNumberMatch = reLineNumber.match(strLine);
+        if(lineNumberMatch.hasMatch()) {
             dwCookie = Start;
             flush = true;
-            //qCDebug(LOG_KILE_PARSER) << "\tline number: " << reLineNumber.cap(1) << endl;
-            m_currentItem.setSourceLine(reLineNumber.cap(1).toInt());
-            m_currentItem.setMessage(m_currentItem.message() + reLineNumber.cap(2));
+            //qCDebug(LOG_KILE_PARSER) << "\tline number: " << reLineNumber.cap(1) << Qt::endl;
+            m_currentItem.setSourceLine(lineNumberMatch.captured(1).toInt());
+            m_currentItem.setMessage(m_currentItem.message() + lineNumberMatch.captured(2));
         }
         else if(GetCurrentOutputLine() - m_currentItem.outputLine() > 10) {
             dwCookie = Start;
             flush = true;
-            qWarning() << "\tBAILING OUT: did not detect a TeX line number for an error" << endl;
+            qWarning() << "\tBAILING OUT: did not detect a TeX line number for an error" << Qt::endl;
             m_currentItem.setSourceLine(0);
         }
         break;
+    }
 
     default :
         break;
@@ -405,16 +410,17 @@ bool LaTeXOutputParser::detectWarning(const QString & strLine, short &dwCookie)
     bool found = false, flush = false;
     QString warning;
 
-    static QRegExp reLaTeXWarning("^(((! )?(La|pdf)TeX)|Package|Class) .*Warning.*:(.*)", Qt::CaseInsensitive);
-    static QRegExp reNoFile("No file (.*)");
-    static QRegExp reNoAsyFile("File .* does not exist."); // FIXME can be removed when http://sourceforge.net/tracker/index.php?func=detail&aid=1772022&group_id=120000&atid=685683 has promoted to the users
+    static QRegularExpression reLaTeXWarning("^(((! )?(La|pdf)TeX)|Package|Class) .*Warning.*:(.*)", QRegularExpression::CaseInsensitiveOption);
+    static QRegularExpression reNoFile("No file (.*)");
+    static QRegularExpression reNoAsyFile("File .* does not exist."); // FIXME can be removed when https://sourceforge.net/p/asymptote/bugs/70/ has promoted to the users
 
     switch(dwCookie) {
     //detect the beginning of a warning
-    case Start :
-        if(reLaTeXWarning.indexIn(strLine) != -1) {
-            warning = reLaTeXWarning.cap(5);
-            //qCDebug(LOG_KILE_PARSER) << "\tWarning found: " << warning << endl;
+    case Start : {
+        QRegularExpressionMatch match;
+        if(strLine.indexOf(reLaTeXWarning, 0, &match) != -1) {
+            warning = match.captured(5);
+            //qCDebug(LOG_KILE_PARSER) << "\tWarning found: " << warning << Qt::endl;
 
             found = true;
             dwCookie = Start;
@@ -424,28 +430,31 @@ bool LaTeXOutputParser::detectWarning(const QString & strLine, short &dwCookie)
 
             //do we expect a line number?
             flush = detectLaTeXLineNumber(warning, dwCookie, strLine.length());
+            break;
         }
-        else if(reNoFile.indexIn(strLine) != -1) {
+        else if(strLine.indexOf(reNoFile, 0, &match) != -1) {
             found = true;
             flush = true;
             m_currentItem.setSourceLine(0);
-            m_currentItem.setMessage(reNoFile.cap(0));
+            m_currentItem.setMessage(match.captured(0));
             m_currentItem.setOutputLine(GetCurrentOutputLine());
+            break;
         }
-        else if(reNoAsyFile.indexIn(strLine) != -1) {
+        else if(strLine.indexOf(reNoAsyFile, 0, &match) != -1) {
             found = true;
             flush = true;
             m_currentItem.setSourceLine(0);
-            m_currentItem.setMessage(reNoAsyFile.cap(0));
+            m_currentItem.setMessage(match.captured(0));
             m_currentItem.setOutputLine(GetCurrentOutputLine());
         }
 
         break;
+    }
 
     //warning spans multiple lines, detect the end
     case Warning :
         warning = m_currentItem.message() + strLine;
-        //qCDebug(LOG_KILE_PARSER) << "'\tWarning (cont'd) : " << warning << endl;
+        //qCDebug(LOG_KILE_PARSER) << "'\tWarning (cont'd) : " << warning << Qt::endl;
         flush = detectLaTeXLineNumber(warning, dwCookie, strLine.length());
         m_currentItem.setMessage(warning);
         break;
@@ -468,50 +477,61 @@ bool LaTeXOutputParser::detectWarning(const QString & strLine, short &dwCookie)
 
 bool LaTeXOutputParser::detectLaTeXLineNumber(QString & warning, short & dwCookie, int len)
 {
-    //qCDebug(LOG_KILE_PARSER) << "==LaTeXOutputParser::detectLaTeXLineNumber(" << warning.length() << ")================" << endl;
+    //qCDebug(LOG_KILE_PARSER) << "==LaTeXOutputParser::detectLaTeXLineNumber(" << warning.length() << ")================" << Qt::endl;
 
-    static QRegExp reLaTeXLineNumber("(.*) on input line ([0-9]+)\\.$", Qt::CaseInsensitive);
-    static QRegExp reInternationalLaTeXLineNumber("(.*)([0-9]+)\\.$", Qt::CaseInsensitive);
-    if((reLaTeXLineNumber.indexIn(warning) != -1) || (reInternationalLaTeXLineNumber.indexIn(warning) != -1)) {
-        //qCDebug(LOG_KILE_PARSER) << "een" << endl;
-        m_currentItem.setSourceLine(reLaTeXLineNumber.cap(2).toInt());
-        warning += reLaTeXLineNumber.cap(1);
+    static QRegularExpression reLaTeXLineNumber("(.*) on input line ([0-9]+)\\.$", QRegularExpression::CaseInsensitiveOption);
+    static QRegularExpression reInternationalLaTeXLineNumber("(.*)([0-9]+)\\.$", QRegularExpression::CaseInsensitiveOption);
+    QRegularExpressionMatch match;
+    if((warning.indexOf(reLaTeXLineNumber, 0, &match) != -1) || (warning.indexOf(reInternationalLaTeXLineNumber, 0, &match) != -1)) {
+        //qCDebug(LOG_KILE_PARSER) << "een" << Qt::endl;
+        m_currentItem.setSourceLine(match.captured(2).toInt());
+        warning += match.captured(1);
         dwCookie = Start;
         return true;
     }
-    else if(warning.endsWith('.')) {
-        //qCDebug(LOG_KILE_PARSER) << "twee" << endl;
+
+    QRegularExpressionMatch internaltionalLaTeXLineNumberMatch = reInternationalLaTeXLineNumber.match(warning);
+
+    if(internaltionalLaTeXLineNumberMatch.hasMatch()) {
+        m_currentItem.setSourceLine(internaltionalLaTeXLineNumberMatch.captured(2).toInt());
+        warning += internaltionalLaTeXLineNumberMatch.captured(1);
+        dwCookie = Start;
+        return true;
+    }
+
+    if(warning.endsWith('.')) {
+        //qCDebug(LOG_KILE_PARSER) << "twee" << Qt::endl;
         m_currentItem.setSourceLine(0);
         dwCookie = Start;
         return true;
     }
+
     //bailing out, did not find a line number
-    else if((GetCurrentOutputLine() - m_currentItem.outputLine() > 4) || (len == 0)) {
-        //qCDebug(LOG_KILE_PARSER) << "drie current " << GetCurrentOutputLine() << " " <<  m_currentItem.outputLine() << " len " << len << endl;
+    if((GetCurrentOutputLine() - m_currentItem.outputLine() > 4) || (len == 0)) {
+        //qCDebug(LOG_KILE_PARSER) << "drie current " << GetCurrentOutputLine() << " " <<  m_currentItem.outputLine() << " len " << len << Qt::endl;
         m_currentItem.setSourceLine(0);
         dwCookie = Start;
         return true;
     }
+
     //error message is continued on the other line
-    else {
-        //qCDebug(LOG_KILE_PARSER) << "vier" << endl;
-        dwCookie = Warning;
-        return false;
-    }
+    dwCookie = Warning;
+    return false;
 }
 
 bool LaTeXOutputParser::detectBadBox(const QString & strLine, short & dwCookie)
 {
-    //qCDebug(LOG_KILE_PARSER) << "==LaTeXOutputParser::detectBadBox(" << strLine.length() << ")================" << endl;
+    //qCDebug(LOG_KILE_PARSER) << "==LaTeXOutputParser::detectBadBox(" << strLine.length() << ")================" << Qt::endl;
 
     bool found = false, flush = false;
     QString badbox;
 
-    static QRegExp reBadBox("^(Over|Under)(full \\\\[hv]box .*)", Qt::CaseInsensitive);
+    static QRegularExpression reBadBox("^(Over|Under)(full \\\\[hv]box .*)", QRegularExpression::CaseInsensitiveOption);
+    QRegularExpressionMatch match;
 
     switch(dwCookie) {
-    case Start :
-        if(reBadBox.indexIn(strLine) != -1) {
+    case Start : 
+        if(strLine.indexOf(reBadBox, 0, &match) != -1) {
             found = true;
             dwCookie = Start;
             badbox = strLine;
@@ -544,51 +564,51 @@ bool LaTeXOutputParser::detectBadBox(const QString & strLine, short & dwCookie)
 
 bool LaTeXOutputParser::detectBadBoxLineNumber(QString & strLine, short & dwCookie, int len)
 {
-    //qCDebug(LOG_KILE_PARSER) << "==LaTeXOutputParser::detectBadBoxLineNumber(" << strLine.length() << ")================" << endl;
+    //qCDebug(LOG_KILE_PARSER) << "==LaTeXOutputParser::detectBadBoxLineNumber(" << strLine.length() << ")================" << Qt::endl;
 
-    static QRegExp reBadBoxLines("(.*) at lines ([0-9]+)--([0-9]+)", Qt::CaseInsensitive);
-    static QRegExp reBadBoxLine("(.*) at line ([0-9]+)", Qt::CaseInsensitive);
+    static QRegularExpression reBadBoxLines("(.*) at lines ([0-9]+)--([0-9]+)", QRegularExpression::CaseInsensitiveOption);
+    static QRegularExpression reBadBoxLine("(.*) at line ([0-9]+)", QRegularExpression::CaseInsensitiveOption);
     //Use the following only, if you know how to get the source line for it.
     // This is not simple, as TeX is not reporting it.
-    static QRegExp reBadBoxOutput("(.*)has occurred while \\output is active^", Qt::CaseInsensitive);
+    static QRegularExpression reBadBoxOutput("(.*)has occurred while \\output is active^", QRegularExpression::CaseInsensitiveOption);
+    QRegularExpressionMatch match;
 
-    if(reBadBoxLines.indexIn(strLine) != -1) {
+    if(strLine.indexOf(reBadBoxLines, 0, &match) != -1) {
         dwCookie = Start;
-        strLine = reBadBoxLines.cap(1);
-        int n1 = reBadBoxLines.cap(2).toInt();
-        int n2 = reBadBoxLines.cap(3).toInt();
+        strLine = match.captured(1);
+        int n1 = match.captured(2).toInt();
+        int n2 = match.captured(3).toInt();
         m_currentItem.setSourceLine(n1 < n2 ? n1 : n2);
         return true;
     }
-    else if(reBadBoxLine.indexIn(strLine) != -1) {
+    else if(strLine.indexOf(reBadBoxLine, 0, &match) != -1) {
         dwCookie = Start;
-        strLine = reBadBoxLine.cap(1);
-        m_currentItem.setSourceLine(reBadBoxLine.cap(2).toInt());
-        //qCDebug(LOG_KILE_PARSER) << "\tBadBox@" << reBadBoxLine.cap(2) << "." << endl;
+        strLine = match.captured(1);
+        m_currentItem.setSourceLine(match.captured(2).toInt());
+        //qCDebug(LOG_KILE_PARSER) << "\tBadBox@" << reBadBoxLine.cap(2) << "." << Qt::endl;
         return true;
     }
-    else if(reBadBoxOutput.indexIn(strLine) != -1) {
+    else if(strLine.indexOf(reBadBoxOutput, 0, &match) != -1) {
         dwCookie = Start;
-        strLine = reBadBoxLines.cap(1);
+        strLine = match.captured(1);
         m_currentItem.setSourceLine(0);
         return true;
     }
-    //bailing out, did not find a line number
-    else if((GetCurrentOutputLine() - m_currentItem.outputLine() > 3) || (len == 0)) {
-        dwCookie = Start;
-        m_currentItem.setSourceLine(0);
-        return true;
-    }
-    else {
-        dwCookie = BadBox;
-    }
 
+    //bailing out, did not find a line number
+    if((GetCurrentOutputLine() - m_currentItem.outputLine() > 3) || (len == 0)) {
+        dwCookie = Start;
+        m_currentItem.setSourceLine(0);
+        return true;
+    }
+
+    dwCookie = BadBox;
     return false;
 }
 
 short LaTeXOutputParser::parseLine(const QString & strLine, short dwCookie)
 {
-    //qCDebug(LOG_KILE_PARSER) << "==LaTeXOutputParser::parseLine(" << strLine << dwCookie << strLine.length() << ")================" << endl;
+    //qCDebug(LOG_KILE_PARSER) << "==LaTeXOutputParser::parseLine(" << strLine << dwCookie << strLine.length() << ")================" << Qt::endl;
 
     switch (dwCookie) {
     case Start :
@@ -635,7 +655,6 @@ ParserOutput* LaTeXOutputParser::parse()
     m_stackFile.push(LOFStackItem(QFileInfo(source()).fileName(), true));
 
     short sCookie = 0;
-    QString s;
     QFile f(m_logFile);
 
     m_log.clear();
@@ -654,7 +673,7 @@ ParserOutput* LaTeXOutputParser::parse()
             f.close();
             return Q_NULLPTR;
         }
-        s = t.readLine();
+        QString s = t.readLine();
         sCookie = parseLine(s.trimmed(), sCookie);
         ++m_nOutputLines;
 
