@@ -1,7 +1,7 @@
 /**********************************************************************************
 *   Copyright (C) 2003 by Jeroen Wijnhout (Jeroen.Wijnhout@kdemail.net)           *
 *                 2005-2007 by Holger Danielsson (holger.danielsson@versanet.de)  *
-*                 2006-2011 by Michel Ludwig (michel.ludwig@kdemail.net)          *
+*                 2006-2022 by Michel Ludwig (michel.ludwig@kdemail.net)          *
 ***********************************************************************************/
 
 /***************************************************************************
@@ -50,7 +50,7 @@ ParserInput::~ParserInput()
 
 ParserOutput::~ParserOutput()
 {
-    Q_FOREACH(StructureViewItem *item, structureViewItems) {
+    for(StructureViewItem *item : structureViewItems) {
         delete(item);
     }
 }
@@ -67,7 +67,7 @@ Parser::~Parser()
 
 QString Parser::processTextline(const QString &line, TodoResult &todo)
 {
-    static QRegExp reComments("[^\\\\](%.*$)");
+    static QRegularExpression reComments("[^\\\\](%.*$)");
     QString s = line;
     todo.type = -1;
     if(!s.isEmpty()) {
@@ -81,10 +81,10 @@ QString Parser::processTextline(const QString &line, TodoResult &todo)
             s.replace("\\\\", "  ");
 
             //remove comments
-            int pos = s.indexOf(reComments);
-            if(pos != -1) {
-                searchTodoComment(s, pos,todo);
-                s = s.left(reComments.pos(1));
+            const auto match = reComments.match(s);
+            if(match.hasMatch()) {
+                searchTodoComment(s, match.capturedStart(1), todo);
+                s = s.left(match.capturedStart(1));
             }
         }
     }
@@ -93,13 +93,14 @@ QString Parser::processTextline(const QString &line, TodoResult &todo)
 
 void Parser::searchTodoComment(const QString &s, uint startpos, TodoResult &todo)
 {
-    static QRegExp reTodoComment("\\b(TODO|FIXME)\\b(:|\\s)?\\s*(.*)");
+    static QRegularExpression reTodoComment("\\b(TODO|FIXME)\\b(:|\\s)?\\s*(.*)");
 
-    if(s.indexOf(reTodoComment, startpos) != -1) {
-        todo.type = (reTodoComment.cap(1) == "TODO") ? KileStruct::ToDo : KileStruct::FixMe;
-        todo.colTag = reTodoComment.pos(1);
-        todo.colComment = reTodoComment.pos(3);
-        todo.comment = reTodoComment.cap(3).trimmed();
+    auto match = reTodoComment.match(s, startpos);
+    if (match.hasMatch()) {
+        todo.type = (match.capturedView(1) == QLatin1String("TODO")) ? KileStruct::ToDo : KileStruct::FixMe;
+        todo.colTag = match.capturedStart(1);
+        todo.colComment = match.capturedStart(3);
+        todo.comment = match.captured(3).trimmed();
     }
 }
 
@@ -119,13 +120,13 @@ QString Parser::matchBracket(const QStringList& textLines, QChar obracket, int &
     }
 
     QString line, grab = "";
-    int count=0, len;
+    int count=0;
     ++pos;
 
     TodoResult todo;
     while(l < textLines.size()) {
         line = processTextline(textLines[l], todo);
-        len = line.length();
+        int len = line.length();
         for (int i = pos; i < len; ++i) {
             if(line[i] == '\\' && (line[i+1] == obracket || line[i+1] == cbracket)) {
                 ++i;
