@@ -1,5 +1,5 @@
 /**************************************************************************
-*   Copyright (C) 2006-2019 by Michel Ludwig (michel.ludwig@kdemail.net)  *
+*   Copyright (C) 2006-2020 by Michel Ludwig (michel.ludwig@kdemail.net)  *
 ***************************************************************************/
 
 /**************************************************************************
@@ -23,6 +23,7 @@
 #include <QDir>
 #include <QDirIterator>
 #include <QMap>
+#include <qplaintextedit.h>
 
 #include "kiledebug.h"
 #include "kileconfig.h"
@@ -76,9 +77,10 @@ Manager::~Manager()
     delete m_kileScriptObject;
 
     //still need to delete the scripts
-    for(QList<Script*>::iterator it = m_jScriptList.begin(); it != m_jScriptList.end(); ++it) {
-        delete *it;
+    for(Script *script : std::as_const(m_jScriptList)) {
+        delete script;
     }
+    m_jScriptList.clear();
 }
 
 void Manager::executeScript(const Script *script)
@@ -87,14 +89,15 @@ void Manager::executeScript(const Script *script)
 
     // compatibility check
     QString code = script->getCode();
-    QRegExp endOfLineExp("(\r\n)|\n|\r");
+    QRegularExpression endOfLineExp("(\r\n)|\n|\r");
     int i = code.indexOf(endOfLineExp);
     QString firstLine = (i >= 0 ? code.left(i) : code);
     QRegExp requiredVersionTagExp("(kile-version:\\s*)(\\d+\\.\\d+(.\\d+)?)");
     if(requiredVersionTagExp.indexIn(firstLine) != -1) {
         QString requiredKileVersion = requiredVersionTagExp.cap(2);
-        if(compareVersionStrings(requiredKileVersion, kileFullVersion) > 0) {
-            KMessageBox::sorry(m_kileInfo->mainWindow(), i18n("Version %1 of Kile is at least required to execute the script \"%2\". The execution has been aborted.", requiredKileVersion, script->getName()), i18n("Version Error"));
+        if(compareVersionStrings(requiredKileVersion, QLatin1StringView(KILE_VERSION_STRING)) > 0) {
+            KMessageBox::error(m_kileInfo->mainWindow(), i18n("Version %1 of Kile is at least required to execute the script \"%2\". The execution has been aborted.",
+                                                              requiredKileVersion, script->getName()), i18n("Version Error"));
             return;
         }
     }
@@ -102,7 +105,7 @@ void Manager::executeScript(const Script *script)
     // TODO only scripts with a current view can be started at this moment
     KTextEditor::View *view = m_kileInfo->viewManager()->currentTextView();
     if(!view) {
-        KMessageBox::sorry(m_kileInfo->mainWindow(), i18n("Cannot start the script: no view available"), i18n("Script Error"));
+        KMessageBox::error(m_kileInfo->mainWindow(), i18n("Cannot start the script: no view available"), i18n("Script Error"));
         return;
     }
 
@@ -140,37 +143,54 @@ void Manager::scanScriptDirectories()
     populateDirWatch();
 
     KConfigGroup configGroup = m_config->group("Scripts");
-    QList<unsigned int> idList = configGroup.readEntry("IDs", QList<unsigned int>());
+    const QList<unsigned int> idList = configGroup.readEntry("IDs", QList<unsigned int>());
     unsigned int maxID = 0;
     QMap<QString, unsigned int> pathIDMap;
     QMap<unsigned int, bool> takenIDMap;
-    for(QList<unsigned int>::iterator i = idList.begin(); i != idList.end(); ++i) {
-        QString fileName = configGroup.readPathEntry("Script" + QString::number(*i), QString());
+    for(const unsigned int i : idList) {
+        // as of 12.07.2020, KConfigGroup::readPathEntry messes up the path if $HOME ends in /
+        // for example, if HOME=/home/michel/, KConfigGroup::readPathEntry will return /home/michel//.local/share/kile/scripts/test.js,
+        // resulting in the path /home/michel/.local/share/kile/scripts/test.js not being found;
+        // we have used QDir:cleanPath to work around this
+        QString fileName = QDir::cleanPath(configGroup.readPathEntry("Script" + QString::number(i), QString()));
         if(!fileName.isEmpty()) {
-            unsigned int id = *i;
+            unsigned int id = i;
             pathIDMap[fileName] = id;
             takenIDMap[id] = true;
             maxID = qMax(maxID, id);
         }
     }
 
-    // scan *.js files
+    // scan for *.js files
     QSet<QString> scriptFileNamesSet;
-    const QStringList dirs = KileUtilities::locateAll(QStandardPaths::AppDataLocation, "scripts/", QStandardPaths::LocateDirectory);
-    Q_FOREACH (const QString &dir, dirs) {
-        QDirIterator it(dir, QStringList() << QStringLiteral("*.js"), QDir::Files | QDir::Readable, QDirIterator::Subdirectories);
-        while (it.hasNext()) {
-            scriptFileNamesSet.insert(it.next());
+    {
+        QSet<QString> canonicalScriptFileNamesSet;
+        const QStringList dirs = KileUtilities::locateAll(QStandardPaths::AppDataLocation, "scripts/", QStandardPaths::LocateDirectory);
+        for(const QString &dir : dirs) {
+            QDirIterator it(dir, QStringList() << QStringLiteral("*.js"), QDir::Files | QDir::Readable, QDirIterator::Subdirectories);
+            while(it.hasNext()) {
+                const QString fileName = QDir::cleanPath(it.next());
+                const QString canonicalFilePath = QFileInfo(fileName).canonicalFilePath();
+
+                // filter out file paths that point to the same file (via symbolic links, for example)
+                // but later on we work with the original file path, possibly containing symbolic links
+                if(canonicalFilePath.isEmpty() || canonicalScriptFileNamesSet.contains(canonicalFilePath)) {
+                    continue;
+                }
+                canonicalScriptFileNamesSet.insert(canonicalFilePath);
+
+                scriptFileNamesSet.insert(fileName);
+            }
         }
     }
 
-    Q_FOREACH(const QString &scriptFileName, scriptFileNamesSet) {
+    for(const QString &scriptFileName : std::as_const(scriptFileNamesSet)) {
         registerScript(scriptFileName, pathIDMap, takenIDMap, maxID);
     }
     //rewrite the IDs that are currently in use
     writeIDs();
     m_actionCollection->readSettings();
-    emit scriptsChanged();
+    Q_EMIT scriptsChanged();
 }
 
 void Manager::deleteScripts()
@@ -186,7 +206,8 @@ void Manager::deleteScripts()
     for(QList<Script*>::iterator it = scriptList.begin(); it != scriptList.end(); ++it) {
         QAction *action = (*it)->getActionObject();
         if(action) {
-            foreach(QWidget *w, action->associatedWidgets()) {
+            const QList<QWidget*> widgets = action->associatedWidgets();
+            for(QWidget *w : widgets) {
                 w->removeAction(action);
             }
             m_actionCollection->takeAction(action);
@@ -194,7 +215,7 @@ void Manager::deleteScripts()
         }
         delete *it;
     }
-    emit scriptsChanged();
+    Q_EMIT scriptsChanged();
 }
 
 QList<Script*> Manager::getScripts()
@@ -225,11 +246,11 @@ void Manager::registerScript(const QString& fileName, QMap<QString, unsigned int
     int sequenceType = 0;
     QString editorKeySequence = QString();
     QString seq = configGroup.readEntry("Script" + QString::number(id) + "KeySequence");
-    if ( !seq.isEmpty() ) {
+    if(!seq.isEmpty()) {
         QRegExp re("(\\d+)-(.*)");
-        if ( re.exactMatch(seq) )  {
+        if(re.exactMatch(seq))  {
             sequenceType = re.cap(1).toInt();
-            if ( sequenceType<Script::KEY_SEQUENCE || sequenceType>Script::KEY_SHORTCUT ) {
+            if(sequenceType<Script::KEY_SEQUENCE || sequenceType>Script::KEY_SHORTCUT) {
                 sequenceType = Script::KEY_SEQUENCE;
             }
             editorKeySequence = re.cap(2);
@@ -244,21 +265,22 @@ void Manager::registerScript(const QString& fileName, QMap<QString, unsigned int
     // now set up a regular action object
     ScriptExecutionAction *action = new ScriptExecutionAction(id, this, m_actionCollection);
 
+    // add to action collection
+    m_actionCollection->addAction("script" + QString::number(id) + "_execution", action);
+    m_actionCollection->setDefaultShortcut(action, QString());
+    script->setActionObject(action);
+
     // action with shortcut?
     if(!editorKeySequence.isEmpty()) {
         script->setSequenceType(sequenceType);
         script->setKeySequence(editorKeySequence);
-        if ( sequenceType == Script::KEY_SEQUENCE )  {
+        if(sequenceType == Script::KEY_SEQUENCE) {
             m_kileInfo->editorKeySequenceManager()->addAction(editorKeySequence, new KileEditorKeySequence::ExecuteScriptAction(script, this));
         }
         else {
             action->setShortcut(editorKeySequence);
         }
     }
-
-    // add to action collection
-    m_actionCollection->addAction("script" + QString::number(id) + "_execution", action);
-    script->setActionObject(action);
 }
 
 void Manager::writeConfig()
@@ -272,10 +294,10 @@ void Manager::writeConfig()
 
     // write the key sequences
     KConfigGroup configGroup = m_config->group("Scripts");
-    for(QList<Script*>::iterator i = m_jScriptList.begin(); i != m_jScriptList.end(); ++i) {
-        QString seq = (*i)->getKeySequence();
-        QString sequenceEntry = ( seq.isEmpty() ) ? seq : QString("%1-%2").arg(QString::number((*i)->getSequenceType())).arg(seq);
-        configGroup.writeEntry("Script" + QString::number((*i)->getID()) + "KeySequence", sequenceEntry);
+    for(const Script *script : std::as_const(m_jScriptList)) {
+        QString seq = script->getKeySequence();
+        QString sequenceEntry = (seq.isEmpty()) ? seq : QString("%1-%2").arg(QString::number(script->getSequenceType()), seq);
+        configGroup.writeEntry("Script" + QString::number(script->getID()) + "KeySequence", sequenceEntry);
     }
 }
 
@@ -287,26 +309,40 @@ void Manager::setEditorKeySequence(Script* script, int type, const QString& keyS
     if(script) {
         int oldType = script->getSequenceType();
         QString oldSequence = script->getKeySequence();
-        if( oldType==type && oldSequence==keySequence) {
+        if(oldType == type && oldSequence == keySequence) {
             return;
         }
 
-        if ( oldType == KileScript::Script::KEY_SEQUENCE ) {
+        if(oldType == KileScript::Script::KEY_SEQUENCE) {
             m_kileInfo->editorKeySequenceManager()->removeKeySequence(oldSequence);
         }
         else {
-            script->getActionObject()->setShortcut(QString());
+            script->getActionObject()->setShortcut(QKeySequence());
         }
         script->setSequenceType(type);
         script->setKeySequence(keySequence);
-        if ( type == KileScript::Script::KEY_SEQUENCE ) {
+        if(type == KileScript::Script::KEY_SEQUENCE) {
             m_kileInfo->editorKeySequenceManager()->addAction(keySequence, new KileEditorKeySequence::ExecuteScriptAction(script, this));
         }
         else {
             script->getActionObject()->setShortcut(keySequence);
         }
+    }
+}
 
-        writeConfig();
+void Manager::setShortcut(Script* script, const QKeySequence& keySequence)
+{
+    if(keySequence.isEmpty()) {
+        return;
+    }
+    if(script) {
+        if(script->getSequenceType() == KileScript::Script::KEY_SEQUENCE) {
+            m_kileInfo->editorKeySequenceManager()->removeKeySequence(script->getKeySequence());
+        }
+
+        script->setSequenceType(KileScript::Script::KEY_SHORTCUT);
+        script->setKeySequence(keySequence.toString(QKeySequence::PortableText));
+        script->getActionObject()->setShortcut(keySequence);
     }
 }
 
@@ -320,7 +356,7 @@ void Manager::removeEditorKeySequence(Script* script)
         script->setKeySequence(QString());
 
         int sequenceType = script->getSequenceType();
-        if ( sequenceType == Script::KEY_SEQUENCE ) {
+        if(sequenceType == Script::KEY_SEQUENCE) {
             m_kileInfo->editorKeySequenceManager()->removeKeySequence(keySequence);
         }
         else {
@@ -333,11 +369,11 @@ void Manager::removeEditorKeySequence(Script* script)
 
 void Manager::populateDirWatch()
 {
-    QStringList jScriptDirectories = KileUtilities::locateAll(QStandardPaths::AppDataLocation, "scripts/", QStandardPaths::LocateDirectory);
-    for(QStringList::iterator i = jScriptDirectories.begin(); i != jScriptDirectories.end(); ++i) {
+    const QStringList jScriptDirectories = KileUtilities::locateAll(QStandardPaths::AppDataLocation, "scripts/", QStandardPaths::LocateDirectory);
+    for(const QString& dir : jScriptDirectories) {
         // FIXME: future KDE versions could support the recursive
         //        watching of directories out of the box.
-        addDirectoryToDirWatch(*i);
+        addDirectoryToDirWatch(dir);
     }
     //we do not remove the directories that were once added as this apparently causes some strange
     //bugs (on KDE 3.5.x)
@@ -372,8 +408,8 @@ void Manager::writeIDs()
     KConfigGroup configGroup = m_config->group("Scripts");
     //delete old entries
     QList<unsigned int> idList = configGroup.readEntry("IDs", QList<unsigned int>());
-    for(QList<unsigned int>::iterator i = idList.begin(); i != idList.end(); ++i) {
-        configGroup.deleteEntry("Script" + QString::number(*i));
+    for(const int i : std::as_const(idList)) {
+        configGroup.deleteEntry("Script" + QString::number(i));
     }
     //write new ones
     idList.clear();
@@ -394,9 +430,8 @@ void Manager::addDirectoryToDirWatch(const QString& dir)
         m_jScriptDirWatch->addDir(dir,  KDirWatch::WatchDirOnly);
     }
     QDir qDir(dir);
-    QStringList list = qDir.entryList(QDir::Dirs);
-    for(QStringList::iterator i = list.begin(); i != list.end(); ++i) {
-        QString subdir = *i;
+    const QStringList list = qDir.entryList(QDir::Dirs);
+    for(const QString& subdir : list) {
         if(subdir != "." && subdir != "..") {
             addDirectoryToDirWatch(qDir.filePath(subdir));
         }
@@ -428,13 +463,15 @@ void Manager::initScriptActions()
                                      ;
 
 
-    foreach ( KXMLGUIClient *client, m_kileInfo->mainWindow()->guiFactory()->clients() ) {
-        KILE_DEBUG_MAIN << "collection count: " << client->actionCollection()->count() ;
+    const QList<KXMLGUIClient*> clients = m_kileInfo->mainWindow()->guiFactory()->clients();
+    for(KXMLGUIClient *client : clients) {
+        KILE_DEBUG_MAIN << "collection count: " << client->actionCollection()->count();
 
-        foreach ( QAction *action, client->actionCollection()->actions() ) {
+        const QList<QAction*> actions = client->actionCollection()->actions();
+        for(QAction *action : actions) {
             QString objectname = action->objectName();
-            if ( m_scriptActionList.indexOf(objectname) >= 0  ) {
-                m_scriptActionMap->insert(objectname,action);
+            if(m_scriptActionList.indexOf(objectname) >= 0) {
+                m_scriptActionMap->insert(objectname, action);
             }
         }
     }
