@@ -2,7 +2,7 @@
     begin                : Sat Apr 26 2003
     copyright            : (C) 2003 by Jeroen Wijnhout (wijnhout@science.uva.nl)
                                2005 by Holger Danielsson (holger.danielsson@t-online.de)
-                               2007-2019 by Michel Ludwig (michel.ludwig@kdemail.net)
+                               2007-2024 by Michel Ludwig (michel.ludwig@kdemail.net)
  *******************************************************************************************/
 
 /***************************************************************************
@@ -24,7 +24,8 @@
 #include <KMessageBox>
 #include <KProcess>
 #include <KShell>
-#include <KIO/Job>
+#include <KIO/FileCopyJob>
+#include <KIO/SimpleJob>
 #include <KJobWidgets>
 #include <QTemporaryFile>
 
@@ -49,7 +50,7 @@ Info::Info() : type(KileDocument::Undefined)
 {
 }
 
-bool Info::operator==(const Info ti) const
+bool Info::operator==(const Info &ti) const
 {
     return name==ti.name;
 }
@@ -82,12 +83,15 @@ bool Manager::copyAppData(const QUrl &src, const QString& subdir, const QString&
             testDir.mkpath(dir);
         }
         // copy file
-        KIO::FileCopyJob* copyJob = KIO::file_copy(src, targetURL);
+        if(src == targetURL) { // copying a file over itself
+            return true;
+        }
+        KIO::FileCopyJob* copyJob = KIO::file_copy(src, targetURL, -1, KIO::Overwrite);
         KJobWidgets::setWindow(copyJob, m_kileInfo->mainWindow());
         return copyJob->exec();
     }
     else {
-        KMessageBox::error(Q_NULLPTR, i18n("Could not find a folder to save %1 to.\nCheck whether you have a .kde folder with write permissions in your home folder.", fileName));
+        KMessageBox::error(Q_NULLPTR, i18n("Could not find a folder to save %1 to.\nCheck whether you have a folder named \".kde\" with write permissions in your home folder.", fileName));
         return false;
     }
 }
@@ -130,77 +134,6 @@ bool Manager::remove(Info ti) {
     return removeAppData(ti.path) && removeAppData(ti.icon);
 }
 
-bool Manager::replace(const KileTemplate::Info& toBeReplaced, const QUrl &newTemplateSourceURL, const QString& newName, const QUrl& newIcon) {
-    KileDocument::Type type = m_kileInfo->extensions()->determineDocumentType(newTemplateSourceURL);
-
-    //start by copying the files that belong to the new template to a safe place
-    QString templateTempFile, iconTempFile;
-
-    if( newTemplateSourceURL.isLocalFile() ) {
-        // file protocol. We do not need the network
-        templateTempFile = newTemplateSourceURL.toLocalFile();
-    }
-    else {
-        QTemporaryFile tmpFile;
-        tmpFile.setAutoRemove( false );
-        tmpFile.open();
-
-        templateTempFile = tmpFile.fileName();
-        m_TempFilePath = tmpFile.fileName();
-        KIO::FileCopyJob* fileCopyJob = KIO::file_copy( newTemplateSourceURL, QUrl::fromLocalFile(templateTempFile), -1, KIO::Overwrite );
-        KJobWidgets::setWindow( fileCopyJob, m_kileInfo->mainWindow() );
-
-        if( ! fileCopyJob->exec() ) {
-            return false;
-        }
-    }
-
-    if( newIcon.isLocalFile() ) {
-        // file protocol. We do not need the network
-        iconTempFile = newIcon.toLocalFile();
-    }
-    else {
-        QTemporaryFile tmpFile;
-        tmpFile.setAutoRemove( false );
-        tmpFile.open();
-
-        iconTempFile = tmpFile.fileName();
-        m_TempFilePath = tmpFile.fileName();
-        KIO::FileCopyJob* fileCopyJob = KIO::file_copy( newIcon, QUrl::fromLocalFile(iconTempFile), -1, KIO::Overwrite );
-        KJobWidgets::setWindow( fileCopyJob, m_kileInfo->mainWindow() );
-
-        if( ! fileCopyJob->exec() ) {
-            if( ! templateTempFile.isEmpty() )
-                QFile::remove( templateTempFile );
-            return false;
-        }
-    }
-
-    //now delete the template that should be replaced
-    if(!remove(toBeReplaced)) {
-        if( ! templateTempFile.isEmpty() )
-            QFile::remove( templateTempFile );
-        if( ! iconTempFile.isEmpty() )
-            QFile::remove( iconTempFile );
-    }
-
-    //finally, create the new template
-    if(!add(QUrl::fromUserInput(templateTempFile), type, newName, QUrl::fromUserInput(iconTempFile))) {
-        if( ! templateTempFile.isEmpty() )
-            QFile::remove( templateTempFile );
-        if( ! iconTempFile.isEmpty() )
-            QFile::remove( iconTempFile );
-        return false;
-    }
-
-    if( ! templateTempFile.isEmpty() )
-        QFile::remove( templateTempFile );
-    if( ! iconTempFile.isEmpty() )
-        QFile::remove( iconTempFile );
-
-    return true;
-}
-
 void Manager::scanForTemplates() {
     KILE_DEBUG_MAIN << "===scanForTemplates()===================";
     QStringList dirs = KileUtilities::locateAll(QStandardPaths::AppDataLocation, "templates", QStandardPaths::LocateDirectory);
@@ -341,7 +274,7 @@ void TemplateIconView::searchLaTeXClassFiles()
 
     connect(m_proc, SIGNAL(readyReadStandardOutput()), this, SLOT(slotProcessOutput()));
     connect(m_proc, SIGNAL(finished(int,QProcess::ExitStatus)), this, SLOT(slotProcessExited(int,QProcess::ExitStatus)));
-    connect(m_proc, SIGNAL(error(QProcess::ProcessError)), this, SLOT(slotProcessError()));
+    connect(m_proc, &KProcess::errorOccurred, this, &TemplateIconView::slotProcessError);
     KILE_DEBUG_MAIN << "=== NewFileWidget::searchClassFiles() ====================";
     KILE_DEBUG_MAIN << "\texecute: " << command;
     m_proc->start();
@@ -356,7 +289,7 @@ void TemplateIconView::slotProcessOutput()
 void TemplateIconView::slotProcessError()
 {
     addTemplateIcons(KileDocument::LaTeX);
-    emit classFileSearchFinished();
+    Q_EMIT classFileSearchFinished();
 }
 
 void TemplateIconView::slotProcessExited(int /*exitCode*/, QProcess::ExitStatus exitStatus)
@@ -366,7 +299,7 @@ void TemplateIconView::slotProcessExited(int /*exitCode*/, QProcess::ExitStatus
     }
 
     addTemplateIcons(KileDocument::LaTeX);
-    emit classFileSearchFinished();
+    Q_EMIT classFileSearchFinished();
 }
 
 void TemplateIconView::addTemplateIcons(KileDocument::Type type)
