@@ -17,10 +17,10 @@
 #include <QFileInfo>
 #include <QMenu>
 
-#include <KIconLoader>
 #include <KMessageBox>
 #include <QUrl>
-#include <KRun>
+#include <KIO/OpenUrlJob>
+#include <KIO/JobUiDelegateFactory>
 
 #include "kileactions.h"
 #include "kileconfig.h"
@@ -183,7 +183,9 @@ void UserHelp::slotUserHelpActivated(const QUrl &url)
         m_manager->run(tool);
     }
     else {
-        new KRun(url,m_mainWindow);
+        auto job = new KIO::OpenUrlJob(url, m_mainWindow);
+        job->setUiDelegate(KIO::createDefaultJobUiDelegate());
+        job->start();
     }
 }
 
