@@ -1,7 +1,7 @@
 /******************************************************************************************
     begin                : Wed Aug 14 2002
     copyright            : (C) 2003 by Jeroen Wijnhout (Jeroen.Wijnhout@kdemail.net)
-                               2007-2014 by Michel Ludwig (michel.ludwig@kdemail.net)
+                               2007-2022 by Michel Ludwig (michel.ludwig@kdemail.net)
 
 from Kate (C) 2001 by Matt Newell
 
@@ -34,19 +34,22 @@ from Kate (C) 2001 by Matt Newell
 #include <KLocalizedString>
 #include <KToolBar>
 #include <KConfig>
+#include <QFrame>
 
 #include "kileconfig.h"
 #include "kiledebug.h"
 
+using namespace Qt::Literals::StringLiterals;
+
 namespace KileWidget {
 
 FileBrowserWidget::FileBrowserWidget(KileDocument::Extensions *extensions, QWidget *parent)
     : QWidget(parent), m_extensions(extensions)
 {
-    m_configGroup = KConfigGroup(KSharedConfig::openConfig(),"FileBrowserWidget");
+    m_configGroup = KConfigGroup(KSharedConfig::openConfig(), u"FileBrowserWidget"_s);
 
     QVBoxLayout* layout = new QVBoxLayout(this);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
     layout->setSpacing(0);
     setLayout(layout);
 
@@ -61,10 +64,15 @@ FileBrowserWidget::FileBrowserWidget(KileDocument::Extensions *extensions, QWidg
     layout->addWidget(m_urlNavigator);
     connect(m_urlNavigator, SIGNAL(urlChanged(QUrl)), SLOT(setDir(QUrl)));
 
+    auto separator = new QFrame(this);
+    separator->setFrameShape(QFrame::HLine);
+    separator->setMaximumHeight(1);
+    layout->addWidget(separator);
+
     m_dirOperator = new KDirOperator(QUrl(), this);
     m_dirOperator->setViewConfig(m_configGroup);
     m_dirOperator->readConfig(m_configGroup);
-    m_dirOperator->setView(KFile::Tree);
+    m_dirOperator->setViewMode(KFile::Tree);
     m_dirOperator->setMode(KFile::Files);
     setFocusProxy(m_dirOperator);
 
@@ -72,8 +80,6 @@ FileBrowserWidget::FileBrowserWidget(KileDocument::Extensions *extensions, QWidg
     connect(m_dirOperator, SIGNAL(fileSelected(KFileItem)), this, SIGNAL(fileSelected(KFileItem)));
     connect(m_dirOperator, SIGNAL(urlEntered(QUrl)), this, SLOT(dirUrlEntered(QUrl)));
 
-
-
     setupToolbar();
 
     layout->addWidget(m_dirOperator);
@@ -109,9 +115,8 @@ void FileBrowserWidget::writeConfig()
 
 void FileBrowserWidget::setupToolbar()
 {
-    KActionCollection *coll = m_dirOperator->actionCollection();
-    m_toolbar->addAction(coll->action("back"));
-    m_toolbar->addAction(coll->action("forward"));
+    m_toolbar->addAction(m_dirOperator->action(KDirOperator::Back));
+    m_toolbar->addAction(m_dirOperator->action(KDirOperator::Forward));
 
     QAction *action = new QAction(this);
     action->setIcon(QIcon::fromTheme("document-open"));
@@ -127,14 +132,14 @@ void FileBrowserWidget::setupToolbar()
 
     // section for settings menu
     KActionMenu *optionsMenu = new KActionMenu(QIcon::fromTheme("configure"), i18n("Options"), this);
-    optionsMenu->setDelayed(false);
-    optionsMenu->addAction(m_dirOperator->actionCollection()->action("short view"));
-    optionsMenu->addAction(m_dirOperator->actionCollection()->action("detailed view"));
-    optionsMenu->addAction(m_dirOperator->actionCollection()->action("tree view"));
-    optionsMenu->addAction(m_dirOperator->actionCollection()->action("detailed tree view"));
+    optionsMenu->setPopupMode(QToolButton::InstantPopup);
+    optionsMenu->addAction(m_dirOperator->action(KDirOperator::ShortView));
+    optionsMenu->addAction(m_dirOperator->action(KDirOperator::DetailedView));
+    optionsMenu->addAction(m_dirOperator->action(KDirOperator::TreeView));
+    optionsMenu->addAction(m_dirOperator->action(KDirOperator::DetailedTreeView));
     optionsMenu->addSeparator();
     optionsMenu->addAction(showOnlyLaTexFilesAction);
-    optionsMenu->addAction(m_dirOperator->actionCollection()->action("show hidden"));
+    optionsMenu->addAction(m_dirOperator->action(KDirOperator::ShowHiddenFiles));
 
     m_toolbar->addSeparator();
     m_toolbar->addAction(optionsMenu);
@@ -178,7 +183,7 @@ void FileBrowserWidget::emitFileSelectedSignal()
 {
     KFileItemList itemList = m_dirOperator->selectedItems();
     for(KFileItemList::iterator it = itemList.begin(); it != itemList.end(); ++it) {
-        emit(fileSelected(*it));
+        Q_EMIT(fileSelected(*it));
     }
 
     m_dirOperator->view()->clearSelection();
