@@ -2,7 +2,7 @@
     begin                : Mon Dec 22 2003
     copyright            : (C) 2001 - 2003 by Brachet Pascal
                                2003 by Jeroen Wijnhout (Jeroen.Wijnhout@kdemail.net)
-                               2007-2012 by Michel Ludwig (michel.ludwig@kdemail.net)
+                               2007-2023 by Michel Ludwig (michel.ludwig@kdemail.net)
  ***************************************************************************************************/
 
 /***************************************************************************
@@ -24,12 +24,12 @@
 #include <QVBoxLayout>
 
 #include <KLocalizedString>
-#include <KPluginLoader>
-#include <KService>
+#include <KPluginFactory>
 #include <KShell>
 #include <QUrl>
 
 #include <KParts/Part>
+#include <KParts/PartLoader>
 #include <KTextEditor/Document>
 #include <KTextEditor/View>
 
@@ -43,7 +43,7 @@ Konsole::Konsole(KileInfo * info, QWidget *parent) :
     m_ki(info)
 {
     setLayout(new QVBoxLayout(this));
-    layout()->setMargin(0);
+    layout()->setContentsMargins(0, 0, 0, 0);
     setFrameStyle(QFrame::StyledPanel | QFrame::Sunken);
     spawn();
 }
@@ -56,22 +56,18 @@ void Konsole::spawn()
 {
     KILE_DEBUG_MAIN << "void Konsole::spawn()";
 
-    KPluginFactory *factory = Q_NULLPTR;
-    KService::Ptr service = KService::serviceByDesktopName("konsolepart");
-    if(!service) {
-        KILE_DEBUG_MAIN << "No service for konsolepart";
-        return;
-    }
+    const QString konsolePart = QStringLiteral("kf6/parts/konsolepart");
+    KPluginFactory *factory = KPluginFactory::loadFactory(konsolePart).plugin;
 
-    factory = KPluginLoader(service->library()).factory();
     if(!factory) {
         KILE_DEBUG_MAIN << "No factory for konsolepart";
         return;
     }
 
-    // the catalog for translations is added by the Konsole part constructor already
-    m_part = static_cast<KParts::ReadOnlyPart*>(factory->create<QObject>(this, this));
+    m_part = factory->create<KParts::ReadOnlyPart>(this);
+
     if(!m_part) {
+        KILE_DEBUG_MAIN << "Could not create konsolepart";
         return;
     }
 
@@ -105,7 +101,6 @@ void Konsole::sync()
     }
 
     if(view) {
-        QString finame;
         QUrl url = view->document()->url();
 
         if(url.path().isEmpty()) {
@@ -131,8 +126,8 @@ void Konsole::setDirectory(const QString &directory)
     if(m_term && !directory.isEmpty() && directory != m_currentDir) {
         m_term->sendInput(QChar(0x05)); // clear the shell command prompt by sending Ctrl+E and
         m_term->sendInput(QChar(0x15)); // Ctrl+U (#301653)
-        m_term->sendInput("cd " + KShell::quoteArg(directory) + '\n');
-        m_term->sendInput("clear\n");
+        m_term->sendInput(" cd " + KShell::quoteArg(directory) + '\n');
+        m_term->sendInput(" clear\n");
         m_currentDir = directory;
     }
 }
