@@ -28,7 +28,7 @@ class ProgressDialog : public QProgressDialog
     Q_OBJECT
 
 public:
-    ProgressDialog(QWidget *parent = Q_NULLPTR);
+    explicit ProgressDialog(QWidget *parent = Q_NULLPTR);
     ~ProgressDialog();
     virtual void closeEvent(QCloseEvent *event) Q_DECL_OVERRIDE;
 
