@@ -26,8 +26,11 @@
 #include <QUrl>
 
 #include <KActionMenu>
-#include <KMimeTypeTrader>
-#include <KRun>
+#include <KIO/ApplicationLauncherJob>
+#include <KIO/JobUiDelegateFactory>
+#include <KIO/OpenUrlJob>
+#include <KApplicationTrader>
+#include <KJobUiDelegate>
 
 #include "kileinfo.h"
 #include "documentinfo.h"
@@ -264,10 +267,10 @@ void ProjectView::slotClicked(QTreeWidgetItem *item)
     ProjectViewItem *itm = static_cast<ProjectViewItem*>(item);
     if(itm) {
         if(itm->type() == KileType::File) {
-            emit(fileSelected(itm->url()));
+            Q_EMIT(fileSelected(itm->url()));
         }
         else if(itm->type() == KileType::ProjectItem) {
-            emit(fileSelected(itm->projectItem()));
+            Q_EMIT(fileSelected(itm->projectItem()));
         }
         else if(itm->type() != KileType::Folder) {
             // don't open project configuration files (*.kilepr)
@@ -276,10 +279,12 @@ void ProjectView::slotClicked(QTreeWidgetItem *item)
                 QMimeDatabase db;
                 QMimeType pMime = db.mimeTypeForUrl(itm->url());
                 if(pMime.name().startsWith(QLatin1String("text/"))) {
-                    emit(fileSelected(itm->url()));
+                    Q_EMIT(fileSelected(itm->url()));
                 }
                 else {
-                    KRun::runUrl(itm->url(), pMime.name(), this, KRun::RunFlags());
+                    auto *job = new KIO::OpenUrlJob(itm->url(), pMime.name());
+                    job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+                    job->start();
                 }
             }
         }
@@ -294,16 +299,16 @@ void ProjectView::slotFile(int id)
         if(item->type() == KileType::File) {
             switch(id) {
             case KPV_ID_OPEN:
-                emit(fileSelected(item->url()));
+                Q_EMIT(fileSelected(item->url()));
                 break;
             case KPV_ID_SAVE:
-                emit(saveURL(item->url()));
+                Q_EMIT(saveURL(item->url()));
                 break;
             case KPV_ID_ADD:
-                emit(addToProject(item->url()));
+                Q_EMIT(addToProject(item->url()));
                 break;
             case KPV_ID_CLOSE:
-                emit(closeURL(item->url()));
+                Q_EMIT(closeURL(item->url()));
                 return; //don't access "item" later on
             default:
                 break;
@@ -319,13 +324,13 @@ void ProjectView::slotProjectItem(int id)
         if(item->type() == KileType::ProjectItem || item->type() == KileType::ProjectExtra) {
             switch(id) {
             case KPV_ID_OPEN:
-                emit(fileSelected(item->projectItem()));
+                Q_EMIT(fileSelected(item->projectItem()));
                 break;
             case KPV_ID_SAVE:
-                emit(saveURL(item->url()));
+                Q_EMIT(saveURL(item->url()));
                 break;
             case KPV_ID_REMOVE:
-                emit(removeFromProject(item->projectItem()));
+                Q_EMIT(removeFromProject(item->projectItem()));
                 break;
             case KPV_ID_INCLUDE :
                 if(item->text(1) == "*") {
@@ -334,14 +339,19 @@ void ProjectView::slotProjectItem(int id)
                 else {
                     item->setText(1, "*");
                 }
-                emit(toggleArchive(item->projectItem()));
+                Q_EMIT(toggleArchive(item->projectItem()));
                 break;
             case KPV_ID_CLOSE:
-                emit(closeURL(item->url()));
+                Q_EMIT(closeURL(item->url()));
                 break; //we can access "item" later as it isn't deleted
             case KPV_ID_OPENWITH:
-                KRun::displayOpenWithDialog(QList<QUrl>() << item->url(), this);
+            {
+                auto *job = new KIO::ApplicationLauncherJob();
+                job->setUrls(QList<QUrl>() << item->url());
+                job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+                job->start();
                 break;
+            }
             default:
                 break;
             }
@@ -356,22 +366,22 @@ void ProjectView::slotProject(int id)
         if(item->type() == KileType::Project) {
             switch(id) {
             case KPV_ID_BUILDTREE:
-                emit(buildProjectTree(item->url()));
+                Q_EMIT(buildProjectTree(item->url()));
                 break;
             case KPV_ID_OPTIONS:
-                emit(projectOptions(item->url()));
+                Q_EMIT(projectOptions(item->url()));
                 break;
             case KPV_ID_CLOSE:
-                emit(closeProject(item->url()));
+                Q_EMIT(closeProject(item->url()));
                 return; //don't access "item" later on
             case KPV_ID_ARCHIVE:
-                emit(projectArchive(item->url()));
+                Q_EMIT(projectArchive(item->url()));
                 break;
             case KPV_ID_ADDFILES:
-                emit(addFiles(item->url()));
+                Q_EMIT(addFiles(item->url()));
                 break;
             case KPV_ID_OPENALLFILES:
-                emit(openAllFiles(item->url()));
+                Q_EMIT(openAllFiles(item->url()));
                 break;
             default:
                 break;
@@ -389,10 +399,17 @@ void ProjectView::slotRun(int id)
     }
 
     if(id == 0) {
-        KRun::displayOpenWithDialog(QList<QUrl>() << itm->url(), this);
+        // open with dialog
+        auto *job = new KIO::ApplicationLauncherJob();
+        job->setUrls(QList<QUrl>() << itm->url());
+        job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+        job->start();
     }
     else {
-        KRun::runService(*m_offerList[id-1], QList<QUrl>() << itm->url(), this);
+        auto *job = new KIO::ApplicationLauncherJob(m_offerList[id - 1]);
+        job->setUrls(QList<QUrl>() << itm->url());
+        job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+        job->start();
     }
 
     itm->setSelected(false);
@@ -557,7 +574,7 @@ ProjectViewItem* ProjectView::parentFor(const KileProjectItem *projitem, Project
             KILE_DEBUG_MAIN << "\t\t" << vi->url().toLocalFile();
             if (vi->url() == parpi->url()) {
                 parpvi = vi;
-                KILE_DEBUG_MAIN << "\t\tfound" <<endl;
+                KILE_DEBUG_MAIN << "\t\tfound" << Qt::endl;
                 break;
             }
             ++it;
@@ -790,7 +807,7 @@ void ProjectView::contextMenuEvent(QContextMenuEvent *event)
     if(projectViewItem->type() == KileType::ProjectExtra && !isKilePrFile) {
         QMenu *servicesMenu = popup.addMenu(QIcon::fromTheme("fork"), i18n("&Open With"));
         QMimeDatabase db;
-        m_offerList = KMimeTypeTrader::self()->query(db.mimeTypeForUrl(projectViewItem->url()).name(), "Application");
+        m_offerList = KApplicationTrader::queryByMimeType(db.mimeTypeForUrl(projectViewItem->url()).name());
         for (int i = 0; i < m_offerList.count(); ++i) {
             action = new QAction(servicesMenu);
             action->setIcon(QIcon::fromTheme(m_offerList[i]->icon()));
