@@ -1,7 +1,7 @@
 /*************************************************************************************************
    Copyright (C) 2003 by Jeroen Wijnhout (Jeroen.Wijnhout@kdemail.net
                  2005-2007 by Holger Danielsson (holger.danielsson@versanet.de)
-                 2008-2016 by Michel Ludwig (michel.ludwig@kdemail.net)
+                 2008-2022 by Michel Ludwig (michel.ludwig@kdemail.net)
  *************************************************************************************************/
 
 /***************************************************************************
@@ -63,13 +63,17 @@
 #include <QHeaderView>
 #include <QMimeDatabase>
 #include <QMimeType>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QScrollBar>
 #include <QUrl>
 
+#include <KApplicationTrader>
+#include <KIO/ApplicationLauncherJob>
+#include <KIO/JobUiDelegateFactory>
+#include <KIO/OpenUrlJob>
+#include <KJobUiDelegate>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KRun>
 
 #include "documentinfo.h"
 #include "errorhandler.h"
@@ -631,10 +635,10 @@ void StructureWidget::slotClicked(QTreeWidgetItem * itm)
     }
 
     if(!(item->type() & KileStruct::None)) {
-        emit(setCursor(item->url(), item->line()-1, item->column()));
+        Q_EMIT(setCursor(item->url(), item->line()-1, item->column()));
     }
     else if(!item->parent()) { //root item
-        emit(setCursor(item->url(), 0, 0));
+        Q_EMIT(setCursor(item->url(), 0, 0));
     }
 }
 
@@ -642,7 +646,7 @@ void StructureWidget::slotDoubleClicked(QTreeWidgetItem * itm)
 {
     KILE_DEBUG_MAIN << "\tStructureWidget::slotDoubleClicked";
     StructureViewItem *item = dynamic_cast<StructureViewItem*>(itm);
-    static QRegExp suffix("\\.[\\d\\w]*$");
+    static QRegularExpression suffix("\\.[\\d\\w]*$");
 
     if (!item) {
         return;
@@ -654,8 +658,9 @@ void StructureWidget::slotDoubleClicked(QTreeWidgetItem * itm)
         QString fname = item->title();
 
 
-        if(fname.indexOf(suffix) != -1) { // check if we have a suffix, if not add standard suffixes
-            KILE_DEBUG_MAIN << "Suffix found: " << suffix.cap(0);
+        QRegularExpressionMatch match;
+        if(fname.indexOf(suffix, 0, &match) != -1) { // check if we have a suffix, if not add standard suffixes
+            KILE_DEBUG_MAIN << "Suffix found: " << match.captured(0);
         }
         else {
             // filename in structureview entry has no extension: this shouldn't happen anymore,
@@ -708,10 +713,12 @@ void StructureWidget::slotDoubleClicked(QTreeWidgetItem * itm)
             if(item->type() == KileStruct::Graphics) {
                 QMimeDatabase db;
                 QMimeType pMime = db.mimeTypeForUrl(url);
-                KRun::runUrl(url, pMime.name(), this, KRun::RunFlags());
+                auto *job = new KIO::OpenUrlJob(url, pMime.name());
+                job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+                job->start();
             }
             else {
-                emit(fileOpen(url, QString()));
+                Q_EMIT(fileOpen(url, QString()));
             }
         }
         else {
@@ -727,12 +734,16 @@ void StructureWidget::slotDoubleClicked(QTreeWidgetItem * itm)
             fi.setFile(otherFilename);
 
             if(fi.isReadable()) {
-                emit(fileOpen(QUrl::fromLocalFile(otherFilename), QString()));
+                Q_EMIT(fileOpen(QUrl::fromLocalFile(otherFilename), QString()));
             }
             else {
-                if(KMessageBox::warningYesNo(this, i18n("Cannot find the included file. The file does not exist, is not readable or Kile is unable to determine the correct path to it. The filename causing this error was: %1.\nDo you want to create this file?", fname), i18n("Cannot Find File"))
-                        == KMessageBox::Yes) {
-                    emit(fileNew(QUrl::fromLocalFile(fname)));
+                if(KMessageBox::warningTwoActions(this,
+                                                  i18n("Cannot find the included file. The file does not exist, is not readable or Kile is unable to determine the correct path to it. The filename causing this error was: %1.\nDo you want to create this file?", fname),
+                                                  i18n("Cannot Find File"),
+                                                  KStandardGuiItem::ok(),
+                                                  KStandardGuiItem::cancel())
+                        == KMessageBox::PrimaryAction) {
+                    Q_EMIT(fileNew(QUrl::fromLocalFile(fname)));
                 }
             }
         }
@@ -787,7 +798,7 @@ void StructureWidget::viewContextMenuEvent(StructureView *view, QContextMenuEven
             url.setPath(m_popupInfo);
 
             QMimeDatabase db;
-            m_offerList = KMimeTypeTrader::self()->query(db.mimeTypeForUrl(url).name(), "Application");
+            m_offerList = KApplicationTrader::queryByMimeType(db.mimeTypeForUrl(url).name());
             for(int i = 0; i < m_offerList.count(); ++i) {
                 popup.addAction(QIcon::fromTheme(m_offerList[i]->icon()), m_offerList[i]->name(),
                                          this, [this, i] { slotPopupGraphics(i + SectioningGraphicsOfferlist); });
@@ -799,9 +810,9 @@ void StructureWidget::viewContextMenuEvent(StructureView *view, QContextMenuEven
 
     if(hasLabel) {
         popup.addSection(i18n("Insert Label"));
-        popup.addAction(i18n("As &reference"), this, [this] { emit(sendText("\\ref{" + m_popupItem->label() + '}')); });
-        popup.addAction(i18n("As &page reference"), this, [this] { emit(sendText("\\pageref{" + m_popupItem->label() + '}')); });
-        popup.addAction(i18n("Only the &label"), this, [this] { emit(sendText(m_popupItem->label())); });
+        popup.addAction(i18n("As &reference"), this, [this] { Q_EMIT(sendText("\\ref{" + m_popupItem->label() + '}')); });
+        popup.addAction(i18n("As &page reference"), this, [this] { Q_EMIT(sendText("\\pageref{" + m_popupItem->label() + '}')); });
+        popup.addAction(i18n("Only the &label"), this, [this] { Q_EMIT(sendText(m_popupItem->label())); });
         popup.addSeparator();
         popup.addSection(i18n("Copy Label to Clipboard"));
         popup.addAction(i18n("As reference"), this, [this] { QApplication::clipboard()->setText("\\ref{" + m_popupItem->label() + '}'); });
@@ -819,25 +830,32 @@ void StructureWidget::viewContextMenuEvent(StructureView *view, QContextMenuEven
 // id's 10..16 (already checked)
 void StructureWidget::slotPopupSectioning(int id)
 {
-    KILE_DEBUG_MAIN << "\tStructureWidget::slotPopupSectioning (" << id << ")"<< endl;
+    KILE_DEBUG_MAIN << "\tStructureWidget::slotPopupSectioning (" << id << ")"<< Qt::endl;
     if(m_popupItem->level() >= 1 && m_popupItem->level() <= 7) {
-        emit(sectioningPopup(m_popupItem, id));
+        Q_EMIT(sectioningPopup(m_popupItem, id));
     }
 }
 
 // id's 100ff (already checked)
 void StructureWidget::slotPopupGraphics(int id)
 {
-    KILE_DEBUG_MAIN << "\tStructureWidget::slotPopupGraphics (" << id << ")"<< endl;
+    KILE_DEBUG_MAIN << "\tStructureWidget::slotPopupGraphics (" << id << ")"<< Qt::endl;
 
     QUrl url;
     url.setPath(m_popupInfo);
 
     if(id == SectioningGraphicsOther) {
-        KRun::displayOpenWithDialog(QList<QUrl>() << url, this);
+        // open with dialog
+        auto *job = new KIO::ApplicationLauncherJob();
+        job->setUrls(QList<QUrl>() << url);
+        job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+        job->start();
     }
     else {
-        KRun::runService(*m_offerList[id-SectioningGraphicsOfferlist], QList<QUrl>() << url, this);
+        auto *job = new KIO::ApplicationLauncherJob(m_offerList[id-SectioningGraphicsOfferlist]);
+        job->setUrls(QList<QUrl>() << url);
+        job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+        job->start();
     }
 }
 
@@ -934,7 +952,7 @@ void StructureWidget::update(KileDocument::Info *docinfo, bool forceParsing)
     view->activate();
 }
 
-void StructureWidget::updateAfterParsing(KileDocument::Info *info, const QLinkedList<KileParser::StructureViewItem*>& items)
+void StructureWidget::updateAfterParsing(KileDocument::Info *info, const std::list<KileParser::StructureViewItem*>& items)
 {
     KILE_DEBUG_MAIN;
     StructureView *view = viewFor(info);
@@ -948,7 +966,7 @@ void StructureWidget::updateAfterParsing(KileDocument::Info *info, const QLinked
     // avoid flickering when parsing
     view->setUpdatesEnabled(false);
     view->cleanUp();
-    Q_FOREACH( KileParser::StructureViewItem *item, items) {
+    for(KileParser::StructureViewItem *item : items) {
         view->addItem(item->title, item->line, item->column, item->type, item->level, item->startline, item->startcol, item->pix, item->folder);
     }
     view->setUpdatesEnabled(true);
