@@ -19,7 +19,6 @@
 #include <QInputDialog>
 #include <QLabel>
 #include <QLayout>
-#include <QRegExp>
 #include <QSpinBox>
 #include <QStackedWidget>
 #include <QTabWidget>
@@ -27,12 +26,12 @@
 
 #include "kiledebug.h"
 #include <KLocalizedString>
-#include <kicondialog.h>
-#include <kiconloader.h>
-#include <kcombobox.h>
+#include <KIconDialog>
+#include <KIconLoader>
+#include <KComboBox>
 #include <QPushButton>
-#include <kconfig.h>
-#include <kmessagebox.h>
+#include <KConfig>
+#include <KMessageBox>
 #include <KConfigGroup>
 
 #include "kiletool_enums.h"
@@ -53,7 +52,7 @@ ToolConfig::ToolConfig(KileTool::Manager *mngr, QWidget *parent, const char *nam
     setObjectName(name);
     m_config = m_manager->config();
     QVBoxLayout *layout = new QVBoxLayout();
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
 //TODO PORT QT5 		layout->setSpacing(QDialog::spacingHint());
     setLayout(layout);
     m_configWidget = new ToolConfigWidget(this);
@@ -484,7 +483,7 @@ void ToolConfig::switchClass(const QString & cls)
 {
     if(m_map["class"] != cls) {
         setClass(cls);
-        emit(changed());
+        Q_EMIT(changed());
     }
 }
 
@@ -507,7 +506,7 @@ void ToolConfig::switchType(int index)
         m_map["type"] = "Process";
         break;
     }
-    emit(changed());
+    Q_EMIT(changed());
 }
 
 void ToolConfig::setCommand(const QString & command) {
